<!--
// Eclipse Calculator Dashboard Widget (Xavier Jubier: http://xjubier.free.fr/)
//
// History:
// --------
// 2005-07-05   1.0.0   First Dashboard Widget version
// 2006-01-25   1.0.1   Minor bug corrections
// 2006-02-12   1.0.2   Minor tweaks
// 2007-02-02   1.0.3   Minor bug corrections and new languages
// 2007-10-06   1.0.4   Added refraction
// 2007-10-07   1.0.5   Use 5MCSE Besselian elements
// 2007-10-08   1.0.6   Check if update is available
//

var D2R = Math.PI / 180.0;
var R2D = 180.0 / Math.PI;
var gPrevLat = 0;
var gPrevLng = 0;
var defaultEclipseIndex = 86;  // July 22, 2009

/*
 setup() is called when the body of the widget is loaded. This function places the localized
 strings into the widget.
*/
function setup( )
{
   // Uncomment to debug in Safari
//  toggleDebug();

  document.getElementById("E_widget").innerText = getLocalizedString("Widget Name");
  document.getElementById("E_copyright").innerHTML = getLocalizedString("Copyright");

  document.getElementById("chooseSE-label").innerText = getLocalizedString("Choose the solar eclipse:");
   // Eclipse popup
  var savedDefaultEclipseIndex = getEclipseFromPreferences();
  defaultEclipseIndex = savedDefaultEclipseIndex;
  populateEclipseSelect();

  document.getElementById("position-label").innerText = getLocalizedString("Enter your position and time zone:");
  document.getElementById("latitude-label").innerText = getLocalizedString("Latitude:");
   // NS Location popup
  populateNSSelect();
  document.getElementById("longitude-label").innerText = getLocalizedString("Longitude:");
   // EW Location popup
  populateEWSelect();
  document.getElementById("altitude-label").innerText = getLocalizedString("Altitude:");
  document.getElementById("meters-label").innerText = getLocalizedString("meters");
  document.getElementById("timeZone-label").innerText = getLocalizedString("Time zone:");
   // Hour popup
  populateHourSelect();
   // Minute popup
  populateMinuteSelect();
   // EW Time popup
  populateEWTSelect();
   // DST popup
  populateDSTSelect();

  createGenericButton(document.getElementById("Reset_Button"), getLocalizedString("Reset Calculator"), resetCalc);
  createGenericButton(document.getElementById("Calculate_Button"), getLocalizedString("Calculate Eclipse Circumstances"), recalculateCircumstances);
  createGenericButton(document.getElementById("Done_Button"), getLocalizedString("Done"), hidePrefs);

  document.getElementById("circumstances-label").innerText = getLocalizedString("Predicted Eclipse Circumstances");
  getdTValue();
  document.getElementById("event-label").innerText = getLocalizedString("Event");
  document.getElementById("date-label").innerText = getLocalizedString("Date");
  document.getElementById("time-label").innerText = getLocalizedString("Time");
  document.getElementById("alt-label").innerText = getLocalizedString("Alt");
  document.getElementById("azi-label").innerText = getLocalizedString("Azi");
  document.getElementById("P-label").innerText = getLocalizedString("P");
  document.getElementById("V-label").innerText = getLocalizedString("V");
  document.getElementById("LC-label").innerText = getLocalizedString("LC");
  document.getElementById("C1-label").innerText = getLocalizedString("Start of partial eclipse");
  document.getElementById("C2-label").innerText = getLocalizedString("Start of central eclipse");
  document.getElementById("Mid-label").innerText = getLocalizedString("Mid eclipse");
  document.getElementById("C3-label").innerText = getLocalizedString("End of central eclipse");
  document.getElementById("C4-label").innerText = getLocalizedString("End of partial eclipse");

  document.getElementById("EType-label").innerText = getLocalizedString("Eclipse type");
  document.getElementById("EDuration-label").innerText = getLocalizedString("Duration");
  document.getElementById("ECoverage-label").innerText = getLocalizedString("Coverage");
  document.getElementById("EMagnitude-label").innerText = getLocalizedString("Magnitude at mid eclipse");
  document.getElementById("ERatio-label").innerText = getLocalizedString("Moon/Sun size ratio");
  document.getElementById("EAntumbralDepth-label").innerText = getLocalizedString("Antumbral depth");

  setLinks();

  clearCoords();

  checkUpdate(getLocalizedString("Language"));

  document.getElementById("latd").focus();
  document.getElementById("latd").select();
}

function showPrefs( )
{
  var front = document.getElementById("front");
  var back = document.getElementById("back");

  if ( window.widget )
    widget.prepareForTransition("ToBack");

  front.style.display = "none";
  back.style.display = "block";
  exitflip( );

  if ( window.widget )
    setTimeout ("widget.performTransition();", 0);
}

function hidePrefs( )
{
  var front = document.getElementById("front");
  var back = document.getElementById("back");

  if ( window.widget )
    widget.prepareForTransition("ToFront");

  back.style.display = "none";
  front.style.display = "block";

  if ( window.widget )
    setTimeout ("widget.performTransition();", 0);
}

function getEclipseFromPreferences( )
{
  var eclipseIndex;

  if ( window.widget )
  {
    eclipseIndex = widget.preferenceForKey("defaultEclipse");
    if ( eclipseIndex == null )
      eclipseIndex = defaultEclipseIndex;
  }
  else
    eclipseIndex = defaultEclipseIndex;

  return eclipseIndex;
}

function setEclipsePreferences( key, value )
{
  if ( window.widget )
    widget.setPreferenceForKey (value, key);
}

function populateEclipseSelect( )
{
  var select = document.getElementById("eclipseIndex");
  var numEclipse = Eclipses.length;

  for (var j = 0; j < numEclipse; j++)
  {
    var element = document.createElement("option");
    element.innerText = getLocalizedString(Eclipses[j].name);
    element.value = Eclipses[j].value;
    element.setAttribute("name", element.innerText);
    select.appendChild(element);
  }

  select.options[defaultEclipseIndex].selected = true;
}

function populateNSSelect( )
{
  var select = document.getElementById("latx");
  var numDirection = NSLocation.length;

  for (var j = 0; j < numDirection; j++)
  {
    var element = document.createElement("option");
    element.innerText = getLocalizedString(NSLocation[j].name);
    element.value = NSLocation[j].value;
    element.setAttribute("name", element.innerText);
    select.appendChild(element);
  }

  select.options[0].selected = true;
}

function populateEWSelect( )
{
  var select = document.getElementById("lonx");
  var numDirection = EWLocation.length;

  for (var j = 0; j < numDirection; j++)
  {
    var element = document.createElement("option");
    element.innerText = getLocalizedString(EWLocation[j].name);
    element.value = EWLocation[j].value;
    element.setAttribute("name", element.innerText);
    select.appendChild(element);
  }

  select.options[0].selected = true;
}

function populateHourSelect( )
{
  var select = document.getElementById("tzh");
  var numHours = HourTimeZone.length;

  for (var j = 0; j < numHours; j++)
  {
    var element = document.createElement("option");
    element.innerText = getLocalizedString(HourTimeZone[j].name);
    element.value = HourTimeZone[j].value;
    element.setAttribute("name", element.innerText);
    select.appendChild(element);
  }

  select.options[0].selected = true;
}

function populateMinuteSelect( )
{
  var select = document.getElementById("tzm");
  var numMinutes = MinuteTimeZone.length;

  for (var j = 0; j < numMinutes; j++)
  {
    var element = document.createElement("option");
    element.innerText = getLocalizedString(MinuteTimeZone[j].name);
    element.value = MinuteTimeZone[j].value;
    element.setAttribute("name", element.innerText);
    select.appendChild(element);
  }

  select.options[0].selected = true;
}

function populateEWTSelect( )
{
  var select = document.getElementById("tzx");
  var numDirection = EWTimeZone.length;

  for (var j = 0; j < numDirection; j++)
  {
    var element = document.createElement("option");
    element.innerText = getLocalizedString(EWTimeZone[j].name);
    element.value = EWTimeZone[j].value;
    element.setAttribute("name", element.innerText);
    select.appendChild(element);
  }

  select.options[0].selected = true;
}

function populateDSTSelect( )
{
  var select = document.getElementById("dst");
  var numDST = DSTTimeZone.length;

  for (var j = 0; j < numDST; j++)
  {
    var element = document.createElement("option");
    element.innerText = getLocalizedString(DSTTimeZone[j].name);
    element.value = DSTTimeZone[j].value;
    element.setAttribute("name", element.innerText);
    select.appendChild(element);
  }

  select.options[0].selected = true;
}

function recalculateCircumstances( )
{
  recalculate(getLocalizedString("Language"));
  setLinks();
}

function resetCalc( )
{
  document.getElementById("eclipseIndex").options[defaultEclipseIndex].selected = true;
  resetEclipse();
  setTimeout( "getdTValue( )", 50);
}

function resetEclipse( )
{
  clearinputs();
  clearresults();
  getdTValue();
  setEclipsePreferences("defaultEclipse", getEclipseIndex());
  setLinks();

  document.getElementById("latd").focus();
  document.getElementById("latd").select();
}

function getEclipseIndex( )
{
  var index = parseInt(document.getElementById("eclipseIndex").value, 10) - 1;

  return index;
}

function setLinks( )
{
  var index;

  index = 30 * getEclipseIndex();
  if ( elements[28 + index] != "" )
    document.getElementById("E_GoogleMaps").style.visibility = "visible";
  else
    document.getElementById("E_GoogleMaps").style.visibility = "hidden";
  document.getElementById("E_GoogleMaps").innerHTML = getLocalizedString("Current Interactive Google Maps1") + elements[28 + index] + getLocalizedString("Current Interactive Google Maps2");
  if ( elements[29 + index] != "" )
    document.getElementById("E_GoogleEarth").style.visibility = "visible";
  else
    document.getElementById("E_GoogleEarth").style.visibility = "hidden";
  document.getElementById("E_GoogleEarth").innerHTML = getLocalizedString("Current Google Earth File1") + elements[29 + index] + getLocalizedString("Current Google Earth File2");

  document.getElementById("SolarEclipses").innerHTML = getLocalizedString("Solar Eclipses");
  document.getElementById("GoogleMaps").innerHTML = getLocalizedString("Interactive Google Maps");
  document.getElementById("GoogleEarthFiles").innerHTML = getLocalizedString("Google Earth Files");
  document.getElementById("EclipseWeather").innerHTML = getLocalizedString("Eclipse Weather");
}

/*
 getLocalizedString() pulls a string out an array named localizedStrings.  Each language project
 directory in this widget contains a file named "localizedStrings.js", which, in turn, contains
 an array called localizedStrings.  This method queries the array of the file of whichever language
 has highest precidence, according to the International pane of System Preferences.
*/
function getLocalizedString( key )
{
  var returnValue = key;

  if ( window.widget )
  {
    try
    {
       // This handles the case where localizedStrings[key] doesn't exist
      if ( localizedStrings[key] != null )
        returnValue = localizedStrings[key];
    }
    catch (ex)
    {
       // This handles the case where localizedStrings[] doesn't exist
      debug(key);
    }
  }

  return returnValue;
}

/*
function onshow( )
{
  resizeFromTextAsNeeded();
  resizeToTextAsNeeded();
  document.getElementById("from_text_area").focus();
  document.getElementById("to_text_area").blur();
}

function onhide( )
{
  document.getElementById("from_text_area").blur();
  document.getElementById("to_text_area").blur();
}

if ( window.widget )
{
  widget.onshow = onshow;
  widget.onhide = onhide;
}
*/

var flipShown = false;
var animation = {duration: 0, starttime: 0, to: 1.0, now: 0.0, from: 0.0, firstElement: null, timer: null};

function mousemove( event )
{
  if ( window.widget )
  {
    if (!flipShown)
    {
      if (animation.timer != null)
      {
        clearInterval (animation.timer);
        animation.timer = null;
      }

      var starttime = (new Date).getTime() - 13;

      animation.duration = 500;
      animation.starttime = starttime;
      animation.firstElement = document.getElementById("flip");
      animation.timer = setInterval ("animate();", 13);
      animation.from = animation.now;
      animation.to = 1.0;
      animate();
      flipShown = true;
    }
  }
}

function mouseexit( event )
{
  if ( window.widget )
  {
    if (flipShown)
    {
       // fade in the info button
      if (animation.timer != null)
      {
        clearInterval (animation.timer);
        animation.timer = null;
      }

      var starttime = (new Date).getTime() - 13;

      animation.duration = 500;
      animation.starttime = starttime;
      animation.firstElement = document.getElementById("flip");
      animation.timer = setInterval ("animate();", 13);
      animation.from = animation.now;
      animation.to = 0.0;
      animate();
      flipShown = false;
    }
  }
}

function animate( )
{
  var T, ease;
  var time = (new Date).getTime();

  T = limit_3(time-animation.starttime, 0, animation.duration);

  if (T >= animation.duration)
  {
    clearInterval (animation.timer);
    animation.timer = null;
    animation.now = animation.to;
  }
  else
  {
    ease = 0.5 - (0.5 * Math.cos(Math.PI * T / animation.duration));
    animation.now = computeNextFloat (animation.from, animation.to, ease);
  }

  animation.firstElement.style.opacity = animation.now;
}

function limit_3( a, b, c )
{
  return a < b ? b : (a > c ? c : a);
}

function computeNextFloat( from, to, ease )
{
  return from + (to - from) * ease;
}

// these functions are called when the info button itself receives onmouseover and onmouseout events

function enterflip( event )
{
  document.getElementById("fliprollie").style.display = "block";
}

function exitflip ( event )
{
  document.getElementById("fliprollie").style.display = "none";
}

// Show the cursor lat and lon as mouse moves out of the map
function latlonCoords( )
{
  if ( document.getElementById("latlonInfo") )
  {
    var latitude = y2lat(event.clientY - 487);
    var longitude = x2lng(event.clientX - 350);
    if ( ( ! isNaN(latitude) ) && ( ! isNaN(longitude) ) )
    {
      if ( ( gPrevLat != latitude ) || ( gPrevLng != longitude ) )
      {
        if ( latitude < -90 )
          latitude = -90;
        else if ( latitude > 90 )
          latitude = 90;
        if ( longitude < -180 )
          longitude = -180;
        else if ( longitude > 180 )
          longitude = 180;
        var cursor = latitude.toFixed(5) + "&deg;,&nbsp;" + longitude.toFixed(5) + "&deg;";
        document.getElementById("latlonInfo").innerHTML = cursor;
        gPrevLat = latitude;
        gPrevLng = longitude;
      }
    }
    else
    {
      cursor += "&ndash;&ndash;.&ndash;&ndash;&ndash;&ndash;&ndash;&ndash;, &ndash;&ndash;.&ndash;&ndash;&ndash;&ndash;&ndash;&ndash;";
      document.getElementById("latlonInfo").innerHTML = cursor;
    }
  }
}

// Clear cursor lat and lon as mouse moves out of the map
function clearCoords( )
{
  if ( document.getElementById("latlonInfo") )
  {
    var cursor = "&ndash;&ndash;.&ndash;&ndash;&ndash;&ndash;&ndash;&ndash;, &ndash;&ndash;.&ndash;&ndash;&ndash;&ndash;&ndash;&ndash;";
    document.getElementById("latlonInfo").innerHTML = cursor;
  }
  gPrevLat = 0;
  gPrevLng = 0;
}

//
// Debug
//

var debugMode = false;

// Write to the debug div when in Safari.
// Send a simple alert to Console when in Dashboard.
function debug( msg )
{
  if ( debugMode == true )
  {
    if ( window.widget )
      alert(msg);
    else
    {
      var debugDiv = document.getElementById("debugDiv");
      debugDiv.appendChild(document.createTextNode(msg));
      debugDiv.appendChild(document.createElement("br"));
      debugDiv.scrollTop = debugDiv.scrollHeight;
    }
  }
}

// Toggle the debugMode flag, but only show the debugDiv in Safari
function toggleDebug( )
{
  debugMode = !debugMode;
  if ( (debugMode == true) && !window.widget )
    document.getElementById("debugDiv").style.display = "block";
  else
    document.getElementById("debugDiv").style.display = "none";
}


// Solar Eclipse Calculator

//
// Eclipse Elements
//
// First line -
//  (0) Julian date of maximum eclipse
//  (1) t0 - the TDT hour at which t=0
//  (2) tmin - the lowest allowed value of t
//  (3) tmax - the highest allowed value of t
//  (4) dUTC - the difference between the civilian "GMT" timescale and TDT
//  (5) dT - the difference between UT and TDT
// Second line -
//  (6) X0, X1, X2, X3 - X elements
// Third line -
// (10) Y0, Y1, Y2, Y3 - Y elements
// Fourth line -
// (14) D0, D1, D2 - D elements
// Fifth line -
// (17) M0, M1, M2 - mu elements
// Sixth line -
// (20) L10, L11, L12 - L1 elements
// Seventh line -
// (23) L20, L21, L22 - L2 elements
// Eigth line -
// (26) tan f1
// (27) tan f2
//
// (28) Google Maps URL
// (29) Google Earth KMZ file
//

var elements = new Array(
//1970 Mar 7
2440653.235, 18.0, -3.0, 3.0,   40.4,   40.4,
   -0.03258900,   0.50545257,  -0.00002270,  -0.00008160,
    0.49145600,   0.27499720,  -0.00000080,  -0.00004640,
   -5.23252010,   0.01554100,   0.00000100,
   87.22515869,  15.00374031,   0.00000000,
    0.53945303,   0.00006010,  -0.00001270,
   -0.00665200,   0.00005980,  -0.00001260,
    0.00471040,   0.00468690,
"+19700307&Acc=2&Umb=1&Lmt=1&Mag=0&dT=40.4", "TSE_1970_03_07.kmz",
//1970 Aug 31
2440830.414, 22.0, -3.0, 3.0,   40.8,   40.8,
   -0.21532001,   0.44769949,  -0.00001160,  -0.00004930,
   -0.49274400,  -0.23453270,  -0.00002420,   0.00002750,
    8.54804039,  -0.01448500,  -0.00000200,
  149.93722534,  15.00432968,   0.00000000,
    0.56757599,  -0.00001620,  -0.00000970,
    0.02133100,  -0.00001610,  -0.00000970,
    0.00463370,   0.00461060,
"+19700831&Acc=2&Umb=1&Lmt=1&Mag=0&dT=40.8", "ASE_1970_08_31.kmz",
//1971 Feb 25
2441007.901, 10.0, -3.0, 3.0,   41.3,   41.3,
   -0.32150701,   0.51789367,  -0.00000410,  -0.00008660,
    1.09239399,   0.26550749,  -0.00000510,  -0.00004660,
   -9.26004028,   0.01480200,   0.00000200,
  326.69076538,  15.00288010,   0.00000000,
    0.53716397,  -0.00004130,  -0.00001300,
   -0.00892900,  -0.00004110,  -0.00001300,
    0.00472280,   0.00469930,
"+19710225&Acc=2&Umb=1&Lmt=1&Mag=0&dT=41.3", "PSE_1971_02_25.kmz",
//1971 Jul 22
2441154.897, 10.0, -3.0, 3.0,   41.8,   41.8,
    0.68553901,   0.50543481,  -0.00008310,  -0.00006390,
    1.37127304,  -0.15726250,  -0.00018100,   0.00002160,
   20.36965942,  -0.00779900,  -0.00000400,
  328.41455078,  15.00082016,   0.00000000,
    0.55451798,   0.00010070,  -0.00001050,
    0.00833900,   0.00010020,  -0.00001050,
    0.00460210,   0.00457920,
"+19710722&Acc=2&Umb=1&Lmt=1&Mag=0&dT=41.8", "PSE_1971_07_22.kmz",
//1971 Aug 20
2441184.444, 23.0, -3.0, 3.0,   41.9,   41.9,
   -0.38978899,   0.46392801,  -0.00002560,  -0.00005400,
   -1.21714795,  -0.22285859,  -0.00001140,   0.00002740,
   12.42899990,  -0.01321400,  -0.00000300,
  164.15951538,  15.00360966,   0.00000000,
    0.56229699,   0.00007560,  -0.00001000,
    0.01607900,   0.00007520,  -0.00001000,
    0.00462190,   0.00459890,
"+19710820&Acc=2&Umb=1&Lmt=1&Mag=0&dT=41.9", "PSE_1971_08_20.kmz",
//1972 Jan 16
2441332.961, 11.0, -3.0, 3.0,   42.3,   42.3,
    0.23215500,   0.52077079,  -0.00003420,  -0.00007120,
   -0.90779197,   0.15136750,   0.00018800,  -0.00002200,
  -21.05788994,   0.00739400,   0.00000500,
  342.61105347,  14.99773026,   0.00000000,
    0.55647802,  -0.00012140,  -0.00001140,
    0.01028800,  -0.00012080,  -0.00001130,
    0.00475370,   0.00473010,
"+19720116&Acc=2&Umb=1&Lmt=1&Mag=0&dT=42.3", "ASE_1972_01_16.kmz",
//1972 Jul 10
2441509.324, 20.0, -3.0, 3.0,   42.8,   42.8,
    0.28179699,   0.54694629,  -0.00006470,  -0.00008290,
    0.63914198,  -0.13100550,  -0.00017900,   0.00002150,
   22.14701080,  -0.00514000,  -0.00000500,
  118.66390228,  14.99997997,   0.00000000,
    0.53946501,   0.00010210,  -0.00001190,
   -0.00663900,   0.00010160,  -0.00001180,
    0.00459880,   0.00457590,
"+19720710&Acc=2&Umb=1&Lmt=1&Mag=0&dT=42.8", "TSE_1972_07_10.kmz",
//1973 Jan 4
2441687.157, 16.0, -3.0, 3.0,   43.4,   43.4,
    0.16819701,   0.50076550,  -0.00002600,  -0.00005810,
   -0.23491099,   0.10499610,   0.00016070,  -0.00001340,
  -22.68857002,   0.00422700,   0.00000600,
   58.72660065,  14.99662018,   0.00000000,
    0.57126302,  -0.00008140,  -0.00001020,
    0.02500000,  -0.00008100,  -0.00001010,
    0.00475630,   0.00473260,
"+19730104&Acc=2&Umb=1&Lmt=1&Mag=0&dT=43.4", "ASE_1973_01_04.kmz",
//1973 Jun 30
2441863.985, 12.0, -3.0, 3.0,   43.8,   43.8,
    0.19178900,   0.57546759,  -0.00004080,  -0.00009740,
   -0.11111100,  -0.09466380,  -0.00015800,   0.00001750,
   23.16778946,  -0.00232900,  -0.00000500,
  359.11322021,  14.99942970,   0.00000000,
    0.53058898,   0.00001900,  -0.00001280,
   -0.01547100,   0.00001890,  -0.00001270,
    0.00459820,   0.00457530,
"+19730630&Acc=2&Umb=1&Lmt=1&Mag=0&dT=43.8", "TSE_1973_06_30.kmz",
//1973 Dec 24
2442041.127, 15.0, -3.0, 3.0,   44.3,   44.3,
   -0.07312300,   0.49988991,  -0.00002010,  -0.00005550,
    0.41127700,   0.06085120,   0.00013950,  -0.00000790,
  -23.41661072,   0.00070800,   0.00000600,
   45.08675003,  14.99615002,   0.00000000,
    0.57516003,   0.00002670,  -0.00000990,
    0.02887700,   0.00002660,  -0.00000980,
    0.00475520,   0.00473150,
"+19731224&Acc=2&Umb=1&Lmt=1&Mag=0&dT=44.3", "ASE_1973_12_24.kmz",
//1974 Jun 20
2442218.700, 5.0, -3.0, 3.0,   44.9,   44.9,
    0.04381400,   0.57430023,  -0.00000560,  -0.00009410,
   -0.83066499,  -0.04926460,  -0.00012050,   0.00000940,
   23.43549919,   0.00056700,  -0.00000600,
  254.66212463,  14.99921989,   0.00000000,
    0.53338897,  -0.00007640,  -0.00001250,
   -0.01268500,  -0.00007600,  -0.00001240,
    0.00460050,   0.00457760,
"+19740620&Acc=2&Umb=1&Lmt=1&Mag=0&dT=44.9", "TSE_1974_06_20.kmz",
//1974 Dec 13
2442395.176, 16.0, -3.0, 3.0,   45.4,   45.4,
   -0.15130401,   0.52346951,  -0.00001600,  -0.00006520,
    1.07530797,   0.01739980,   0.00011450,  -0.00000300,
  -23.15629959,  -0.00282700,   0.00000600,
   61.46255112,  14.99647999,   0.00000000,
    0.56476498,   0.00011430,  -0.00001070,
    0.01853400,   0.00011370,  -0.00001060,
    0.00475040,   0.00472670,
"+19741213&Acc=2&Umb=1&Lmt=1&Mag=0&dT=45.4", "PSE_1974_12_13.kmz",
//1975 May 11
2442543.804, 7.0, -3.0, 3.0,   45.8,   45.8,
   -0.33642799,   0.52215040,   0.00004950,  -0.00006690,
    1.02199996,   0.09154180,  -0.00015040,  -0.00001120,
   17.73483086,   0.01059300,  -0.00000400,
  285.91113281,  15.00166035,   0.00000000,
    0.55560702,  -0.00010870,  -0.00001060,
    0.00942200,  -0.00010820,  -0.00001060,
    0.00462990,   0.00460690,
"+19750511&Acc=2&Umb=1&Lmt=1&Mag=0&dT=45.8", "PSE_1975_05_11.kmz",
//1975 Nov 3
2442720.053, 13.0, -3.0, 3.0,   46.4,   46.4,
   -0.37404200,   0.55952722,   0.00003070,  -0.00009080,
   -0.96607900,  -0.12643839,   0.00015740,   0.00001950,
  -14.96477032,  -0.01276200,   0.00000300,
   19.09967041,  15.00144958,   0.00000000,
    0.54037303,   0.00008900,  -0.00001260,
   -0.00573600,   0.00008850,  -0.00001260,
    0.00471330,   0.00468980,
"+19751103&Acc=2&Umb=1&Lmt=1&Mag=0&dT=46.4", "PSE_1975_11_03.kmz",
//1976 Apr 29
2442897.934, 10.0, -3.0, 3.0,   46.8,   46.8,
   -0.27503201,   0.49430400,   0.00003470,  -0.00005580,
    0.28392601,   0.11243640,  -0.00009300,  -0.00001210,
   14.56363964,   0.01261900,  -0.00000300,
  330.67230225,  15.00265026,   0.00000000,
    0.56739402,  -0.00003440,  -0.00000980,
    0.02115100,  -0.00003420,  -0.00000970,
    0.00464280,   0.00461960,
"+19760429&Acc=2&Umb=1&Lmt=1&Mag=0&dT=46.8", "ASE_1976_04_29.kmz",
//1976 Oct 23
2443074.718, 5.0, -3.0, 3.0,   47.3,   47.3,
   -0.21339600,   0.56328303,   0.00003370,  -0.00009580,
   -0.28151399,  -0.15026081,   0.00009020,   0.00002470,
  -11.44277000,  -0.01423300,   0.00000200,
  258.90966797,  15.00282955,   0.00000000,
    0.53574198,  -0.00001090,  -0.00001300,
   -0.01034400,  -0.00001090,  -0.00001300,
    0.00469980,   0.00467640,
"+19761023&Acc=2&Umb=1&Lmt=1&Mag=0&dT=47.3", "TSE_1976_10_23.kmz",
//1977 Apr 18
2443251.939, 11.0, -3.0, 3.0,   47.9,   47.9,
    0.33826199,   0.49262390,  -0.00000410,  -0.00005670,
   -0.32183799,   0.13328400,  -0.00005050,  -0.00001470,
   10.86802959,   0.01420000,  -0.00000200,
  345.16647339,  15.00354004,   0.00000000,
    0.56643301,   0.00004990,  -0.00001000,
    0.02019400,   0.00004970,  -0.00000990,
    0.00465650,   0.00463330,
"+19770418&Acc=2&Umb=1&Lmt=1&Mag=0&dT=47.9", "ASE_1977_04_18.kmz",
//1977 Oct 12
2443429.352, 20.0, -3.0, 3.0,   48.4,   48.4,
   -0.13762200,   0.54020309,   0.00003330,  -0.00008300,
    0.44132701,  -0.16101509,   0.00001800,   0.00002390,
   -7.58560991,  -0.01522500,   0.00000100,
  123.39025116,  15.00387001,   0.00000000,
    0.54330802,  -0.00009000,  -0.00001210,
   -0.00281600,  -0.00008960,  -0.00001210,
    0.00468600,   0.00466270,
"+19771012&Acc=2&Umb=1&Lmt=1&Mag=0&dT=48.4", "TSE_1977_10_12.kmz",
//1978 Apr 7
2443606.128, 15.0, -3.0, 3.0,   48.9,   48.9,
    0.28864300,   0.51485878,  -0.00001760,  -0.00006890,
   -1.07041299,   0.15584759,   0.00000340,  -0.00002040,
    6.84699011,   0.01528300,  -0.00000200,
   44.45846939,  15.00419044,   0.00000000,
    0.55396003,   0.00011720,  -0.00001100,
    0.00778400,   0.00011670,  -0.00001100,
    0.00467050,   0.00464730,
"+19780407&Acc=2&Umb=1&Lmt=1&Mag=0&dT=48.9", "PSE_1978_04_07.kmz",
//1978 Oct 2
2443783.770, 6.0, -3.0, 3.0,   49.4,   49.4,
    0.11055200,   0.50530899,   0.00001460,  -0.00006490,
    1.18390298,  -0.16086040,  -0.00003930,   0.00001980,
   -3.44973993,  -0.01576000,   0.00000100,
  272.61926270,  15.00454044,   0.00000000,
    0.55766201,  -0.00009950,  -0.00001070,
    0.01146700,  -0.00009900,  -0.00001070,
    0.00467210,   0.00464880,
"+19781002&Acc=2&Umb=1&Lmt=1&Mag=0&dT=49.4", "PSE_1978_10_02.kmz",
//1979 Feb 26
2443931.205, 17.0, -3.0, 3.0,   49.7,   49.7,
   -0.20600200,   0.55702728,  -0.00001020,  -0.00009350,
    0.87545103,   0.16251630,   0.00000390,  -0.00002640,
   -8.75745964,   0.01517600,   0.00000200,
   71.75305939,  15.00310993,   0.00000000,
    0.53787899,   0.00004140,  -0.00001300,
   -0.00821800,   0.00004110,  -0.00001290,
    0.00472150,   0.00469800,
"+19790226&Acc=2&Umb=1&Lmt=1&Mag=0&dT=49.7", "TSE_1979_02_26.kmz",
//1979 Aug 22
2444108.224, 17.0, -3.0, 3.0,   50.2,   50.2,
   -0.42897499,   0.48865560,  -0.00000310,  -0.00005470,
   -0.88320202,  -0.12830280,  -0.00002930,   0.00001370,
   11.82268047,  -0.01367800,  -0.00000300,
   74.26717377,  15.00380993,   0.00000000,
    0.56705999,   0.00002140,  -0.00000970,
    0.02081800,   0.00002130,  -0.00000970,
    0.00462390,   0.00460090,
"+19790822&Acc=2&Umb=1&Lmt=1&Mag=0&dT=50.2", "ASE_1979_08_22.kmz",
//1980 Feb 16
2444285.871, 9.0, -3.0, 3.0,   50.6,   50.6,
    0.00102400,   0.56041688,  -0.00001240,  -0.00009310,
    0.22978801,   0.14254691,   0.00007350,  -0.00002280,
  -12.56628036,   0.01400700,   0.00000300,
  311.45928955,  15.00195026,   0.00000000,
    0.53932601,  -0.00006220,  -0.00001290,
   -0.00677800,  -0.00006190,  -0.00001280,
    0.00473260,   0.00470910,
"+19800216&Acc=2&Umb=1&Lmt=1&Mag=0&dT=50.6", "TSE_1980_02_16.kmz",
//1980 Aug 10
2444462.300, 19.0, -3.0, 3.0,   51.1,   51.1,
   -0.14559400,   0.51036757,  -0.00002790,  -0.00006270,
   -0.16445500,  -0.11048350,  -0.00007830,   0.00001290,
   15.35354042,  -0.01204400,  -0.00000300,
  103.69719696,  15.00288010,   0.00000000,
    0.55835700,   0.00010530,  -0.00001030,
    0.01215900,   0.00010470,  -0.00001030,
    0.00461400,   0.00459100,
"+19800810&Acc=2&Umb=1&Lmt=1&Mag=0&dT=51.1", "ASE_1980_08_10.kmz",
//1981 Feb 4
2444640.423, 22.0, -3.0, 3.0,   51.5,   51.5,
    0.01344600,   0.53927892,  -0.00000570,  -0.00007750,
   -0.49118501,   0.11136020,   0.00013520,  -0.00001510,
  -16.03495026,   0.01230600,   0.00000400,
  146.49736023,  15.00049019,   0.00000000,
    0.55202502,  -0.00011760,  -0.00001170,
    0.00585800,  -0.00011700,  -0.00001160,
    0.00474230,   0.00471870,
"+19810204&Acc=2&Umb=1&Lmt=1&Mag=0&dT=51.5", "ASE_1981_02_04.kmz",
//1981 Jul 31
2444816.657, 4.0, -3.0, 3.0,   51.9,   51.9,
    0.21525300,   0.54793638,  -0.00004560,  -0.00008030,
    0.55176699,  -0.08917380,  -0.00014110,   0.00001240,
   18.30328941,  -0.01003600,  -0.00000400,
  238.42109680,  15.00187016,   0.00000000,
    0.54299301,   0.00011140,  -0.00001160,
   -0.00312900,   0.00011080,  -0.00001150,
    0.00460610,   0.00458320,
"+19810731&Acc=2&Umb=1&Lmt=1&Mag=0&dT=51.9", "TSE_1981_07_31.kmz",
//1982 Jan 25
2444994.696, 5.0, -3.0, 3.0,   52.3,   52.3,
    0.32499701,   0.51230949,  -0.00001700,  -0.00006180,
   -1.19656396,   0.07533980,   0.00017720,  -0.00000820,
  -19.03972054,   0.01001400,   0.00000500,
  251.93632507,  14.99890041,   0.00000000,
    0.56792402,  -0.00010190,  -0.00001040,
    0.02167700,  -0.00010140,  -0.00001040,
    0.00475010,   0.00472640,
"+19820125&Acc=2&Umb=1&Lmt=1&Mag=0&dT=52.3", "PSE_1982_01_25.kmz",
//1982 Jun 21
2445142.003, 12.0, -3.0, 3.0,   52.6,   52.6,
    0.07337400,   0.58126402,   0.00001210,  -0.00009900,
   -1.20875704,   0.05667380,  -0.00009920,  -0.00001090,
   23.44343948,  -0.00007000,  -0.00000600,
  359.59048462,  14.99923992,   0.00000000,
    0.53014201,   0.00000110,  -0.00001280,
   -0.01591600,   0.00000100,  -0.00001280,
    0.00460000,   0.00457710,
"+19820621&Acc=2&Umb=1&Lmt=1&Mag=0&dT=52.6", "PSE_1982_06_21.kmz",
//1982 Jul 20
2445171.281, 19.0, -3.0, 3.0,   52.7,   52.7,
    0.27990600,   0.57789010,  -0.00003700,  -0.00009690,
    1.26646698,  -0.06000160,  -0.00021320,   0.00000930,
   20.61553955,  -0.00772000,  -0.00000400,
  103.42675781,  15.00088024,   0.00000000,
    0.53170800,   0.00004360,  -0.00001270,
   -0.01435700,   0.00004340,  -0.00001260,
    0.00460080,   0.00457790,
"+19820720&Acc=2&Umb=1&Lmt=1&Mag=0&dT=52.7", "PSE_1982_07_20.kmz",
//1982 Dec 15
2445318.897, 10.0, -3.0, 3.0,   53.0,   53.0,
    0.40209100,   0.50094628,   0.00000050,  -0.00005650,
    1.08119798,  -0.07597220,   0.00011160,   0.00000980,
  -23.26392937,  -0.00201900,   0.00000600,
  331.24942017,  14.99633026,   0.00000000,
    0.57327700,   0.00004610,  -0.00001000,
    0.02700400,   0.00004580,  -0.00001000,
    0.00475180,   0.00472810,
"+19821215&Acc=2&Umb=1&Lmt=1&Mag=0&dT=53.0", "PSE_1982_12_15.kmz",
//1983 Jun 11
2445496.697, 5.0, -3.0, 3.0,   53.4,   53.4,
    0.24025901,   0.56096530,   0.00003000,  -0.00008860,
   -0.45982301,   0.09958330,  -0.00013400,  -0.00001710,
   23.04494095,   0.00283400,  -0.00000600,
  255.14927673,  14.99936008,   0.00000000,
    0.53645003,  -0.00009960,  -0.00001220,
   -0.00963900,  -0.00009910,  -0.00001210,
    0.00460450,   0.00458150,
"+19830611&Acc=2&Umb=1&Lmt=1&Mag=0&dT=53.4", "TSE_1983_06_11.kmz",
//1983 Dec 4
2445673.022, 13.0, -3.0, 3.0,   53.7,   53.7,
    0.34178901,   0.51896453,   0.00000380,  -0.00006760,
    0.33128399,  -0.12362550,   0.00013730,   0.00001760,
  -22.20572090,  -0.00537000,   0.00000600,
   17.49019051,  14.99719048,   0.00000000,
    0.56003398,   0.00011000,  -0.00001100,
    0.01382700,   0.00010940,  -0.00001100,
    0.00474480,   0.00472120,
"+19831204&Acc=2&Umb=1&Lmt=1&Mag=0&dT=53.7", "ASE_1983_12_04.kmz",
//1984 May 30
2445851.198, 17.0, -3.0, 3.0,   54.0,   54.0,
    0.05601100,   0.52088928,   0.00005120,  -0.00006920,
    0.29867199,   0.13301229,  -0.00015060,  -0.00001920,
   21.86890030,   0.00569500,  -0.00000500,
   75.61669922,  14.99985981,   0.00000000,
    0.55108398,  -0.00012500,  -0.00001090,
    0.00492200,  -0.00012440,  -0.00001080,
    0.00461160,   0.00458860,
"+19840530&Acc=2&Umb=1&Lmt=1&Mag=0&dT=54.0", "ASE_1984_05_30.kmz",
//1984 Nov 22
2446027.454, 23.0, -3.0, 3.0,   54.3,   54.3,
   -0.04324900,   0.54060382,   0.00003250,  -0.00008420,
   -0.31485900,  -0.17163490,   0.00015930,   0.00002840,
  -20.32707024,  -0.00828800,   0.00000500,
  168.41831970,  14.99853039,   0.00000000,
    0.54429102,   0.00009640,  -0.00001240,
   -0.00183800,   0.00009590,  -0.00001230,
    0.00473520,   0.00471160,
"+19841122&Acc=2&Umb=1&Lmt=1&Mag=0&dT=54.3", "TSE_1984_11_22.kmz",
//1985 May 19
2446205.396, 21.0, -3.0, 3.0,   54.6,   54.6,
   -0.57546300,   0.48482391,   0.00006910,  -0.00005530,
    0.93886298,   0.16021270,  -0.00015240,  -0.00001980,
   19.89410973,   0.00840400,  -0.00000500,
  135.88954163,  15.00069046,   0.00000000,
    0.56446803,  -0.00005250,  -0.00000990,
    0.01823900,  -0.00005220,  -0.00000980,
    0.00462120,   0.00459820,
"+19850519&Acc=2&Umb=1&Lmt=1&Mag=0&dT=54.6", "PSE_1985_05_19.kmz",
//1985 Nov 12
2446382.091, 14.0, -3.0, 3.0,   54.8,   54.8,
   -0.45631000,   0.54434079,   0.00007060,  -0.00009210,
   -0.87380499,  -0.21001160,   0.00017000,   0.00003750,
  -17.77672958,  -0.01071500,   0.00000400,
   33.95471954,  15.00004005,   0.00000000,
    0.53676897,   0.00001190,  -0.00001310,
   -0.00932200,   0.00001180,  -0.00001300,
    0.00472400,   0.00470040,
"+19851112&Acc=2&Umb=1&Lmt=1&Mag=0&dT=54.8", "TSE_1985_11_12.kmz",
//1986 Apr 9
2446529.765, 6.0, -3.0, 3.0,   55.0,   55.0,
    0.34347799,   0.45629579,  -0.00000640,  -0.00005340,
   -1.04254603,   0.24137659,   0.00000000,  -0.00003010,
    7.48053980,   0.01493900,  -0.00000200,
  269.57122803,  15.00397968,   0.00000000,
    0.56414098,   0.00008970,  -0.00001020,
    0.01791400,   0.00008930,  -0.00001010,
    0.00466900,   0.00464580,
"+19860409&Acc=2&Umb=1&Lmt=1&Mag=0&dT=55.0", "PSE_1986_04_09.kmz",
//1986 Oct 3
2446707.296, 19.0, -3.0, 3.0,   55.2,   55.2,
    0.42664501,   0.48638749,   0.00000560,  -0.00007030,
    0.89859098,  -0.26658240,  -0.00002940,   0.00004030,
   -4.06904984,  -0.01545800,   0.00000100,
  107.74845886,  15.00440979,   0.00000000,
    0.54658300,  -0.00011010,  -0.00001170,
    0.00044300,  -0.00010950,  -0.00001170,
    0.00467350,   0.00465020,
"+19861003&Acc=2&Umb=1&Lmt=1&Mag=0&dT=55.2", "HSE_1986_10_03.kmz",
//1987 Mar 29
2446884.035, 13.0, -3.0, 3.0,   55.4,   55.4,
    0.22913501,   0.47956261,  -0.00001680,  -0.00006670,
   -0.22226299,   0.26463541,  -0.00001340,  -0.00003880,
    3.29555011,   0.01560400,  -0.00000100,
   13.76953030,  15.00430965,   0.00000000,
    0.55025101,   0.00011280,  -0.00001150,
    0.00409300,   0.00011230,  -0.00001140,
    0.00468330,   0.00466000,
"+19870329&Acc=2&Umb=1&Lmt=1&Mag=0&dT=55.4", "HSE_1987_03_29.kmz",
//1987 Sep 23
2447061.634, 3.0, -3.0, 3.0,   55.6,   55.6,
    0.04200800,   0.45559469,   0.00001020,  -0.00005500,
    0.29572800,  -0.25436291,  -0.00001890,   0.00003240,
    0.17405000,  -0.01560800,   0.00000000,
  226.83679199,  15.00475979,   0.00000000,
    0.56106901,  -0.00009200,  -0.00001040,
    0.01485700,  -0.00009150,  -0.00001030,
    0.00465960,   0.00463640,
"+19870923&Acc=2&Umb=1&Lmt=1&Mag=0&dT=55.6", "ASE_1987_09_23.kmz",
//1988 Mar 18
2447238.583, 2.0, -3.0, 3.0,   55.9,   55.9,
   -0.19467901,   0.50395763,  -0.00000070,  -0.00008190,
    0.37094000,   0.28034660,  -0.00001930,  -0.00004760,
   -0.91812998,   0.01579700,   0.00000000,
  207.96847534,  15.00426006,   0.00000000,
    0.53823400,   0.00006380,  -0.00001270,
   -0.00786400,   0.00006350,  -0.00001270,
    0.00469700,   0.00467360,
"+19880318&Acc=2&Umb=1&Lmt=1&Mag=0&dT=55.9", "TSE_1988_03_18.kmz",
//1988 Sep 11
2447415.698, 5.0, -3.0, 3.0,   56.1,   56.1,
   -0.11086500,   0.44259560,  -0.00000580,  -0.00004860,
   -0.47318000,  -0.24311569,  -0.00000410,   0.00002840,
    4.48112011,  -0.01527400,  -0.00000100,
  255.84582520,  15.00471973,   0.00000000,
    0.56848300,  -0.00001320,  -0.00000970,
    0.02223400,  -0.00001320,  -0.00000970,
    0.00464590,   0.00462280,
"+19880911&Acc=2&Umb=1&Lmt=1&Mag=0&dT=56.1", "ASE_1988_09_11.kmz",
//1989 Mar 7
2447593.256, 18.0, -3.0, 3.0,   56.4,   56.4,
   -0.59674698,   0.51151341,   0.00002300,  -0.00008530,
    0.92568600,   0.27690780,  -0.00002170,  -0.00004840,
   -5.08024979,   0.01555600,   0.00000100,
   87.25440216,  15.00378036,   0.00000000,
    0.53672099,  -0.00003370,  -0.00001300,
   -0.00937000,  -0.00003350,  -0.00001290,
    0.00471020,   0.00468670,
"+19890307&Acc=2&Umb=1&Lmt=1&Mag=0&dT=56.4", "PSE_1989_03_07.kmz",
//1989 Aug 31
2447769.730, 6.0, -3.0, 3.0,   56.7,   56.7,
   -0.33568799,   0.45761240,  -0.00001960,  -0.00005350,
   -1.17003095,  -0.23831220,   0.00000870,   0.00002940,
    8.64247036,  -0.01444700,  -0.00000200,
  269.90951538,  15.00434017,   0.00000000,
    0.56232601,   0.00007800,  -0.00001010,
    0.01610800,   0.00007770,  -0.00001010,
    0.00463280,   0.00460980,
"+19890831&Acc=2&Umb=1&Lmt=1&Mag=0&dT=56.7", "PSE_1989_08_31.kmz",
//1990 Jan 26
2447918.313, 20.0, -3.0, 3.0,   56.9,   56.9,
    0.56778198,   0.50742018,  -0.00005080,  -0.00006860,
   -0.79894900,   0.18643750,   0.00016130,  -0.00002670,
  -18.62072945,   0.01014600,   0.00000400,
  116.84973907,  14.99911022,   0.00000000,
    0.55694902,  -0.00013390,  -0.00001130,
    0.01075700,  -0.00013320,  -0.00001120,
    0.00474880,   0.00472510,
"+19900126&Acc=2&Umb=1&Lmt=1&Mag=0&dT=56.9", "ASE_1990_01_26.kmz",
//1990 Jul 22
2448094.627, 3.0, -3.0, 3.0,   57.3,   57.3,
    0.19994600,   0.53828198,  -0.00006690,  -0.00008220,
    0.73351997,  -0.16929629,  -0.00016640,   0.00002770,
   20.34538078,  -0.00779800,  -0.00000500,
  223.39979553,  15.00090981,   0.00000000,
    0.53878498,   0.00010620,  -0.00001190,
   -0.00731600,   0.00010560,  -0.00001190,
    0.00460170,   0.00457880,
"+19900722&Acc=2&Umb=1&Lmt=1&Mag=0&dT=57.3", "TSE_1990_07_22.kmz",
//1991 Jan 15
2448272.496, 0.0, -3.0, 3.0,   57.6,   57.6,
    0.12669100,   0.49010649,  -0.00003300,  -0.00005630,
   -0.24713200,   0.14324540,   0.00014570,  -0.00001790,
  -21.07114983,   0.00739100,   0.00000500,
  177.63291931,  14.99763966,   0.00000000,
    0.57167602,  -0.00007540,  -0.00001020,
    0.02541100,  -0.00007500,  -0.00001010,
    0.00475420,   0.00473060,
"+19910115&Acc=2&Umb=1&Lmt=1&Mag=0&dT=57.6", "ASE_1991_01_15.kmz",
//1991 Jul 11
2448449.297, 19.0, -3.0, 3.0,   58.0,   58.0,
   -0.06725900,   0.56713760,  -0.00003690,  -0.00009610,
    0.01212700,  -0.13797720,  -0.00015290,   0.00002500,
   22.09742928,  -0.00522000,  -0.00000500,
  103.63977814,  15.00006008,   0.00000000,
    0.53041399,   0.00002520,  -0.00001280,
   -0.01564500,   0.00002510,  -0.00001270,
    0.00459860,   0.00457570,
"+19910711&Acc=2&Umb=1&Lmt=1&Mag=0&dT=58.0", "TSE_1991_07_11.kmz",
//1992 Jan 4
2448626.462, 23.0, -3.0, 3.0,   58.4,   58.4,
   -0.12922300,   0.49348110,  -0.00003040,  -0.00005480,
    0.39099500,   0.10225830,   0.00013210,  -0.00001260,
  -22.72167015,   0.00413200,   0.00000600,
  163.77447510,  14.99658012,   0.00000000,
    0.57502598,   0.00003210,  -0.00000990,
    0.02874400,   0.00003200,  -0.00000990,
    0.00475630,   0.00473260,
"+19920104&Acc=2&Umb=1&Lmt=1&Mag=0&dT=58.4", "ASE_1992_01_04.kmz",
//1992 Jun 30
2448804.008, 12.0, -3.0, 3.0,   58.7,   58.7,
   -0.23040099,   0.56738228,  -0.00000380,  -0.00009210,
   -0.72324997,  -0.09407900,  -0.00012280,   0.00001670,
   23.14089966,  -0.00244500,  -0.00000600,
  359.08343506,  14.99942970,   0.00000000,
    0.53385502,  -0.00007130,  -0.00001240,
   -0.01222100,  -0.00007090,  -0.00001240,
    0.00459840,   0.00457550,
"+19920630&Acc=2&Umb=1&Lmt=1&Mag=0&dT=58.7", "TSE_1992_06_30.kmz",
//1992 Dec 24
2448980.522, 1.0, -3.0, 3.0,   59.1,   59.1,
    0.12051400,   0.52160692,  -0.00003970,  -0.00006530,
    1.09276998,   0.06171780,   0.00011410,  -0.00000880,
  -23.41921997,   0.00064300,   0.00000700,
  195.11781311,  14.99621010,   0.00000000,
    0.56433100,   0.00010120,  -0.00001070,
    0.01810200,   0.00010070,  -0.00001070,
    0.00475450,   0.00473090,
"+19921224&Acc=2&Umb=1&Lmt=1&Mag=0&dT=59.1", "PSE_1992_12_24.kmz",
//1993 May 21
2449129.097, 14.0, -3.0, 3.0,   59.4,   59.4,
   -0.30414200,   0.52511013,   0.00004290,  -0.00006670,
    1.11016095,   0.05911710,  -0.00017390,  -0.00000700,
   20.25684929,   0.00822100,  -0.00000500,
   30.86197090,  15.00061989,   0.00000000,
    0.55585802,  -0.00010480,  -0.00001050,
    0.00967200,  -0.00010430,  -0.00001050,
    0.00461950,   0.00459650,
"+19930521&Acc=2&Umb=1&Lmt=1&Mag=0&dT=59.4", "PSE_1993_05_21.kmz",
//1993 Nov 13
2449305.407, 22.0, -3.0, 3.0,   59.9,   59.9,
   -0.03945600,   0.56676358,   0.00001330,  -0.00009240,
   -1.04916894,  -0.09547200,   0.00018790,   0.00001450,
  -18.14669037,  -0.01068700,   0.00000400,
  153.90306091,  14.99989986,   0.00000000,
    0.54056603,   0.00007180,  -0.00001270,
   -0.00554400,   0.00007140,  -0.00001260,
    0.00472560,   0.00470200,
"+19931113&Acc=2&Umb=1&Lmt=1&Mag=0&dT=59.9", "PSE_1993_11_13.kmz",
//1994 May 10
2449483.217, 17.0, -3.0, 3.0,   60.3,   60.3,
   -0.17342000,   0.49906290,   0.00002960,  -0.00005630,
    0.38365200,   0.08693930,  -0.00011830,  -0.00000920,
   17.68613052,   0.01064200,  -0.00000400,
   75.90923309,  15.00162029,   0.00000000,
    0.56691301,  -0.00003180,  -0.00000980,
    0.02067200,  -0.00003170,  -0.00000970,
    0.00463080,   0.00460770,
"+19940510&Acc=2&Umb=1&Lmt=1&Mag=0&dT=60.3", "ASE_1994_05_10.kmz",
//1994 Nov 3
2449660.070, 14.0, -3.0, 3.0,   60.7,   60.7,
    0.11255000,   0.56878269,   0.00002070,  -0.00009660,
   -0.38556999,  -0.12578030,   0.00012330,   0.00002050,
  -15.10091019,  -0.01268600,   0.00000300,
   34.10425186,  15.00142002,   0.00000000,
    0.53659701,  -0.00003140,  -0.00001300,
   -0.00949300,  -0.00003120,  -0.00001300,
    0.00471330,   0.00468990,
"+19941103&Acc=2&Umb=1&Lmt=1&Mag=0&dT=60.7", "TSE_1994_11_03.kmz",
//1995 Apr 29
2449837.231, 18.0, -3.0, 3.0,   61.0,   61.0,
    0.29701000,   0.49877340,  -0.00000070,  -0.00005780,
   -0.27902299,   0.11401000,  -0.00007490,  -0.00001260,
   14.48233032,   0.01265900,  -0.00000300,
   90.65738678,  15.00267982,   0.00000000,
    0.56506699,   0.00005580,  -0.00001000,
    0.01883500,   0.00005550,  -0.00000990,
    0.00464330,   0.00462020,
"+19950429&Acc=2&Umb=1&Lmt=1&Mag=0&dT=61.0", "ASE_1995_04_29.kmz",
//1995 Oct 24
2450014.690, 5.0, -3.0, 3.0,   61.4,   61.4,
    0.33002800,   0.54305178,   0.00001820,  -0.00008280,
    0.27634901,  -0.14410999,   0.00005250,   0.00002110,
  -11.58057022,  -0.01419600,   0.00000200,
  258.92837524,  15.00273991,   0.00000000,
    0.54475302,  -0.00011490,  -0.00001210,
   -0.00137800,  -0.00011430,  -0.00001200,
    0.00470030,   0.00467690,
"+19951024&Acc=2&Umb=1&Lmt=1&Mag=0&dT=61.4", "TSE_1995_10_24.kmz",
//1996 Apr 17
2450191.443, 23.0, -3.0, 3.0,   61.8,   61.8,
    0.46804100,   0.52094162,  -0.00001940,  -0.00007050,
   -0.96887398,   0.14228970,  -0.00002450,  -0.00001870,
   10.83629036,   0.01419100,  -0.00000300,
  165.15182495,  15.00360966,   0.00000000,
    0.55227602,   0.00010840,  -0.00001110,
    0.00610800,   0.00010790,  -0.00001100,
    0.00465640,   0.00463320,
"+19960417&Acc=2&Umb=1&Lmt=1&Mag=0&dT=61.8", "PSE_1996_04_17.kmz",
//1996 Oct 12
2450369.085, 14.0, -3.0, 3.0,   62.2,   62.2,
    0.29615900,   0.50603628,   0.00001450,  -0.00006440,
    1.08322501,  -0.15152180,  -0.00001020,   0.00001840,
   -7.63950014,  -0.01523400,   0.00000200,
   33.40581894,  15.00378036,   0.00000000,
    0.55934799,  -0.00010670,  -0.00001070,
    0.01314400,  -0.00010620,  -0.00001060,
    0.00468650,   0.00466320,
"+19961012&Acc=2&Umb=1&Lmt=1&Mag=0&dT=62.2", "PSE_1996_10_12.kmz",
//1997 Mar 9
2450516.559, 1.0, -3.0, 3.0,   62.5,   62.5,
   -0.50502998,   0.55430740,   0.00001340,  -0.00009340,
    0.80380797,   0.17435861,  -0.00002040,  -0.00002850,
   -4.55015993,   0.01586200,   0.00000100,
  192.33604431,  15.00395966,   0.00000000,
    0.53689098,   0.00004860,  -0.00001300,
   -0.00920100,   0.00004840,  -0.00001290,
    0.00470880,   0.00468530,
"+19970309&Acc=2&Umb=1&Lmt=1&Mag=0&dT=62.5", "TSE_1997_03_09.kmz",
//1997 Sep 2
2450693.503, 0.0, -3.0, 3.0,   62.8,   62.8,
   -0.33190000,   0.48463470,  -0.00000260,  -0.00005430,
   -0.98140198,  -0.14306040,  -0.00000310,   0.00001540,
    7.98437977,  -0.01483800,  -0.00000200,
  180.05259705,  15.00450039,   0.00000000,
    0.56764102,   0.00002240,  -0.00000970,
    0.02139600,   0.00002230,  -0.00000970,
    0.00463490,   0.00461180,
"+19970902&Acc=2&Umb=1&Lmt=1&Mag=0&dT=62.8", "PSE_1997_09_02.kmz",
//1998 Feb 26
2450871.229, 17.0, -3.0, 3.0,   63.0,   63.0,
   -0.33884799,   0.55449569,   0.00001030,  -0.00009160,
    0.15050501,   0.16113161,   0.00004940,  -0.00002580,
   -8.60943031,   0.01521500,   0.00000200,
   71.77806091,  15.00312996,   0.00000000,
    0.53915900,  -0.00005210,  -0.00001280,
   -0.00694400,  -0.00005190,  -0.00001280,
    0.00472160,   0.00469810,
"+19980226&Acc=2&Umb=1&Lmt=1&Mag=0&dT=63.0", "TSE_1998_02_26.kmz",
//1998 Aug 22
2451047.588, 2.0, -3.0, 3.0,   63.3,   63.3,
   -0.12743101,   0.50677431,  -0.00002700,  -0.00006280,
   -0.23999999,  -0.13235679,  -0.00005200,   0.00001570,
   11.89284992,  -0.01363700,  -0.00000300,
  209.24456787,  15.00384998,   0.00000000,
    0.55809700,   0.00010750,  -0.00001040,
    0.01190000,   0.00010700,  -0.00001030,
    0.00462290,   0.00459990,
"+19980822&Acc=2&Umb=1&Lmt=1&Mag=0&dT=63.3", "ASE_1998_08_22.kmz",
//1999 Feb 16
2451225.774, 7.0, -3.0, 3.0,   63.5,   63.5,
    0.34195700,   0.53182107,  -0.00001820,  -0.00007590,
   -0.40033099,   0.13612880,   0.00010500,  -0.00001850,
  -12.45960999,   0.01406600,   0.00000300,
  281.47750854,  15.00191021,   0.00000000,
    0.55225098,  -0.00013240,  -0.00001160,
    0.00608200,  -0.00013180,  -0.00001160,
    0.00473320,   0.00470970,
"+19990216&Acc=2&Umb=1&Lmt=1&Mag=0&dT=63.5", "ASE_1999_02_16.kmz",
//1999 Aug 11
2451401.961, 11.0, -3.0, 3.0,   63.7,   63.7,
    0.07004200,   0.54430348,  -0.00004060,  -0.00008060,
    0.50284100,  -0.11849290,  -0.00011580,   0.00001690,
   15.32734013,  -0.01203500,  -0.00000300,
  343.68740845,  15.00298023,   0.00000000,
    0.54246902,   0.00011680,  -0.00001170,
   -0.00365000,   0.00011630,  -0.00001160,
    0.00461290,   0.00459000,
"+19990811&Acc=2&Umb=1&Lmt=1&Mag=0&dT=63.7", "TSE_1999_08_11.kmz",
//2000 Feb 5
2451580.035, 13.0, -3.0, 3.0,   63.9,   63.9,
    0.32955399,   0.50568569,  -0.00002070,  -0.00006050,
   -1.18089199,   0.10520780,   0.00015300,  -0.00001180,
  -16.02865028,   0.01232400,   0.00000400,
   11.51093006,  15.00039959,   0.00000000,
    0.56818300,  -0.00009630,  -0.00001030,
    0.02193600,  -0.00009580,  -0.00001030,
    0.00474330,   0.00471970,
"+20000205&Acc=2&Umb=1&Lmt=1&Mag=0&dT=63.9", "PSE_2000_02_05.kmz",
//2000 Jul 1
2451727.315, 20.0, -3.0, 3.0,   64.0,   64.0,
    0.28072700,   0.58385360,  -0.00001040,  -0.00009950,
   -1.27723205,   0.01061090,  -0.00009230,  -0.00000290,
   23.04426003,  -0.00308400,  -0.00000600,
  119.01207733,  14.99952984,   0.00000000,
    0.53005701,  -0.00001810,  -0.00001280,
   -0.01600000,  -0.00001800,  -0.00001270,
    0.00459810,   0.00457520,
"+20000701&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.0", "PSE_2000_07_01.kmz",
//2000 Jul 31
2451756.593, 2.0, -3.0, 3.0,   64.0,   64.0,
    0.06576000,   0.57378107,  -0.00003150,  -0.00009670,
    1.22255099,  -0.09595570,  -0.00019000,   0.00001540,
   18.21853065,  -0.01008600,  -0.00000400,
  208.41012573,  15.00197983,   0.00000000,
    0.53159600,   0.00005060,  -0.00001270,
   -0.01446900,   0.00005040,  -0.00001260,
    0.00460550,   0.00458260,
"+20000731&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.0", "PSE_2000_07_31.kmz",
//2000 Dec 25
2451904.233, 18.0, -3.0, 3.0,   64.1,   64.1,
    0.27834100,   0.50631279,  -0.00000840,  -0.00005750,
    1.12071705,  -0.03355850,   0.00011200,   0.00000490,
  -23.37237930,   0.00144900,   0.00000700,
   89.90811920,  14.99619961,   0.00000000,
    0.57309198,   0.00005140,  -0.00001000,
    0.02682000,   0.00005110,  -0.00001000,
    0.00475530,   0.00473160,
"+20001225&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.1", "PSE_2000_12_25.kmz",
//2001 Jun 21
2452082.003, 12.0, -3.0, 3.0,   64.2,   64.2,
    0.01034000,   0.56538612,   0.00002920,  -0.00008860,
   -0.57182997,   0.05512560,  -0.00013390,  -0.00000980,
   23.43976974,  -0.00018300,  -0.00000600,
  359.56015015,  14.99919987,   0.00000000,
    0.53697199,  -0.00009440,  -0.00001210,
   -0.00912000,  -0.00009390,  -0.00001210,
    0.00460050,   0.00457750,
"+20010621&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.2", "TSE_2001_06_21.kmz",
//2001 Dec 14
2452258.370, 21.0, -3.0, 3.0,   64.3,   64.3,
    0.12365400,   0.52894193,   0.00000150,  -0.00006980,
    0.39464501,  -0.08130250,   0.00014550,   0.00001210,
  -23.25180054,  -0.00205500,   0.00000600,
  136.27827454,  14.99641037,   0.00000000,
    0.55952901,   0.00011850,  -0.00001110,
    0.01332400,   0.00011790,  -0.00001100,
    0.00475080,   0.00472720,
"+20011214&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.3", "ASE_2001_12_14.kmz",
//2002 Jun 10
2452436.490, 0.0, -3.0, 3.0,   64.4,   64.4,
    0.09389900,   0.52745432,   0.00004030,  -0.00006950,
    0.21901999,   0.09319090,  -0.00015940,  -0.00001360,
   23.05546951,   0.00279400,  -0.00000500,
  180.13342285,  14.99925995,   0.00000000,
    0.55165702,  -0.00012310,  -0.00001080,
    0.00549200,  -0.00012250,  -0.00001070,
    0.00460540,   0.00458240,
"+20020610&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.4", "ASE_2002_06_10.kmz",
//2002 Dec 4
2452612.814, 8.0, -3.0, 3.0,   64.4,   64.4,
    0.18612599,   0.55325001,   0.00001540,  -0.00008700,
   -0.35446101,  -0.13091300,   0.00018070,   0.00002210,
  -22.22649956,  -0.00529700,   0.00000600,
  302.48074341,  14.99726963,   0.00000000,
    0.54416603,   0.00008340,  -0.00001250,
   -0.00196200,   0.00008300,  -0.00001240,
    0.00474370,   0.00472010,
"+20021204&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.4", "TSE_2002_12_04.kmz",
//2003 May 31
2452790.673, 4.0, -3.0, 3.0,   64.5,   64.5,
   -0.32386601,   0.49390131,   0.00005450,  -0.00005630,
    0.94520599,   0.12632860,  -0.00016910,  -0.00001580,
   21.84598923,   0.00574600,  -0.00000500,
  240.61102295,  14.99979019,   0.00000000,
    0.56438500,  -0.00005300,  -0.00000980,
    0.01815700,  -0.00005270,  -0.00000980,
    0.00461260,   0.00458960,
"+20030531&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.5", "ASE_2003_05_31.kmz",
//2003 Nov 23
2452967.452, 23.0, -3.0, 3.0,   64.5,   64.5,
   -0.19797000,   0.55689752,   0.00005700,  -0.00009440,
   -0.94789201,  -0.17392470,   0.00019900,   0.00003130,
  -20.40538979,  -0.00817700,   0.00000500,
  168.39500427,  14.99853039,   0.00000000,
    0.53732800,  -0.00000320,  -0.00001310,
   -0.00876600,  -0.00000320,  -0.00001300,
    0.00473480,   0.00471120,
"+20031123&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.5", "TSE_2003_11_23.kmz",
//2004 Apr 19
2453115.066, 14.0, -3.0, 3.0,   64.6,   64.6,
    0.69318199,   0.46464899,  -0.00001010,  -0.00005490,
   -0.92220002,   0.22851950,  -0.00002590,  -0.00002880,
   11.41963959,   0.01377300,  -0.00000300,
   30.24735069,  15.00335026,   0.00000000,
    0.56262702,   0.00007810,  -0.00001020,
    0.01640800,   0.00007770,  -0.00001020,
    0.00465490,   0.00463170,
"+20040419&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.6", "PSE_2004_04_19.kmz",
//2004 Oct 14
2453292.625, 3.0, -3.0, 3.0,   64.7,   64.7,
    0.47696501,   0.48947239,   0.00001590,  -0.00007010,
    0.91834301,  -0.25634459,  -0.00000620,   0.00003840,
   -8.23845959,  -0.01485900,   0.00000200,
  228.49928284,  15.00360012,   0.00000000,
    0.54824603,  -0.00011410,  -0.00001170,
    0.00209800,  -0.00011350,  -0.00001160,
    0.00468810,   0.00466480,
"+20041014&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.7", "PSE_2004_10_14.kmz",
//2005 Apr 8
2453469.359, 21.0, -3.0, 3.0,   64.8,   64.8,
    0.35021499,   0.48577619,  -0.00001010,  -0.00006830,
   -0.20743699,   0.25757569,  -0.00003670,  -0.00003820,
    7.48628998,   0.01489900,  -0.00000200,
  134.57385254,  15.00403976,   0.00000000,
    0.54854798,   0.00010690,  -0.00001150,
    0.00239900,   0.00010640,  -0.00001150,
    0.00466860,   0.00464540,
"+20050408&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.8", "HSE_2005_04_08.kmz",
//2005 Oct 3
2453646.939, 11.0, -3.0, 3.0,   65.0,   65.0,
    0.36603001,   0.45547909,   0.00000990,  -0.00005450,
    0.17582799,  -0.25080660,   0.00000750,   0.00003170,
   -4.09223986,  -0.01549000,   0.00000100,
  347.75360107,  15.00434017,   0.00000000,
    0.56266099,  -0.00010220,  -0.00001040,
    0.01644100,  -0.00010170,  -0.00001030,
    0.00467410,   0.00465080,
"+20051003&Acc=2&Umb=1&Lmt=1&Mag=0&dT=65.0", "ASE_2005_10_03.kmz",
//2006 Mar 29
2453823.925, 10.0, -3.0, 3.0,   64.9,   64.9,
   -0.28993699,   0.50608802,   0.00001810,  -0.00008270,
    0.27902201,   0.27899179,  -0.00003860,  -0.00004760,
    3.39883995,   0.01555800,  -0.00000100,
  328.79330444,  15.00436974,   0.00000000,
    0.53700203,   0.00006440,  -0.00001270,
   -0.00909000,   0.00006410,  -0.00001270,
    0.00468260,   0.00465930,
"+20060329&Acc=2&Umb=1&Lmt=1&Mag=0&dT=64.9", "TSE_2006_03_29.kmz",
//2006 Sep 22
2454000.987, 12.0, -3.0, 3.0,   65.0,   65.0,
   -0.06066800,   0.44051009,   0.00000280,  -0.00004830,
   -0.43146199,  -0.24612799,   0.00001520,   0.00002870,
    0.26179001,  -0.01562100,   0.00000000,
    1.81218004,  15.00473022,   0.00000000,
    0.56941998,  -0.00000790,  -0.00000970,
    0.02316600,  -0.00000790,  -0.00000970,
    0.00465930,   0.00463610,
"+20060922&Acc=2&Umb=1&Lmt=1&Mag=0&dT=65.0", "ASE_2006_09_22.kmz",
//2007 Mar 19
2454178.606, 3.0, -3.0, 3.0,   65.5,   65.5,
   -0.28989300,   0.50867432,   0.00002180,  -0.00008460,
    1.06554902,   0.28123659,  -0.00005350,  -0.00004900,
   -0.74650002,   0.01579500,   0.00000000,
  223.00271606,  15.00428009,   0.00000000,
    0.53622502,  -0.00005460,  -0.00001290,
   -0.00986400,  -0.00005430,  -0.00001290,
    0.00469660,   0.00467320,
"+20070319&Acc=2&Umb=1&Lmt=1&Mag=0&dT=65.5", "PSE_2007_03_19.kmz",
//2007 Sep 11
2454355.023, 13.0, -3.0, 3.0,   65.7,   65.7,
   -0.33111000,   0.45388380,  -0.00000990,  -0.00005340,
   -1.10170305,  -0.24807690,   0.00002780,   0.00003080,
    4.58238983,  -0.01524400,  -0.00000100,
   15.81803036,  15.00475025,   0.00000000,
    0.56238699,   0.00008300,  -0.00001020,
    0.01616900,   0.00008260,  -0.00001010,
    0.00464490,   0.00462180,
"+20070911&Acc=2&Umb=1&Lmt=1&Mag=0&dT=65.7", "PSE_2007_09_11.kmz",
//2008 Feb 7
2454503.664, 4.0, -3.0, 3.0,   65.6,   65.6,
    0.41244400,   0.49431279,  -0.00004200,  -0.00006600,
   -0.86425298,   0.21449891,   0.00013950,  -0.00003020,
  -15.51263046,   0.01237700,   0.00000300,
  236.47749329,  15.00059986,   0.00000000,
    0.55741698,  -0.00012470,  -0.00001120,
    0.01122300,  -0.00012400,  -0.00001120,
    0.00474170,   0.00471810,
"+20080207&Acc=2&Umb=1&Lmt=1&Mag=0&dT=65.6", "ASE_2008_02_07.kmz",
//2008 Aug 1
2454679.932, 10.0, -3.0, 3.0,   65.8,   65.8,
    0.10176700,   0.52857709,  -0.00006350,  -0.00008140,
    0.85062701,  -0.20252250,  -0.00015120,   0.00003310,
   17.86754036,  -0.01012100,  -0.00000400,
  328.42578125,  15.00201035,   0.00000000,
    0.53823203,   0.00011110,  -0.00001200,
   -0.00786600,   0.00011050,  -0.00001200,
    0.00460650,   0.00458360,
"+20080801&Acc=2&Umb=1&Lmt=1&Mag=0&dT=65.8", "TSE_2008_08_01.kmz",
//2009 Jan 26
2454857.833, 8.0, -3.0, 3.0,   66.3,   66.3,
    0.09959900,   0.47819701,  -0.00003520,  -0.00005450,
   -0.26380599,   0.17630760,   0.00012550,  -0.00002160,
  -18.64789963,   0.01014500,   0.00000500,
  296.86315918,  14.99901962,   0.00000000,
    0.57190800,  -0.00006970,  -0.00001010,
    0.02564200,  -0.00006930,  -0.00001010,
    0.00474980,   0.00472620,
"+20090126&Acc=2&Umb=1&Lmt=1&Mag=0&dT=66.3", "ASE_2009_01_26.kmz",
//2009 Jul 22
2455034.609, 3.0, -3.0, 3.0,   66.5,   66.5,
    0.23996100,   0.55639547,  -0.00005760,  -0.00009420,
   -0.00327600,  -0.17745790,  -0.00013440,   0.00003180,
   20.26424026,  -0.00787400,  -0.00000500,
  223.38821411,  15.00100040,   0.00000000,
    0.53042698,   0.00000630,  -0.00001280,
   -0.01563300,   0.00000630,  -0.00001270,
    0.00460140,   0.00457840,
"+20090722&Acc=2&Umb=1&Lmt=1&Mag=0&dT=66.5", "TSE_2009_07_22.kmz",
//2010 Jan 15
2455211.797, 7.0, -3.0, 3.0,   66.7,   66.7,
   -0.17327000,   0.48452041,  -0.00003710,  -0.00005380,
    0.36639899,   0.14049201,   0.00011700,  -0.00001700,
  -21.12929916,   0.00730700,   0.00000600,
  282.67111206,  14.99759007,   0.00000000,
    0.57467598,   0.00003720,  -0.00000990,
    0.02839600,   0.00003700,  -0.00000990,
    0.00475450,   0.00473080,
"+20100115&Acc=2&Umb=1&Lmt=1&Mag=0&dT=66.7", "ASE_2010_01_15.kmz",
//2010 Jul 11
2455389.316, 20.0, -3.0, 3.0,   66.9,   66.9,
    0.07406800,   0.55725157,  -0.00002760,  -0.00008970,
   -0.71702600,  -0.13665789,  -0.00011210,   0.00002360,
   22.03569984,  -0.00534100,  -0.00000500,
  118.61431885,  15.00006962,   0.00000000,
    0.53442299,  -0.00009080,  -0.00001240,
   -0.01165600,  -0.00009040,  -0.00001230,
    0.00459880,   0.00457590,
"+20100711&Acc=2&Umb=1&Lmt=1&Mag=0&dT=66.9", "TSE_2010_07_11.kmz",
//2011 Jan 4
2455565.869, 9.0, -3.0, 3.0,   67.1,   67.1,
   -0.14063101,   0.51627600,  -0.00004180,  -0.00006510,
    1.05582201,   0.10513870,   0.00010640,  -0.00001450,
  -22.74122047,   0.00406200,   0.00000600,
  313.81118774,  14.99662971,   0.00000000,
    0.56359202,   0.00010980,  -0.00001080,
    0.01736700,   0.00010920,  -0.00001070,
    0.00475570,   0.00473200,
"+20110104&Acc=2&Umb=1&Lmt=1&Mag=0&dT=67.1", "PSE_2011_01_04.kmz",
//2011 Jun 1
2455714.387, 21.0, -3.0, 3.0,   67.3,   67.3,
   -0.20265900,   0.52627438,   0.00002970,  -0.00006620,
    1.20555794,   0.02219590,  -0.00019310,  -0.00000220,
   22.09197044,   0.00552000,  -0.00000500,
  135.53765869,  14.99975014,   0.00000000,
    0.55621397,  -0.00010260,  -0.00001050,
    0.01002700,  -0.00010210,  -0.00001040,
    0.00461120,   0.00458820,
"+20110601&Acc=2&Umb=1&Lmt=1&Mag=0&dT=67.3", "PSE_2011_06_01.kmz",
//2011 Jul 1
2455743.861, 9.0, -3.0, 3.0,   67.3,   67.3,
   -0.05930200,   0.53551131,  -0.00000390,  -0.00007330,
   -1.50203300,  -0.08818300,  -0.00008330,   0.00001360,
   23.12097931,  -0.00254000,  -0.00000600,
  314.05319214,  14.99936008,   0.00000000,
    0.54776901,  -0.00012720,  -0.00001110,
    0.00162400,  -0.00012660,  -0.00001100,
    0.00459900,   0.00457610,
"+20110701&Acc=2&Umb=1&Lmt=1&Mag=0&dT=67.3", "PSE_2011_07_01.kmz",
//2011 Nov 25
2455890.765, 6.0, -3.0, 3.0,   67.5,   67.5,
   -0.31004301,   0.57290632,   0.00002050,  -0.00009410,
   -1.02766097,  -0.05788100,   0.00021050,   0.00000840,
  -20.67680931,  -0.00810000,   0.00000500,
  273.29934692,  14.99839973,   0.00000000,
    0.54060298,   0.00008220,  -0.00001280,
   -0.00550700,   0.00008180,  -0.00001270,
    0.00473600,   0.00471240,
"+20111125&Acc=2&Umb=1&Lmt=1&Mag=0&dT=67.5", "PSE_2011_11_25.kmz",
//2012 May 20
2456068.496, 0.0, -3.0, 3.0,   67.7,   67.7,
   -0.00226600,   0.50318283,   0.00001830,  -0.00005660,
    0.48552400,   0.05605380,  -0.00014110,  -0.00000560,
   20.22056007,   0.00827100,  -0.00000500,
  180.85658264,  15.00057983,   0.00000000,
    0.56648701,  -0.00003120,  -0.00000970,
    0.02024800,  -0.00003110,  -0.00000970,
    0.00462050,   0.00459740,
"+20120520&Acc=2&Umb=1&Lmt=1&Mag=0&dT=67.7", "ASE_2012_05_20.kmz",
//2012 Nov 13
2456245.426, 22.0, -3.0, 3.0,   68.0,   68.0,
   -0.18374100,   0.57434052,   0.00003510,  -0.00009730,
   -0.34676701,  -0.09407010,   0.00014840,   0.00001500,
  -18.24754906,  -0.01060200,   0.00000400,
  153.89781189,  14.99987030,   0.00000000,
    0.53744501,  -0.00002290,  -0.00001300,
   -0.00864900,  -0.00002280,  -0.00001300,
    0.00472550,   0.00470200,
"+20121113&Acc=2&Umb=1&Lmt=1&Mag=0&dT=68.0", "TSE_2012_11_13.kmz",
//2013 May 10
2456422.518, 0.0, -3.0, 3.0,   68.2,   68.2,
   -0.17518000,   0.50528872,   0.00001440,  -0.00005910,
   -0.30430099,   0.08888990,  -0.00009590,  -0.00000970,
   17.60548019,   0.01070100,  -0.00000400,
  180.90347290,  15.00166035,   0.00000000,
    0.56367201,   0.00007880,  -0.00001000,
    0.01744700,   0.00007840,  -0.00001000,
    0.00463130,   0.00460820,
"+20130510&Acc=2&Umb=1&Lmt=1&Mag=0&dT=68.2", "ASE_2013_05_10.kmz",
//2013 Nov 3
2456600.033, 13.0, -3.0, 3.0,   68.4,   68.4,
    0.18319599,   0.54694963,   0.00002830,  -0.00008260,
    0.29471999,  -0.12007570,   0.00007900,   0.00001730,
  -15.20965958,  -0.01263600,   0.00000300,
   19.11058998,  15.00131989,   0.00000000,
    0.54628199,  -0.00011210,  -0.00001200,
    0.00014300,  -0.00011150,  -0.00001200,
    0.00471370,   0.00469020,
"+20131103&Acc=2&Umb=1&Lmt=1&Mag=0&dT=68.4", "HSE_2013_11_03.kmz",
//2014 Apr 29
2456776.753, 6.0, -3.0, 3.0,   68.6,   68.6,
    0.18516301,   0.52826840,  -0.00000500,  -0.00007240,
   -0.98353201,   0.12211310,  -0.00004730,  -0.00001620,
   14.44979954,   0.01265800,  -0.00000300,
  270.65600586,  15.00275993,   0.00000000,
    0.55053800,   0.00011860,  -0.00001120,
    0.00437800,   0.00011810,  -0.00001110,
    0.00464330,   0.00462020,
"+20140429&Acc=2&Umb=1&Lmt=1&Mag=0&dT=68.6", "ASE_2014_04_29.kmz",
//2014 Oct 23
2456954.407, 22.0, -3.0, 3.0,   68.9,   68.9,
    0.40253600,   0.50848591,   0.00001600,  -0.00006410,
    1.02157903,  -0.13553271,   0.00001800,   0.00001630,
  -11.61851978,  -0.01419900,   0.00000200,
  153.93078613,  15.00265026,   0.00000000,
    0.56099701,  -0.00011080,  -0.00001060,
    0.01478500,  -0.00011030,  -0.00001060,
    0.00470060,   0.00467710,
"+20141023&Acc=2&Umb=1&Lmt=1&Mag=0&dT=68.9", "PSE_2014_10_23.kmz",
//2015 Mar 20
2457101.907, 10.0, -3.0, 3.0,   69.1,   69.1,
   -0.16829400,   0.55374151,   0.00000580,  -0.00009360,
    0.93905699,   0.17864820,  -0.00005410,  -0.00002930,
   -0.21266000,   0.01603600,   0.00000000,
  328.10678101,  15.00440979,   0.00000000,
    0.53593200,   0.00002650,  -0.00001300,
   -0.01015500,   0.00002640,  -0.00001290,
    0.00469500,   0.00467170,
"+20150320&Acc=2&Umb=1&Lmt=1&Mag=0&dT=69.1", "TSE_2015_03_20.kmz",
//2015 Sep 13
2457278.788, 7.0, -3.0, 3.0,   69.3,   69.3,
   -0.29289499,   0.48214200,   0.00000170,  -0.00005400,
   -1.06142998,  -0.15181831,   0.00002260,   0.00001640,
    3.89023995,  -0.01556400,  -0.00000100,
  285.97653198,  15.00485039,   0.00000000,
    0.56826299,   0.00002580,  -0.00000980,
    0.02201500,   0.00002570,  -0.00000970,
    0.00464730,   0.00462420,
"+20150913&Acc=2&Umb=1&Lmt=1&Mag=0&dT=69.3", "PSE_2015_09_13.kmz",
//2016 Mar 9
2457456.582, 2.0, -3.0, 3.0,   69.6,   69.6,
   -0.06252500,   0.55027688,   0.00000470,  -0.00009060,
    0.25383601,   0.17212330,   0.00001710,  -0.00002750,
   -4.37972021,   0.01588600,   0.00000100,
  207.37216187,  15.00397015,   0.00000000,
    0.53886801,  -0.00007040,  -0.00001280,
   -0.00723400,  -0.00007000,  -0.00001270,
    0.00470870,   0.00468520,
"+20160309&Acc=2&Umb=1&Lmt=1&Mag=0&dT=69.6", "TSE_2016_03_09.kmz",
//2016 Sep 1
2457632.881, 9.0, -3.0, 3.0,   69.8,   69.8,
   -0.16139600,   0.50406349,  -0.00002140,  -0.00006310,
   -0.29965001,  -0.14815210,  -0.00002580,   0.00001780,
    8.06330013,  -0.01480200,  -0.00000200,
  315.03155518,  15.00454044,   0.00000000,
    0.55792803,   0.00011150,  -0.00001050,
    0.01173100,   0.00011100,  -0.00001040,
    0.00463390,   0.00461090,
"+20160901&Acc=2&Umb=1&Lmt=1&Mag=0&dT=69.8", "ASE_2016_09_01.kmz",
//2017 Feb 26
2457811.121, 15.0, -3.0, 3.0,   70.0,   70.0,
    0.17594101,   0.52535641,  -0.00000620,  -0.00007420,
   -0.42556000,   0.15325411,   0.00007920,  -0.00002080,
   -8.49164009,   0.01526100,   0.00000200,
   41.79893875,  15.00308990,   0.00000000,
    0.55247003,  -0.00012570,  -0.00001150,
    0.00630100,  -0.00012510,  -0.00001150,
    0.00472190,   0.00469840,
"+20170226&Acc=2&Umb=1&Lmt=1&Mag=0&dT=70.0", "ASE_2017_02_26.kmz",
//2017 Aug 21
2457987.269, 18.0, -3.0, 3.0,   70.3,   70.3,
   -0.12957101,   0.54064262,  -0.00002940,  -0.00008100,
    0.48541600,  -0.14163999,  -0.00009050,   0.00002050,
   11.86695957,  -0.01362200,  -0.00000200,
   89.24542999,  15.00393963,   0.00000000,
    0.54209298,   0.00012410,  -0.00001180,
   -0.00402500,   0.00012340,  -0.00001170,
    0.00462220,   0.00459920,
"+20170821&Acc=2&Umb=1&Lmt=1&Mag=0&dT=70.3", "TSE_2017_08_21.kmz",
//2018 Feb 15
2458165.370, 21.0, -3.0, 3.0,   70.5,   70.5,
    0.36362001,   0.49905229,  -0.00002120,  -0.00005930,
   -1.15754902,   0.12833360,   0.00012680,  -0.00001440,
  -12.46403980,   0.01408000,   0.00000300,
  131.48074341,  15.00181961,   0.00000000,
    0.56825697,  -0.00009230,  -0.00001030,
    0.02200900,  -0.00009180,  -0.00001020,
    0.00473400,   0.00471040,
"+20180215&Acc=2&Umb=1&Lmt=1&Mag=0&dT=70.5", "PSE_2018_02_15.kmz",
//2018 Jul 13
2458312.627, 3.0, -3.0, 3.0,   70.8,   70.8,
   -0.09928600,   0.58281469,  -0.00000130,  -0.00009930,
   -1.35076904,  -0.03329330,  -0.00007700,   0.00000470,
   21.84531021,  -0.00593700,  -0.00000500,
  223.57078552,  15.00024033,   0.00000000,
    0.53016800,  -0.00001180,  -0.00001280,
   -0.01589000,  -0.00001180,  -0.00001270,
    0.00459880,   0.00457590,
"+20180713&Acc=2&Umb=1&Lmt=1&Mag=0&dT=70.8", "PSE_2018_07_13.kmz",
//2018 Aug 11
2458341.908, 10.0, -3.0, 3.0,   70.8,   70.8,
    0.36750799,   0.56849581,  -0.00004770,  -0.00009610,
    1.09391904,  -0.12629350,  -0.00015980,   0.00002060,
   15.21673012,  -0.01207600,  -0.00000300,
  328.69610596,  15.00308037,   0.00000000,
    0.53169799,   0.00003380,  -0.00001280,
   -0.01436800,   0.00003360,  -0.00001270,
    0.00461270,   0.00458970,
"+20180811&Acc=2&Umb=1&Lmt=1&Mag=0&dT=70.8", "PSE_2018_08_11.kmz",
//2019 Jan 6
2458489.571, 2.0, -3.0, 3.0,   71.0,   71.0,
    0.12837300,   0.50823838,  -0.00001620,  -0.00005810,
    1.14402199,   0.00842360,   0.00010360,   0.00000000,
  -22.54491997,   0.00484800,   0.00000600,
  208.61529541,  14.99674034,   0.00000000,
    0.57270199,   0.00005750,  -0.00001010,
    0.02643200,   0.00005720,  -0.00001000,
    0.00475620,   0.00473250,
"+20190106&Acc=2&Umb=1&Lmt=1&Mag=0&dT=71.0", "PSE_2019_01_06.kmz",
//2019 Jul 2
2458667.308, 19.0, -3.0, 3.0,   71.3,   71.3,
   -0.21563400,   0.56620872,   0.00002740,  -0.00008790,
   -0.65070802,   0.01063990,  -0.00012720,  -0.00000270,
   23.01295090,  -0.00318700,  -0.00000500,
  103.97972870,  14.99950981,   0.00000000,
    0.53763098,  -0.00008980,  -0.00001200,
   -0.00846400,  -0.00008940,  -0.00001200,
    0.00459840,   0.00457550,
"+20190702&Acc=2&Umb=1&Lmt=1&Mag=0&dT=71.3", "TSE_2019_07_02.kmz",
//2019 Dec 26
2458843.721, 5.0, -3.0, 3.0,   71.5,   71.5,
   -0.14041300,   0.53561032,  -0.00000150,  -0.00007150,
    0.42407501,  -0.03665510,   0.00014580,   0.00000610,
  -23.37347031,   0.00140700,   0.00000600,
  254.93676758,  14.99627018,   0.00000000,
    0.55888700,   0.00012840,  -0.00001120,
    0.01268600,   0.00012770,  -0.00001110,
    0.00475480,   0.00473110,
"+20191226&Acc=2&Umb=1&Lmt=1&Mag=0&dT=71.5", "ASE_2019_12_26.kmz",
//2020 Jun 21
2459021.779, 7.0, -3.0, 3.0,   71.8,   71.8,
    0.15425900,   0.53115457,   0.00002590,  -0.00006940,
    0.13640900,   0.05138710,  -0.00016100,  -0.00000790,
   23.43567085,  -0.00023300,  -0.00000600,
  284.53552246,  14.99911022,   0.00000000,
    0.55231798,  -0.00012230,  -0.00001070,
    0.00615000,  -0.00012170,  -0.00001070,
    0.00460090,   0.00457800,
"+20200621&Acc=2&Umb=1&Lmt=1&Mag=0&dT=71.8", "ASE_2020_06_21.kmz",
//2020 Dec 14
2459198.177, 16.0, -3.0, 3.0,   72.1,   72.1,
   -0.18182400,   0.56335670,   0.00002160,  -0.00008950,
   -0.26964501,  -0.08581220,   0.00018840,   0.00001500,
  -23.25775909,  -0.00198600,   0.00000600,
   61.26591110,  14.99650002,   0.00000000,
    0.54386199,   0.00009700,  -0.00001260,
   -0.00226500,   0.00009650,  -0.00001250,
    0.00475020,   0.00472660,
"+20201214&Acc=2&Umb=1&Lmt=1&Mag=0&dT=72.1", "TSE_2020_12_14.kmz",
//2021 Jun 10
2459375.947, 11.0, -3.0, 3.0,   72.3,   72.3,
   -0.01870400,   0.50122893,   0.00003420,  -0.00005700,
    0.92610598,   0.08877650,  -0.00017970,  -0.00001130,
   23.04228020,   0.00284100,  -0.00000500,
  345.12692261,  14.99919987,   0.00000000,
    0.56437999,  -0.00005510,  -0.00000980,
    0.01815100,  -0.00005480,  -0.00000970,
    0.00460600,   0.00458300,
"+20210610&Acc=2&Umb=1&Lmt=1&Mag=0&dT=72.3", "ASE_2021_06_10.kmz",
//2021 Dec 4
2459552.816, 8.0, -3.0, 3.0,   72.6,   72.6,
    0.02520900,   0.56830281,   0.00003910,  -0.00009650,
   -0.98365301,  -0.13151421,   0.00022130,   0.00002400,
  -22.27471924,  -0.00517800,   0.00000600,
  302.45217896,  14.99728012,   0.00000000,
    0.53780502,  -0.00001600,  -0.00001310,
   -0.00829200,  -0.00001600,  -0.00001310,
    0.00474340,   0.00471980,
"+20211204&Acc=2&Umb=1&Lmt=1&Mag=0&dT=72.6", "TSE_2021_12_04.kmz",
//2022 Apr 30
2459700.363, 21.0, -3.0, 3.0,   72.8,   72.8,
    0.61808002,   0.47531471,  -0.00000150,  -0.00005680,
   -1.02808905,   0.20964050,  -0.00004320,  -0.00002680,
   14.97103977,   0.01216700,  -0.00000300,
  135.70559692,  15.00247002,   0.00000000,
    0.56107301,   0.00008470,  -0.00001030,
    0.01486100,   0.00008430,  -0.00001020,
    0.00464200,   0.00461890,
"+20220430&Acc=2&Umb=1&Lmt=1&Mag=0&dT=72.8", "PSE_2022_04_30.kmz",
//2022 Oct 25
2459877.959, 11.0, -3.0, 3.0,   73.1,   73.1,
    0.45479199,   0.49554950,   0.00002770,  -0.00007030,
    0.96877098,  -0.23958760,   0.00001670,   0.00003560,
  -12.17348003,  -0.01374600,   0.00000300,
  348.98226929,  15.00242996,   0.00000000,
    0.54987901,  -0.00011520,  -0.00001160,
    0.00372300,  -0.00011460,  -0.00001160,
    0.00470190,   0.00467850,
"+20221025&Acc=2&Umb=1&Lmt=1&Mag=0&dT=73.1", "PSE_2022_10_25.kmz",
//2023 Apr 20
2460054.679, 4.0, -3.0, 3.0,   73.4,   73.4,
    0.02685000,   0.49501821,   0.00001350,  -0.00007060,
   -0.42736599,   0.24419920,  -0.00004940,  -0.00003680,
   11.41178989,   0.01374100,  -0.00000300,
  240.24293518,  15.00341988,   0.00000000,
    0.54680401,   0.00012160,  -0.00001160,
    0.00066300,   0.00012100,  -0.00001150,
    0.00465500,   0.00463180,
"+20230420&Acc=2&Umb=1&Lmt=1&Mag=0&dT=73.4", "HSE_2023_04_20.kmz",
//2023 Oct 14
2460232.250, 18.0, -3.0, 3.0,   73.7,   73.7,
    0.16965801,   0.45855331,   0.00002780,  -0.00005430,
    0.33485901,  -0.24136710,   0.00002400,   0.00003030,
   -8.24419022,  -0.01488800,   0.00000200,
   93.50173187,  15.00352955,   0.00000000,
    0.56431103,  -0.00008910,  -0.00001030,
    0.01808300,  -0.00008860,  -0.00001030,
    0.00468820,   0.00466480,
"+20231014&Acc=2&Umb=1&Lmt=1&Mag=0&dT=73.7", "ASE_2023_10_14.kmz",
//2024 Apr 8
2460409.263, 18.0, -3.0, 3.0,   74.0,   74.0,
   -0.31824401,   0.51171160,   0.00003260,  -0.00008420,
    0.21976399,   0.27095890,  -0.00005950,  -0.00004660,
    7.58620024,   0.01484400,  -0.00000200,
   89.59121704,  15.00407982,   0.00000000,
    0.53581399,   0.00006180,  -0.00001280,
   -0.01027200,   0.00006150,  -0.00001270,
    0.00466830,   0.00464500,
"+20240408&Acc=2&Umb=1&Lmt=1&Mag=0&dT=74.0", "TSE_2024_04_08.kmz",
//2024 Oct 2
2460586.282, 19.0, -3.0, 3.0,   74.3,   74.3,
   -0.06804800,   0.44161701,   0.00001360,  -0.00004830,
   -0.36317000,  -0.24356300,   0.00003390,   0.00002840,
   -3.98725009,  -0.01551100,   0.00000100,
  107.73108673,  15.00432968,   0.00000000,
    0.57034898,  -0.00000020,  -0.00000980,
    0.02409100,  -0.00000020,  -0.00000970,
    0.00467340,   0.00465010,
"+20241002&Acc=2&Umb=1&Lmt=1&Mag=0&dT=74.3", "ASE_2024_10_02.kmz",
//2025 Mar 29
2460763.950, 11.0, -3.0, 3.0,   74.5,   74.5,
   -0.40287000,   0.50941223,   0.00004150,  -0.00008450,
    0.96569502,   0.27883479,  -0.00007230,  -0.00004840,
    3.56602001,   0.01553900,  -0.00000100,
  343.83166504,  15.00436020,   0.00000000,
    0.53576601,  -0.00005330,  -0.00001290,
   -0.01032000,  -0.00005300,  -0.00001280,
    0.00468230,   0.00465900,
"+20250329&Acc=2&Umb=1&Lmt=1&Mag=0&dT=74.5", "PSE_2025_03_29.kmz",
//2025 Sep 21
2460940.322, 20.0, -3.0, 3.0,   74.8,   74.8,
   -0.39007199,   0.45315921,   0.00000320,  -0.00005380,
   -1.00183403,  -0.25216329,   0.00004560,   0.00003150,
    0.36471999,  -0.01560000,   0.00000000,
  121.78192139,  15.00477028,   0.00000000,
    0.56249201,   0.00009090,  -0.00001030,
    0.01627300,   0.00009050,  -0.00001020,
    0.00465830,   0.00463510,
"+20250921&Acc=2&Umb=1&Lmt=1&Mag=0&dT=74.8", "PSE_2025_09_21.kmz",
//2026 Feb 17
2461089.009, 12.0, -3.0, 3.0,   75.1,   75.1,
    0.32195401,   0.48272240,  -0.00003140,  -0.00006370,
   -0.92697102,   0.23553941,   0.00011690,  -0.00003270,
  -11.87930012,   0.01404900,   0.00000200,
  356.51440430,  15.00197983,   0.00000000,
    0.55772001,  -0.00011810,  -0.00001110,
    0.01152400,  -0.00011750,  -0.00001110,
    0.00473210,   0.00470850,
"+20260217&Acc=2&Umb=1&Lmt=1&Mag=0&dT=75.1", "ASE_2026_02_17.kmz",
//2026 Aug 12
2461265.241, 18.0, -3.0, 3.0,   75.4,   75.4,
    0.47551399,   0.51892489,  -0.00007730,  -0.00008040,
    0.77118301,  -0.23016800,  -0.00012460,   0.00003770,
   14.79666996,  -0.01206500,  -0.00000300,
   88.74778748,  15.00308990,   0.00000000,
    0.53795499,   0.00009390,  -0.00001210,
   -0.00814200,   0.00009350,  -0.00001210,
    0.00461410,   0.00459110,
"+20260812&Acc=2&Umb=1&Lmt=1&Mag=0&dT=75.4", "TSE_2026_08_12.kmz",
//2027 Feb 6
2461443.167, 16.0, -3.0, 3.0,   75.7,   75.7,
    0.11167600,   0.46649519,  -0.00003370,  -0.00005270,
   -0.27329299,   0.20318560,   0.00010250,  -0.00002460,
  -15.54794025,   0.01238300,   0.00000400,
   56.49306870,  15.00051022,   0.00000000,
    0.57192802,  -0.00006530,  -0.00001010,
    0.02566200,  -0.00006500,  -0.00001000,
    0.00474260,   0.00471900,
"+20270206&Acc=2&Umb=1&Lmt=1&Mag=0&dT=75.7", "ASE_2027_02_06.kmz",
//2027 Aug 2
2461619.922, 10.0, -3.0, 3.0,   76.0,   76.0,
   -0.01977200,   0.54471231,  -0.00004460,  -0.00009220,
    0.16006100,  -0.21115820,  -0.00012170,   0.00003760,
   17.76247025,  -0.01018100,  -0.00000400,
  328.42254639,  15.00209999,   0.00000000,
    0.53059602,   0.00001380,  -0.00001280,
   -0.01546400,   0.00001370,  -0.00001280,
    0.00460640,   0.00458340,
"+20270802&Acc=2&Umb=1&Lmt=1&Mag=0&dT=76.0", "TSE_2027_08_02.kmz",
//2028 Jan 26
2461797.131, 15.0, -3.0, 3.0,   76.3,   76.3,
   -0.20528300,   0.47425699,  -0.00003900,  -0.00005270,
    0.34028000,   0.17385870,   0.00009680,  -0.00002090,
  -18.72825050,   0.01007400,   0.00000500,
   41.89128113,  14.99895954,   0.00000000,
    0.57411700,   0.00004200,  -0.00000990,
    0.02784000,   0.00004180,  -0.00000990,
    0.00475010,   0.00472640,
"+20280126&Acc=2&Umb=1&Lmt=1&Mag=0&dT=76.3", "ASE_2028_01_26.kmz",
//2028 Jul 22
2461974.623, 3.0, -3.0, 3.0,   76.6,   76.6,
   -0.15440901,   0.54498923,  -0.00002140,  -0.00008690,
   -0.58642399,  -0.17460850,  -0.00010210,   0.00002960,
   20.18231010,  -0.00797400,  -0.00000500,
  223.37867737,  15.00102043,   0.00000000,
    0.53523701,  -0.00008590,  -0.00001230,
   -0.01084600,  -0.00008540,  -0.00001220,
    0.00460160,   0.00457860,
"+20280722&Acc=2&Umb=1&Lmt=1&Mag=0&dT=76.6", "TSE_2028_07_22.kmz",
//2029 Jan 14
2462151.218, 17.0, -3.0, 3.0,   76.9,   76.9,
   -0.40744400,   0.50815248,  -0.00003930,  -0.00006460,
    0.98105502,   0.14552830,   0.00009210,  -0.00001990,
  -21.16300964,   0.00724100,   0.00000600,
   72.69288635,  14.99763012,   0.00000000,
    0.56266600,   0.00011890,  -0.00001090,
    0.01644600,   0.00011830,  -0.00001080,
    0.00475410,   0.00473040,
"+20290114&Acc=2&Umb=1&Lmt=1&Mag=0&dT=76.9", "PSE_2029_01_14.kmz",
//2029 Jun 12
2462299.671, 4.0, -3.0, 3.0,   77.2,   77.2,
   -0.01079900,   0.52476060,   0.00001040,  -0.00006540,
    1.29541302,  -0.01763650,  -0.00020570,   0.00000290,
   23.15932083,   0.00259100,  -0.00000500,
  240.03558350,  14.99919987,   0.00000000,
    0.55666202,  -0.00010270,  -0.00001040,
    0.01047200,  -0.00010220,  -0.00001030,
    0.00460480,   0.00458190,
"+20290612&Acc=2&Umb=1&Lmt=1&Mag=0&dT=77.2", "PSE_2029_06_12.kmz",
//2029 Jul 11
2462329.151, 16.0, -3.0, 3.0,   77.2,   77.2,
   -0.13734700,   0.52526343,  -0.00000960,  -0.00007100,
   -1.42714906,  -0.12804170,  -0.00007690,   0.00001890,
   22.00245094,  -0.00542300,  -0.00000500,
   58.60256958,  15.00000954,   0.00000000,
    0.54875600,  -0.00012690,  -0.00001100,
    0.00260500,  -0.00012630,  -0.00001090,
    0.00459940,   0.00457650,
"+20290711&Acc=2&Umb=1&Lmt=1&Mag=0&dT=77.2", "PSE_2029_07_11.kmz",
//2029 Dec 5
2462476.128, 15.0, -3.0, 3.0,   77.5,   77.5,
   -0.06383300,   0.57663530,  -0.00000270,  -0.00009510,
   -1.05966604,  -0.01401650,   0.00022950,   0.00000110,
  -22.44544983,  -0.00505400,   0.00000600,
   47.30984879,  14.99717045,   0.00000000,
    0.54064202,   0.00006990,  -0.00001280,
   -0.00546900,   0.00006950,  -0.00001280,
    0.00474460,   0.00472090,
"+20291205&Acc=2&Umb=1&Lmt=1&Mag=0&dT=77.5", "PSE_2029_12_05.kmz",
//2030 Jun 1
2462653.770, 6.0, -3.0, 3.0,   77.8,   77.8,
   -0.26939100,   0.50563711,   0.00001820,  -0.00005680,
    0.55197698,   0.02101500,  -0.00015860,  -0.00000160,
   22.06130028,   0.00558100,  -0.00000500,
  270.53982544,  14.99969959,   0.00000000,
    0.56615001,  -0.00001300,  -0.00000970,
    0.01991200,  -0.00001290,  -0.00000970,
    0.00461200,   0.00458900,
"+20300601&Acc=2&Umb=1&Lmt=1&Mag=0&dT=77.8", "ASE_2030_06_01.kmz",
//2030 Nov 25
2462830.786, 7.0, -3.0, 3.0,   78.1,   78.1,
    0.04415000,   0.57877982,   0.00001770,  -0.00009780,
   -0.39265999,  -0.05518910,   0.00017440,   0.00000830,
  -20.76099968,  -0.00798900,   0.00000500,
  288.27459717,  14.99835968,   0.00000000,
    0.53821301,  -0.00003790,  -0.00001300,
   -0.00788500,  -0.00003770,  -0.00001300,
    0.00473610,   0.00471250,
"+20301125&Acc=2&Umb=1&Lmt=1&Mag=0&dT=78.1", "TSE_2030_11_25.kmz",
//2031 May 21
2463007.803, 7.0, -3.0, 3.0,   78.5,   78.5,
   -0.11478100,   0.51123917,   0.00000720,  -0.00006030,
   -0.21124800,   0.05793300,  -0.00011820,  -0.00000610,
   20.15914917,   0.00833900,  -0.00000500,
  285.85113525,  15.00061989,   0.00000000,
    0.56240499,   0.00008060,  -0.00001000,
    0.01618600,   0.00008020,  -0.00001000,
    0.00462080,   0.00459780,
"+20310521&Acc=2&Umb=1&Lmt=1&Mag=0&dT=78.5", "ASE_2031_05_21.kmz",
//2031 Nov 14
2463185.380, 21.0, -3.0, 3.0,   78.8,   78.8,
   -0.01986900,   0.55094397,   0.00003660,  -0.00008240,
    0.31497100,  -0.08906520,   0.00010460,   0.00001240,
  -18.33680916,  -0.01053400,   0.00000400,
  138.89398193,  14.99975967,   0.00000000,
    0.54777402,  -0.00010680,  -0.00001200,
    0.00162800,  -0.00010630,  -0.00001190,
    0.00472600,   0.00470250,
"+20311114&Acc=2&Umb=1&Lmt=1&Mag=0&dT=78.8", "HSE_2031_11_14.kmz",
//2032 May 9
2463362.060, 13.0, -3.0, 3.0,   79.1,   79.1,
   -0.07436000,   0.53595459,   0.00000520,  -0.00007440,
   -0.96545100,   0.09540580,  -0.00007020,  -0.00001260,
   17.59291077,   0.01069400,  -0.00000400,
   15.88910007,  15.00174046,   0.00000000,
    0.54885298,   0.00012720,  -0.00001120,
    0.00270200,   0.00012660,  -0.00001120,
    0.00463100,   0.00460790,
"+20320509&Acc=2&Umb=1&Lmt=1&Mag=0&dT=79.1", "ASE_2032_05_09.kmz",
//2032 Nov 3
2463539.732, 6.0, -3.0, 3.0,   79.5,   79.5,
    0.44923899,   0.51201922,   0.00001700,  -0.00006390,
    0.99083602,  -0.11286830,   0.00004520,   0.00001330,
  -15.23991966,  -0.01263300,   0.00000300,
  274.11911011,  15.00123024,   0.00000000,
    0.56260502,  -0.00011270,  -0.00001060,
    0.01638500,  -0.00011210,  -0.00001060,
    0.00471410,   0.00469060,
"+20321103&Acc=2&Umb=1&Lmt=1&Mag=0&dT=79.5", "PSE_2032_11_03.kmz",
//2033 Mar 30
2463687.252, 18.0, -3.0, 3.0,   79.7,   79.7,
   -0.31885099,   0.55542439,   0.00002270,  -0.00009420,
    0.92466700,   0.17566100,  -0.00008010,  -0.00002890,
    4.09367990,   0.01571900,  -0.00000100,
   88.92807770,  15.00444984,   0.00000000,
    0.53494298,   0.00002760,  -0.00001290,
   -0.01113900,   0.00002750,  -0.00001290,
    0.00468070,   0.00465740,
"+20330330&Acc=2&Umb=1&Lmt=1&Mag=0&dT=79.7", "TSE_2033_03_30.kmz",
//2033 Sep 23
2463864.080, 14.0, -3.0, 3.0,   80.1,   80.1,
   -0.30999601,   0.48154479,   0.00000870,  -0.00005410,
   -1.11700499,  -0.15454410,   0.00004780,   0.00001670,
   -0.33982000,  -0.01584500,   0.00000000,
   31.94245911,  15.00479984,   0.00000000,
    0.56889701,   0.00003180,  -0.00000980,
    0.02264600,   0.00003160,  -0.00000970,
    0.00466070,   0.00463750,
"+20330923&Acc=2&Umb=1&Lmt=1&Mag=0&dT=80.1", "PSE_2033_09_23.kmz",
//2034 Mar 20
2464041.930, 10.0, -3.0, 3.0,   80.4,   80.4,
   -0.25960901,   0.54816288,   0.00002340,  -0.00008970,
    0.22075200,   0.17557900,  -0.00000800,  -0.00002790,
   -0.05513000,   0.01604200,   0.00000000,
  328.13912964,  15.00440025,   0.00000000,
    0.53863102,  -0.00006650,  -0.00001270,
   -0.00746900,  -0.00006620,  -0.00001260,
    0.00469520,   0.00467180,
"+20340320&Acc=2&Umb=1&Lmt=1&Mag=0&dT=80.4", "TSE_2034_03_20.kmz",
//2034 Sep 12
2464218.180, 16.0, -3.0, 3.0,   80.8,   80.8,
   -0.28090599,   0.50283420,  -0.00001070,  -0.00006350,
   -0.32433900,  -0.15778451,  -0.00000080,   0.00001920,
    3.97191000,  -0.01553400,  -0.00000100,
   60.94969940,  15.00489998,   0.00000000,
    0.55780101,   0.00011880,  -0.00001060,
    0.01160500,   0.00011820,  -0.00001050,
    0.00464610,   0.00462300,
"+20340912&Acc=2&Umb=1&Lmt=1&Mag=0&dT=80.8", "ASE_2034_09_12.kmz",
//2035 Mar 9
2464396.462, 23.0, -3.0, 3.0,   81.1,   81.1,
    0.07946900,   0.52057391,   0.00000500,  -0.00007280,
   -0.43283200,   0.16309451,   0.00005320,  -0.00002190,
   -4.27334023,   0.01592000,   0.00000100,
  162.39613342,  15.00389957,   0.00000000,
    0.55262297,  -0.00012190,  -0.00001140,
    0.00645300,  -0.00012130,  -0.00001140,
    0.00470950,   0.00468610,
"+20350309&Acc=2&Umb=1&Lmt=1&Mag=0&dT=81.1", "ASE_2035_03_09.kmz",
//2035 Sep 2
2464572.581, 2.0, -3.0, 3.0,   81.5,   81.5,
    0.13428199,   0.53777349,  -0.00003600,  -0.00008120,
    0.34900901,  -0.15846510,  -0.00005950,   0.00002320,
    8.01770973,  -0.01478300,  -0.00000200,
  210.02998352,  15.00463963,   0.00000000,
    0.54192001,   0.00011030,  -0.00001190,
   -0.00419700,   0.00010980,  -0.00001180,
    0.00463280,   0.00460970,
"+20350902&Acc=2&Umb=1&Lmt=1&Mag=0&dT=81.5", "TSE_2035_09_02.kmz",
//2036 Feb 27
2464750.699, 5.0, -3.0, 3.0,   81.8,   81.8,
    0.44404301,   0.49340111,  -0.00002010,  -0.00005820,
   -1.11431897,   0.14454030,   0.00009970,  -0.00001630,
   -8.49969006,   0.01528100,   0.00000200,
  251.80839539,  15.00300026,   0.00000000,
    0.56819201,  -0.00009060,  -0.00001020,
    0.02194500,  -0.00009010,  -0.00001020,
    0.00472310,   0.00469950,
"+20360227&Acc=2&Umb=1&Lmt=1&Mag=0&dT=81.8", "PSE_2036_02_27.kmz",
//2036 Jul 23
2464897.939, 11.0, -3.0, 3.0,   82.1,   82.1,
    0.09001600,   0.57882208,  -0.00001800,  -0.00009850,
   -1.44781399,  -0.07336820,  -0.00005470,   0.00001160,
   19.89421082,  -0.00853700,  -0.00000500,
  343.36190796,  15.00123978,   0.00000000,
    0.53043598,  -0.00003060,  -0.00001280,
   -0.01562400,  -0.00003040,  -0.00001270,
    0.00460190,   0.00457890,
"+20360723&Acc=2&Umb=1&Lmt=1&Mag=0&dT=82.1", "PSE_2036_07_23.kmz",
//2036 Aug 21
2464927.226, 17.0, -3.0, 3.0,   82.1,   82.1,
    0.03644600,   0.56328869,  -0.00002800,  -0.00009550,
    1.11038494,  -0.14969720,  -0.00013540,   0.00002460,
   11.74118996,  -0.01364600,  -0.00000200,
   74.25917816,  15.00403023,   0.00000000,
    0.53190798,   0.00004450,  -0.00001280,
   -0.01415800,   0.00004430,  -0.00001270,
    0.00462170,   0.00459870,
"+20360821&Acc=2&Umb=1&Lmt=1&Mag=0&dT=82.1", "PSE_2036_08_21.kmz",
//2037 Jan 16
2465074.909, 10.0, -3.0, 3.0,   82.4,   82.4,
   -0.01344200,   0.50710249,  -0.00002150,  -0.00005830,
    1.15149105,   0.04756250,   0.00008750,  -0.00000460,
  -20.83011055,   0.00796900,   0.00000600,
  327.55044556,  14.99783039,   0.00000000,
    0.57208198,   0.00006330,  -0.00001010,
    0.02581500,   0.00006300,  -0.00001010,
    0.00475400,   0.00473030,
"+20370116&Acc=2&Umb=1&Lmt=1&Mag=0&dT=82.4", "PSE_2037_01_16.kmz",
//2037 Jul 13
2465252.612, 3.0, -3.0, 3.0,   82.8,   82.8,
    0.14150099,   0.56359971,   0.00000010,  -0.00008690,
   -0.73370701,  -0.03182170,  -0.00011310,   0.00000410,
   21.78243065,  -0.00604600,  -0.00000500,
  223.55012512,  15.00022984,   0.00000000,
    0.53838301,  -0.00011010,  -0.00001200,
   -0.00771600,  -0.00010960,  -0.00001190,
    0.00459930,   0.00457640,
"+20370713&Acc=2&Umb=1&Lmt=1&Mag=0&dT=82.8", "TSE_2037_07_13.kmz",
//2038 Jan 5
2465429.074, 14.0, -3.0, 3.0,   83.2,   83.2,
    0.10891000,   0.53854078,  -0.00002490,  -0.00007260,
    0.41854399,   0.00799330,   0.00013790,  -0.00000010,
  -22.55480957,   0.00481200,   0.00000600,
   28.64307976,  14.99680996,   0.00000000,
    0.55816299,   0.00011650,  -0.00001120,
    0.01196500,   0.00011590,  -0.00001120,
    0.00475540,   0.00473170,
"+20380105&Acc=2&Umb=1&Lmt=1&Mag=0&dT=83.2", "ASE_2038_01_05.kmz",
//2038 Jul 2
2465607.065, 14.0, -3.0, 3.0,   83.5,   83.5,
    0.23919401,   0.53154087,   0.00001000,  -0.00006880,
    0.04416700,   0.00971120,  -0.00015440,  -0.00000230,
   22.99406052,  -0.00324000,  -0.00000500,
   28.96240044,  14.99942017,   0.00000000,
    0.55313599,  -0.00012260,  -0.00001060,
    0.00696300,  -0.00012200,  -0.00001060,
    0.00459930,   0.00457640,
"+20380702&Acc=2&Umb=1&Lmt=1&Mag=0&dT=83.5", "ASE_2038_07_02.kmz",
//2038 Dec 26
2465783.542, 1.0, -3.0, 3.0,   83.9,   83.9,
   -0.02068400,   0.56985623,  -0.00000020,  -0.00009120,
   -0.28739199,  -0.03797120,   0.00019150,   0.00000730,
  -23.36257935,   0.00148100,   0.00000600,
  194.92213440,  14.99637985,   0.00000000,
    0.54350698,   0.00008670,  -0.00001260,
   -0.00261700,   0.00008630,  -0.00001260,
    0.00475370,   0.00473000,
"+20381226&Acc=2&Umb=1&Lmt=1&Mag=0&dT=83.9", "TSE_2038_12_26.kmz",
//2039 Jun 21
2465961.217, 17.0, -3.0, 3.0,   84.2,   84.2,
   -0.18961100,   0.50586933,   0.00002760,  -0.00005740,
    0.81659299,   0.04954140,  -0.00018000,  -0.00000670,
   23.43238068,  -0.00017800,  -0.00000600,
   74.53582001,  14.99903965,   0.00000000,
    0.56452602,  -0.00003880,  -0.00000980,
    0.01829700,  -0.00003860,  -0.00000970,
    0.00460170,   0.00457880,
"+20390621&Acc=2&Umb=1&Lmt=1&Mag=0&dT=84.2", "ASE_2039_06_21.kmz",
//2039 Dec 15
2466138.183, 16.0, -3.0, 3.0,   84.6,   84.6,
   -0.36599201,   0.57692862,   0.00004730,  -0.00009810,
   -0.90211201,  -0.08494870,   0.00022950,   0.00001600,
  -23.27404976,  -0.00186200,   0.00000600,
   61.22589874,  14.99652004,   0.00000000,
    0.53820699,  -0.00000040,  -0.00001310,
   -0.00789200,  -0.00000040,  -0.00001310,
    0.00474990,   0.00472620,
"+20391215&Acc=2&Umb=1&Lmt=1&Mag=0&dT=84.6", "TSE_2039_12_15.kmz",
//2040 May 11
2466285.655, 4.0, -3.0, 3.0,   84.9,   84.9,
    0.58198601,   0.48740420,   0.00000210,  -0.00005890,
   -1.11928499,   0.18475839,  -0.00006000,  -0.00002400,
   18.02784920,   0.01013500,  -0.00000400,
  240.90550232,  15.00144958,   0.00000000,
    0.55954099,   0.00008890,  -0.00001030,
    0.01333700,   0.00008840,  -0.00001030,
    0.00462990,   0.00460680,
"+20400511&Acc=2&Umb=1&Lmt=1&Mag=0&dT=84.9", "PSE_2040_05_11.kmz",
//2040 Nov 4
2466463.298, 19.0, -3.0, 3.0,   85.3,   85.3,
    0.35744399,   0.50393128,   0.00003960,  -0.00007080,
    1.04281497,  -0.21615410,   0.00003950,   0.00003200,
  -15.73229980,  -0.01210000,   0.00000400,
  109.10984802,  15.00098991,   0.00000000,
    0.55151701,  -0.00011360,  -0.00001160,
    0.00535200,  -0.00011300,  -0.00001150,
    0.00471550,   0.00469200,
"+20401104&Acc=2&Umb=1&Lmt=1&Mag=0&dT=85.3", "PSE_2040_11_04.kmz",
//2041 Apr 30
2466639.995, 12.0, -3.0, 3.0,   85.7,   85.7,
    0.24642700,   0.50667208,   0.00001120,  -0.00007310,
   -0.38214701,   0.22423150,  -0.00007400,  -0.00003420,
   14.97447014,   0.01212800,  -0.00000300,
    0.70736998,  15.00253963,   0.00000000,
    0.54520702,   0.00011040,  -0.00001160,
   -0.00092600,   0.00010990,  -0.00001160,
    0.00464150,   0.00461840,
"+20410430&Acc=2&Umb=1&Lmt=1&Mag=0&dT=85.7", "TSE_2041_04_30.kmz",
//2041 Oct 25
2466817.567, 2.0, -3.0, 3.0,   86.0,   86.0,
    0.36374101,   0.46455359,   0.00003020,  -0.00005470,
    0.28274101,  -0.22580899,   0.00004960,   0.00002830,
  -12.17860031,  -0.01377400,   0.00000300,
  213.98297119,  15.00234985,   0.00000000,
    0.56585002,  -0.00009390,  -0.00001030,
    0.01961400,  -0.00009340,  -0.00001020,
    0.00470240,   0.00467900,
"+20411025&Acc=2&Umb=1&Lmt=1&Mag=0&dT=86.0", "ASE_2041_10_25.kmz",
//2042 Apr 20
2466994.595, 2.0, -3.0, 3.0,   86.4,   86.4,
   -0.28233200,   0.52043200,   0.00004180,  -0.00008610,
    0.19049200,   0.25618809,  -0.00008190,  -0.00004440,
   11.51743984,   0.01367000,  -0.00000300,
  210.25866699,  15.00345039,   0.00000000,
    0.53468299,   0.00005610,  -0.00001280,
   -0.01139800,   0.00005580,  -0.00001270,
    0.00465430,   0.00463110,
"+20420420&Acc=2&Umb=1&Lmt=1&Mag=0&dT=86.4", "TSE_2042_04_20.kmz",
//2042 Oct 14
2467171.584, 2.0, -3.0, 3.0,   86.8,   86.8,
   -0.14661400,   0.44586059,   0.00002620,  -0.00004880,
   -0.26527801,  -0.23529270,   0.00005240,   0.00002740,
   -8.14227009,  -0.01492000,   0.00000200,
  213.48588562,  15.00352955,   0.00000000,
    0.57124603,   0.00001050,  -0.00000980,
    0.02498400,   0.00001040,  -0.00000970,
    0.00468780,   0.00466440,
"+20421014&Acc=2&Umb=1&Lmt=1&Mag=0&dT=86.8", "ASE_2042_10_14.kmz",
//2043 Apr 9
2467349.290, 19.0, -3.0, 3.0,   87.2,   87.2,
   -0.44778901,   0.51359999,   0.00005650,  -0.00008490,
    0.89790398,   0.26972800,  -0.00009270,  -0.00004670,
    7.74980021,   0.01480800,  -0.00000200,
  104.61505127,  15.00405979,   0.00000000,
    0.53534299,  -0.00005460,  -0.00001280,
   -0.01074100,  -0.00005440,  -0.00001270,
    0.00466800,   0.00464480,
"+20430409&Acc=2&Umb=1&Lmt=1&Mag=0&dT=87.2", "TSE_2043_04_09.kmz",
//2043 Oct 3
2467525.626, 3.0, -3.0, 3.0,   87.6,   87.6,
   -0.50047100,   0.45564619,   0.00001830,  -0.00005450,
   -0.87765998,  -0.25050679,   0.00006280,   0.00003160,
   -3.88199997,  -0.01549800,   0.00000100,
  227.70957947,  15.00438976,   0.00000000,
    0.56258899,   0.00010130,  -0.00001030,
    0.01637000,   0.00010080,  -0.00001030,
    0.00467230,   0.00464900,
"+20431003&Acc=2&Umb=1&Lmt=1&Mag=0&dT=87.6", "ASE_2043_10_03.kmz",
//2044 Feb 28
2467674.350, 20.0, -3.0, 3.0,   87.9,   87.9,
    0.26971000,   0.47362161,  -0.00001940,  -0.00006180,
   -0.98305500,   0.24971320,   0.00009440,  -0.00003420,
   -7.86254978,   0.01517000,   0.00000100,
  116.87963867,  15.00310040,   0.00000000,
    0.55792099,  -0.00011320,  -0.00001100,
    0.01172400,  -0.00011270,  -0.00001100,
    0.00472090,   0.00469740,
"+20440228&Acc=2&Umb=1&Lmt=1&Mag=0&dT=87.9", "ASE_2044_02_28.kmz",
//2044 Aug 23
2467850.553, 1.0, -3.0, 3.0,   88.3,   88.3,
    0.27951100,   0.51077801,  -0.00006100,  -0.00007970,
    0.93383998,  -0.25128210,  -0.00010950,   0.00004130,
   11.26904011,  -0.01358200,  -0.00000200,
  194.34898376,  15.00401020,   0.00000000,
    0.53768998,   0.00010280,  -0.00001220,
   -0.00840600,   0.00010230,  -0.00001220,
    0.00462320,   0.00460010,
"+20440823&Acc=2&Umb=1&Lmt=1&Mag=0&dT=88.3", "TSE_2044_08_23.kmz",
//2045 Feb 16
2468028.497, 0.0, -3.0, 3.0,   88.7,   88.7,
    0.16709401,   0.45625529,  -0.00002940,  -0.00005120,
   -0.26616400,   0.22355770,   0.00007840,  -0.00002680,
  -11.91637039,   0.01406600,   0.00000300,
  176.51629639,  15.00189972,   0.00000000,
    0.57177597,  -0.00006260,  -0.00001000,
    0.02551000,  -0.00006230,  -0.00001000,
    0.00473320,   0.00470960,
"+20450216&Acc=2&Umb=1&Lmt=1&Mag=0&dT=88.7", "ASE_2045_02_16.kmz",
//2045 Aug 12
2468205.238, 18.0, -3.0, 3.0,   89.1,   89.1,
    0.24066000,   0.53321987,  -0.00005350,  -0.00009020,
    0.12409400,  -0.23881440,  -0.00009660,   0.00004230,
   14.67393970,  -0.01210700,  -0.00000300,
   88.76048279,  15.00317001,   0.00000000,
    0.53094298,  -0.00000290,  -0.00001290,
   -0.01511900,  -0.00000290,  -0.00001280,
    0.00461370,   0.00459080,
"+20450812&Acc=2&Umb=1&Lmt=1&Mag=0&dT=89.1", "TSE_2045_08_12.kmz",
//2046 Feb 5
2468382.463, 23.0, -3.0, 3.0,   89.6,   89.6,
   -0.19963200,   0.46410921,  -0.00003710,  -0.00005160,
    0.32384899,   0.20130549,   0.00007380,  -0.00002400,
  -15.64727020,   0.01232800,   0.00000400,
  161.51135254,  15.00045013,   0.00000000,
    0.57336199,   0.00004560,  -0.00001000,
    0.02708800,   0.00004540,  -0.00000990,
    0.00474320,   0.00471950,
"+20460205&Acc=2&Umb=1&Lmt=1&Mag=0&dT=89.6", "ASE_2046_02_05.kmz",
//2046 Aug 2
2468559.931, 10.0, -3.0, 3.0,   90.0,   90.0,
   -0.38219300,   0.53183311,  -0.00001080,  -0.00008380,
   -0.42529899,  -0.20697869,  -0.00008980,   0.00003450,
   17.65567970,  -0.01027100,  -0.00000400,
  328.41595459,  15.00210953,   0.00000000,
    0.53621101,  -0.00007980,  -0.00001220,
   -0.00987700,  -0.00007940,  -0.00001220,
    0.00460660,   0.00458360,
"+20460802&Acc=2&Umb=1&Lmt=1&Mag=0&dT=90.0", "TSE_2046_08_02.kmz",
//2047 Jan 26
2468736.565, 2.0, -3.0, 3.0,   90.3,   90.3,
   -0.13482200,   0.49846870,  -0.00005200,  -0.00006360,
    1.06279397,   0.18109040,   0.00006610,  -0.00002460,
  -18.76766968,   0.01001800,   0.00000500,
  206.91578674,  14.99899960,   0.00000000,
    0.56168401,   0.00010520,  -0.00001090,
    0.01546900,   0.00010470,  -0.00001090,
    0.00474980,   0.00472610,
"+20470126&Acc=2&Umb=1&Lmt=1&Mag=0&dT=90.3", "PSE_2047_01_26.kmz",
//2047 Jun 23
2468884.953, 11.0, -3.0, 3.0,   90.7,   90.7,
    0.21888000,   0.52008468,  -0.00001130,  -0.00006420,
    1.36068904,  -0.05858210,  -0.00020980,   0.00000810,
   23.41617012,  -0.00044600,  -0.00000500,
  344.42907715,  14.99909019,   0.00000000,
    0.55723202,  -0.00010340,  -0.00001030,
    0.01103900,  -0.00010290,  -0.00001030,
    0.00460100,   0.00457800,
"+20470623&Acc=2&Umb=1&Lmt=1&Mag=0&dT=90.7", "PSE_2047_06_23.kmz",
//2047 Jul 22
2468914.442, 23.0, -3.0, 3.0,   90.8,   90.8,
   -0.20683300,   0.51307613,  -0.00001180,  -0.00006840,
   -1.34861004,  -0.16373120,  -0.00006500,   0.00002350,
   20.13154030,  -0.00805600,  -0.00000500,
  163.36027527,  15.00096989,   0.00000000,
    0.54987299,  -0.00012590,  -0.00001090,
    0.00371700,  -0.00012530,  -0.00001090,
    0.00460200,   0.00457910,
"+20470722&Acc=2&Umb=1&Lmt=1&Mag=0&dT=90.8", "PSE_2047_07_22.kmz",
//2047 Dec 16
2469061.493, 0.0, -3.0, 3.0,   91.1,   91.1,
    0.15609400,   0.57674301,  -0.00002800,  -0.00009550,
   -1.05876899,   0.03364000,   0.00023790,  -0.00000700,
  -23.33400917,  -0.00170000,   0.00000600,
  181.06411743,  14.99647045,   0.00000000,
    0.54056698,   0.00005890,  -0.00001290,
   -0.00554300,   0.00005860,  -0.00001280,
    0.00475060,   0.00472690,
"+20471216&Acc=2&Umb=1&Lmt=1&Mag=0&dT=91.1", "PSE_2047_12_16.kmz",
//2048 Jun 11
2469239.041, 13.0, -3.0, 3.0,   91.5,   91.5,
    0.03164600,   0.50563431,  -0.00000390,  -0.00005670,
    0.64613801,  -0.01737280,  -0.00017060,   0.00000280,
   23.14489937,   0.00265100,  -0.00000500,
   15.03363037,  14.99915028,   0.00000000,
    0.56587303,  -0.00001580,  -0.00000970,
    0.01963700,  -0.00001570,  -0.00000960,
    0.00460560,   0.00458270,
"+20480611&Acc=2&Umb=1&Lmt=1&Mag=0&dT=91.5", "ASE_2048_06_11.kmz",
//2048 Dec 5
2469416.150, 16.0, -3.0, 3.0,   92.0,   92.0,
    0.23019800,   0.58065403,  -0.00000240,  -0.00009780,
   -0.40162799,  -0.01070190,   0.00019240,   0.00000070,
  -22.49575043,  -0.00493100,   0.00000600,
   62.27962875,  14.99715042,   0.00000000,
    0.53890002,  -0.00005060,  -0.00001300,
   -0.00720200,  -0.00005030,  -0.00001300,
    0.00474450,   0.00472090,
"+20481205&Acc=2&Umb=1&Lmt=1&Mag=0&dT=92.0", "TSE_2048_12_05.kmz",
//2049 May 31
2469593.083, 14.0, -3.0, 3.0,   92.3,   92.3,
    0.00529500,   0.51556748,  -0.00000590,  -0.00006120,
   -0.11858700,   0.02221670,  -0.00013630,  -0.00000180,
   22.02430916,   0.00564900,  -0.00000500,
   30.54618073,  14.99973965,   0.00000000,
    0.56122702,   0.00008050,  -0.00001010,
    0.01501400,   0.00008010,  -0.00001000,
    0.00461230,   0.00458940,
"+20490531&Acc=2&Umb=1&Lmt=1&Mag=0&dT=92.3", "ASE_2049_05_31.kmz",
//2049 Nov 25
2469770.732, 6.0, -3.0, 3.0,   92.8,   92.8,
    0.26914200,   0.55388069,   0.00001810,  -0.00008210,
    0.27052301,  -0.05142780,   0.00012980,   0.00000670,
  -20.82802963,  -0.00790100,   0.00000500,
  273.25436401,  14.99825954,   0.00000000,
    0.54905802,  -0.00012280,  -0.00001190,
    0.00290500,  -0.00012220,  -0.00001190,
    0.00473630,   0.00471280,
"+20491125&Acc=2&Umb=1&Lmt=1&Mag=0&dT=92.8", "HSE_2049_11_25.kmz",
//2050 May 20
2469947.363, 21.0, -3.0, 3.0,   93.6,   93.6,
    0.25470400,   0.54296410,  -0.00001300,  -0.00007610,
   -0.84520203,   0.06247110,  -0.00009460,  -0.00000800,
   20.15501022,   0.00833200,  -0.00000500,
  135.84934998,  15.00070000,   0.00000000,
    0.54741001,   0.00011080,  -0.00001130,
    0.00126600,   0.00011030,  -0.00001120,
    0.00462070,   0.00459760,
"+20500520&Acc=2&Umb=1&Lmt=1&Mag=0&dT=93.6", "HSE_2050_05_20.kmz",
//2050 Nov 14
2470125.063, 14.0, -3.0, 3.0,   94.7,   94.7,
    0.41771999,   0.51573420,   0.00001710,  -0.00006380,
    0.99055803,  -0.08366200,   0.00007030,   0.00000950,
  -18.36298943,  -0.01052000,   0.00000400,
   33.89331818,  14.99967003,   0.00000000,
    0.56411302,  -0.00011160,  -0.00001060,
    0.01788500,  -0.00011100,  -0.00001050,
    0.00472620,   0.00470270,
"+20501114&Acc=2&Umb=1&Lmt=1&Mag=0&dT=94.7", "PSE_2050_11_14.kmz",
//2051 Apr 11
2470272.591, 2.0, -3.0, 3.0,   95.5,   95.5,
   -0.38758799,   0.55919588,   0.00003430,  -0.00009510,
    0.94585103,   0.16540970,  -0.00010760,  -0.00002720,
    8.24855042,   0.01493100,  -0.00000200,
  209.70674133,  15.00409985,   0.00000000,
    0.53399599,   0.00002530,  -0.00001290,
   -0.01208200,   0.00002520,  -0.00001290,
    0.00466640,   0.00464320,
"+20510411&Acc=2&Umb=1&Lmt=1&Mag=0&dT=95.5", "PSE_2051_04_11.kmz",
//2051 Oct 4
2470449.377, 21.0, -3.0, 3.0,   96.5,   96.5,
   -0.37927100,   0.48297250,   0.00001740,  -0.00005440,
   -1.14852703,  -0.15116370,   0.00007250,   0.00001640,
   -4.58144999,  -0.01566900,   0.00000100,
  137.84663391,  15.00434971,   0.00000000,
    0.56953001,   0.00004030,  -0.00000980,
    0.02327500,   0.00004010,  -0.00000980,
    0.00467490,   0.00465160,
"+20511004&Acc=2&Umb=1&Lmt=1&Mag=0&dT=96.5", "PSE_2051_10_04.kmz",
//2052 Mar 30
2470627.272, 19.0, -3.0, 3.0,   97.4,   97.4,
    0.16016699,   0.54831469,   0.00001180,  -0.00008930,
    0.38951999,   0.17170270,  -0.00004230,  -0.00002720,
    4.26382017,   0.01570700,  -0.00000100,
  103.96398926,  15.00442028,   0.00000000,
    0.53829801,  -0.00009080,  -0.00001260,
   -0.00780100,  -0.00009030,  -0.00001250,
    0.00468070,   0.00465740,
"+20520330&Acc=2&Umb=1&Lmt=1&Mag=0&dT=97.4", "TSE_2052_03_30.kmz",
//2052 Sep 22
2470803.486, 0.0, -3.0, 3.0,   98.4,   98.4,
    0.03831100,   0.50347388,  -0.00001570,  -0.00006410,
   -0.48267701,  -0.16109531,   0.00002920,   0.00001970,
   -0.26991001,  -0.01582500,   0.00000000,
  181.92547607,  15.00485992,   0.00000000,
    0.55784398,   0.00010750,  -0.00001060,
    0.01164900,   0.00010690,  -0.00001060,
    0.00465980,   0.00463660,
"+20520922&Acc=2&Umb=1&Lmt=1&Mag=0&dT=98.4", "ASE_2052_09_22.kmz",
//2053 Mar 20
2470981.797, 7.0, -3.0, 3.0,   99.4,   99.4,
    0.05291200,   0.51787239,   0.00001410,  -0.00007170,
   -0.41245800,   0.16588341,   0.00002660,  -0.00002210,
    0.05353000,   0.01606300,   0.00000000,
  283.16189575,  15.00432968,   0.00000000,
    0.55268198,  -0.00012130,  -0.00001130,
    0.00651100,  -0.00012070,  -0.00001130,
    0.00469560,   0.00467220,
"+20530320&Acc=2&Umb=1&Lmt=1&Mag=0&dT=99.4", "ASE_2053_03_20.kmz",
//2053 Sep 12
2471157.899, 10.0, -3.0, 3.0,  100.5,  100.5,
    0.32524201,   0.53643298,  -0.00003750,  -0.00008170,
    0.22689000,  -0.16857940,  -0.00002910,   0.00002490,
    3.91318989,  -0.01551200,  -0.00000100,
  330.96356201,  15.00498962,   0.00000000,
    0.54186398,   0.00009900,  -0.00001200,
   -0.00425200,   0.00009850,  -0.00001190,
    0.00464540,   0.00462230,
"+20530912&Acc=2&Umb=1&Lmt=1&Mag=0&dT=100.5", "TSE_2053_09_12.kmz",
//2054 Mar 9
2471336.023, 13.0, -3.0, 3.0,  101.5,  101.5,
    0.56600499,   0.48941809,  -0.00001830,  -0.00005740,
   -1.04965997,   0.15395090,   0.00007230,  -0.00001730,
   -4.28061008,   0.01594100,   0.00000100,
   12.40065002,  15.00382042,   0.00000000,
    0.56799001,  -0.00009100,  -0.00001020,
    0.02174300,  -0.00009060,  -0.00001010,
    0.00471040,   0.00468700,
"+20540309&Acc=2&Umb=1&Lmt=1&Mag=0&dT=101.5", "PSE_2054_03_09.kmz",
//2054 Aug 3
2471483.253, 18.0, -3.0, 3.0,  102.4,  102.4,
   -0.31496301,   0.57296699,  -0.00000030,  -0.00009720,
   -1.46108902,  -0.10786220,  -0.00003210,   0.00001750,
   17.29013062,  -0.01077800,  -0.00000400,
   88.44229889,  15.00236034,   0.00000000,
    0.53089398,  -0.00002280,  -0.00001280,
   -0.01516800,  -0.00002270,  -0.00001270,
    0.00460710,   0.00458420,
"+20540803&Acc=2&Umb=1&Lmt=1&Mag=0&dT=102.4", "PSE_2054_08_03.kmz",
//2054 Sep 2
2471512.548, 1.0, -3.0, 3.0,  102.5,  102.5,
    0.20258600,   0.55893719,  -0.00003060,  -0.00009500,
    1.00549495,  -0.16647930,  -0.00010460,   0.00002750,
    7.88290977,  -0.01479300,  -0.00000200,
  195.05238342,  15.00471020,   0.00000000,
    0.53228903,   0.00003190,  -0.00001280,
   -0.01378000,   0.00003170,  -0.00001280,
    0.00463250,   0.00460940,
"+20540902&Acc=2&Umb=1&Lmt=1&Mag=0&dT=102.5", "PSE_2054_09_02.kmz",
//2055 Jan 27
2471660.246, 18.0, -3.0, 3.0,  103.2,  103.2,
   -0.13582900,   0.50384301,  -0.00002320,  -0.00005830,
    1.14805496,   0.08199030,   0.00006610,  -0.00000870,
  -18.32369041,   0.01066200,   0.00000500,
   86.82602692,  14.99925041,   0.00000000,
    0.57127899,   0.00006870,  -0.00001010,
    0.02501600,   0.00006840,  -0.00001010,
    0.00474940,   0.00472580,
"+20550127&Acc=2&Umb=1&Lmt=1&Mag=0&dT=103.2", "PSE_2055_01_27.kmz",
//2055 Jul 24
2471837.915, 10.0, -3.0, 3.0,  104.2,  104.2,
   -0.07948500,   0.55823022,   0.00000280,  -0.00008520,
   -0.79749501,  -0.06995150,  -0.00009360,   0.00000990,
   19.81361961,  -0.00862800,  -0.00000500,
  328.34844971,  15.00123024,   0.00000000,
    0.53937101,  -0.00010590,  -0.00001190,
   -0.00673300,  -0.00010540,  -0.00001180,
    0.00460210,   0.00457920,
"+20550724&Acc=2&Umb=1&Lmt=1&Mag=0&dT=104.2", "TSE_2055_07_24.kmz",
//2056 Jan 16
2472014.428, 22.0, -3.0, 3.0,  105.3,  105.3,
   -0.18878600,   0.53814572,  -0.00002320,  -0.00007340,
    0.40431899,   0.04952310,   0.00012150,  -0.00000580,
  -20.84804916,   0.00793400,   0.00000500,
  147.56910706,  14.99790001,   0.00000000,
    0.55718100,   0.00012730,  -0.00001130,
    0.01098800,   0.00012670,  -0.00001130,
    0.00475370,   0.00473000,
"+20560116&Acc=2&Umb=1&Lmt=1&Mag=0&dT=105.3", "ASE_2056_01_16.kmz",
//2056 Jul 12
2472192.349, 20.0, -3.0, 3.0,  106.3,  106.3,
   -0.19617300,   0.52878112,   0.00001560,  -0.00006760,
   -0.03170700,  -0.02950300,  -0.00014100,   0.00000290,
   21.76135063,  -0.00608100,  -0.00000500,
  118.53376770,  15.00014973,   0.00000000,
    0.55416799,  -0.00010230,  -0.00001060,
    0.00799100,  -0.00010180,  -0.00001050,
    0.00459970,   0.00457680,
"+20560712&Acc=2&Umb=1&Lmt=1&Mag=0&dT=106.3", "ASE_2056_07_12.kmz",
//2057 Jan 5
2472368.908, 10.0, -3.0, 3.0,  107.4,  107.4,
    0.12033800,   0.57226640,  -0.00002090,  -0.00009220,
   -0.28177100,   0.00942140,   0.00018310,  -0.00000050,
  -22.52547073,   0.00487600,   0.00000600,
  328.63067627,  14.99691963,   0.00000000,
    0.54304302,   0.00007700,  -0.00001270,
   -0.00307900,   0.00007670,  -0.00001260,
    0.00475480,   0.00473120,
"+20570105&Acc=2&Umb=1&Lmt=1&Mag=0&dT=107.4", "TSE_2057_01_05.kmz",
//2057 Jul 1
2472546.486, 0.0, -3.0, 3.0,  108.4,  108.4,
    0.15240000,   0.50751871,   0.00000300,  -0.00005750,
    0.74863100,   0.00983530,  -0.00017460,  -0.00000200,
   23.00357056,  -0.00319200,  -0.00000500,
  178.95947266,  14.99934959,   0.00000000,
    0.56472099,  -0.00004250,  -0.00000970,
    0.01849100,  -0.00004230,  -0.00000970,
    0.00459980,   0.00457690,
"+20570701&Acc=2&Umb=1&Lmt=1&Mag=0&dT=108.4", "ASE_2057_07_01.kmz",
//2057 Dec 26
2472723.552, 1.0, -3.0, 3.0,  109.3,  109.3,
   -0.19915700,   0.58180499,   0.00002410,  -0.00009900,
   -0.93001997,  -0.03588380,   0.00023350,   0.00000750,
  -23.34527016,   0.00160200,   0.00000600,
  194.88423157,  14.99641991,   0.00000000,
    0.53848600,  -0.00001030,  -0.00001310,
   -0.00761300,  -0.00001030,  -0.00001310,
    0.00475340,   0.00472980,
"+20571226&Acc=2&Umb=1&Lmt=1&Mag=0&dT=109.3", "TSE_2057_12_26.kmz",
//2058 May 22
2472870.944, 11.0, -3.0, 3.0,  110.1,  110.1,
    0.56028599,   0.49982601,   0.00000110,  -0.00006120,
   -1.20791101,   0.15412091,  -0.00007490,  -0.00002040,
   20.48373032,   0.00771700,  -0.00000500,
  345.81442261,  15.00043011,   0.00000000,
    0.55811101,   0.00009150,  -0.00001040,
    0.01191400,   0.00009100,  -0.00001030,
    0.00461980,   0.00459680,
"+20580522&Acc=2&Umb=1&Lmt=1&Mag=0&dT=110.1", "PSE_2058_05_22.kmz",
//2058 Jun 21
2472900.514, 0.0, -3.0, 3.0,  110.3,  110.3,
   -0.31122199,   0.50958568,   0.00001690,  -0.00005910,
    1.46354902,   0.05005070,  -0.00020780,  -0.00000670,
   23.42871094,  -0.00009400,  -0.00000500,
  179.53883362,  14.99905014,   0.00000000,
    0.56271702,   0.00007020,  -0.00000990,
    0.01649700,   0.00006990,  -0.00000980,
    0.00460200,   0.00457900,
"+20580621&Acc=2&Umb=1&Lmt=1&Mag=0&dT=110.3", "PSE_2058_06_21.kmz",
//2058 Nov 16
2473048.641, 3.0, -3.0, 3.0,  111.2,  111.2,
    0.18428500,   0.51359898,   0.00005040,  -0.00007150,
    1.12699199,  -0.18608040,   0.00006140,   0.00002740,
  -18.76819038,  -0.00990800,   0.00000500,
  228.82821655,  14.99944019,   0.00000000,
    0.55306399,  -0.00010940,  -0.00001150,
    0.00689200,  -0.00010880,  -0.00001140,
    0.00472730,   0.00470380,
"+20581116&Acc=2&Umb=1&Lmt=1&Mag=0&dT=111.2", "PSE_2058_11_16.kmz",
//2059 May 11
2473225.307, 19.0, -3.0, 3.0,  112.2,  112.2,
   -0.01214900,   0.51977021,   0.00002580,  -0.00007610,
   -0.54813600,   0.19789781,  -0.00008800,  -0.00003070,
   18.03314018,   0.01009800,  -0.00000400,
  105.89466858,  15.00152016,   0.00000000,
    0.54360402,   0.00012050,  -0.00001170,
   -0.00252100,   0.00011990,  -0.00001160,
    0.00462980,   0.00460670,
"+20590511&Acc=2&Umb=1&Lmt=1&Mag=0&dT=112.2", "TSE_2059_05_11.kmz",
//2059 Nov 5
2473402.888, 9.0, -3.0, 3.0,  113.3,  113.3,
    0.03280800,   0.47272870,   0.00004820,  -0.00005520,
    0.47100800,  -0.20413721,   0.00006680,   0.00002550,
  -15.72185993,  -0.01212900,   0.00000400,
  319.11587524,  15.00092030,   0.00000000,
    0.56738901,  -0.00007600,  -0.00001020,
    0.02114600,  -0.00007560,  -0.00001020,
    0.00471560,   0.00469210,
"+20591105&Acc=2&Umb=1&Lmt=1&Mag=0&dT=113.3", "ASE_2059_11_05.kmz",
//2060 Apr 30
2473579.924, 10.0, -3.0, 3.0,  114.1,  114.1,
   -0.18633001,   0.53155172,   0.00004500,  -0.00008850,
    0.18247101,   0.23460589,  -0.00010540,  -0.00004100,
   15.06877041,   0.01204900,  -0.00000300,
  330.71163940,  15.00255966,   0.00000000,
    0.53364098,   0.00004740,  -0.00001280,
   -0.01243400,   0.00004720,  -0.00001270,
    0.00464110,   0.00461800,
"+20600430&Acc=2&Umb=1&Lmt=1&Mag=0&dT=114.1", "TSE_2060_04_30.kmz",
//2060 Oct 24
2473756.892, 9.0, -3.0, 3.0,  115.2,  115.2,
   -0.29760799,   0.45295021,   0.00003950,  -0.00004970,
   -0.14683799,  -0.22110771,   0.00007100,   0.00002590,
  -12.06838036,  -0.01382100,   0.00000200,
  318.97665405,  15.00236988,   0.00000000,
    0.57207000,   0.00002380,  -0.00000980,
    0.02580300,   0.00002370,  -0.00000980,
    0.00470180,   0.00467840,
"+20601024&Acc=2&Umb=1&Lmt=1&Mag=0&dT=115.2", "ASE_2060_10_24.kmz",
//2061 Apr 20
2473934.623, 3.0, -3.0, 3.0,  116.2,  116.2,
   -0.39217201,   0.52077597,   0.00006430,  -0.00008580,
    0.87432301,   0.25394091,  -0.00011550,  -0.00004390,
   11.66526985,   0.01361800,  -0.00000200,
  225.28179932,  15.00341988,   0.00000000,
    0.53497303,  -0.00006020,  -0.00001270,
   -0.01110900,  -0.00005990,  -0.00001270,
    0.00465410,   0.00463090,
"+20610420&Acc=2&Umb=1&Lmt=1&Mag=0&dT=116.2", "TSE_2061_04_20.kmz",
//2061 Oct 13
2474110.939, 11.0, -3.0, 3.0,  117.3,  117.3,
   -0.23491301,   0.46136871,   0.00001940,  -0.00005560,
   -0.96564603,  -0.24275100,   0.00008880,   0.00003090,
   -8.05585003,  -0.01491500,   0.00000100,
  348.47225952,  15.00358963,   0.00000000,
    0.56277299,   0.00009460,  -0.00001040,
    0.01655300,   0.00009410,  -0.00001040,
    0.00468660,   0.00466330,
"+20611013&Acc=2&Umb=1&Lmt=1&Mag=0&dT=117.3", "ASE_2061_10_13.kmz",
//2062 Mar 11
2474259.685, 4.0, -3.0, 3.0,  118.2,  118.2,
    0.28882501,   0.46763989,  -0.00000850,  -0.00006040,
   -1.00961697,   0.25726199,   0.00007160,  -0.00003490,
   -3.62056994,   0.01575100,   0.00000000,
  237.51289368,  15.00386047,   0.00000000,
    0.55800802,  -0.00011170,  -0.00001090,
    0.01181200,  -0.00011110,  -0.00001090,
    0.00470810,   0.00468460,
"+20620311&Acc=2&Umb=1&Lmt=1&Mag=0&dT=118.2", "PSE_2062_03_11.kmz",
//2062 Sep 3
2474435.871, 9.0, -3.0, 3.0,  119.2,  119.2,
    0.52210897,   0.50474769,  -0.00006230,  -0.00007930,
    0.87683702,  -0.26625451,  -0.00008360,   0.00004400,
    7.37100983,  -0.01467600,  -0.00000200,
  315.16360474,  15.00465012,   0.00000000,
    0.53765398,   0.00009000,  -0.00001230,
   -0.00844200,   0.00008960,  -0.00001220,
    0.00463420,   0.00461120,
"+20620903&Acc=2&Umb=1&Lmt=1&Mag=0&dT=119.2", "PSE_2062_09_03.kmz",
//2063 Feb 28
2474613.822, 8.0, -3.0, 3.0,  120.1,  120.1,
    0.28056800,   0.44843099,  -0.00002420,  -0.00005010,
   -0.23166800,   0.23748270,   0.00005370,  -0.00002820,
   -7.90683985,   0.01519100,   0.00000200,
  296.88772583,  15.00302029,   0.00000000,
    0.57146400,  -0.00006220,  -0.00001000,
    0.02520000,  -0.00006190,  -0.00000990,
    0.00472190,   0.00469840,
"+20630228&Acc=2&Umb=1&Lmt=1&Mag=0&dT=120.1", "ASE_2063_02_28.kmz",
//2063 Aug 24
2474790.557, 1.0, -3.0, 3.0,  121.2,  121.2,
   -0.07017500,   0.52327859,  -0.00002950,  -0.00008830,
    0.34422901,  -0.25967699,  -0.00008470,   0.00004580,
   11.13078022,  -0.01360900,  -0.00000200,
  194.36822510,  15.00407028,   0.00000000,
    0.53143799,   0.00000810,  -0.00001290,
   -0.01462700,   0.00000810,  -0.00001280,
    0.00462300,   0.00460000,
"+20630824&Acc=2&Umb=1&Lmt=1&Mag=0&dT=121.2", "TSE_2063_08_24.kmz",
//2064 Feb 17
2474967.792, 7.0, -3.0, 3.0,  122.2,  122.2,
   -0.16082899,   0.45534030,  -0.00003210,  -0.00005070,
    0.32171300,   0.22245960,   0.00004960,  -0.00002650,
  -12.02795982,   0.01402600,   0.00000300,
  281.51879883,  15.00185013,   0.00000000,
    0.57241601,   0.00004800,  -0.00001000,
    0.02614700,   0.00004770,  -0.00000990,
    0.00473380,   0.00471020,
"+20640217&Acc=2&Umb=1&Lmt=1&Mag=0&dT=122.2", "ASE_2064_02_17.kmz",
//2064 Aug 12
2475145.240, 18.0, -3.0, 3.0,  123.3,  123.3,
   -0.07037700,   0.51907349,  -0.00002130,  -0.00008110,
   -0.47837499,  -0.23315150,  -0.00006510,   0.00003830,
   14.55016041,  -0.01218300,  -0.00000300,
   88.77207947,  15.00317955,   0.00000000,
    0.53726602,  -0.00009780,  -0.00001220,
   -0.00882700,  -0.00009730,  -0.00001210,
    0.00461410,   0.00459110,
"+20640812&Acc=2&Umb=1&Lmt=1&Mag=0&dT=123.3", "TSE_2064_08_12.kmz",
//2065 Feb 5
2475321.911, 10.0, -3.0, 3.0,  124.4,  124.4,
   -0.34694800,   0.48884830,  -0.00004070,  -0.00006290,
    0.97591901,   0.21044900,   0.00004430,  -0.00002870,
  -15.69262981,   0.01227600,   0.00000400,
  326.51922607,  15.00049973,   0.00000000,
    0.56041801,   0.00011290,  -0.00001100,
    0.01420900,   0.00011230,  -0.00001090,
    0.00474280,   0.00471920,
"+20650205&Acc=2&Umb=1&Lmt=1&Mag=0&dT=124.4", "PSE_2065_02_05.kmz",
//2065 Jul 3
2475470.232, 18.0, -3.0, 3.0,  125.2,  125.2,
    0.49852201,   0.51231283,  -0.00003360,  -0.00006260,
    1.39284098,  -0.09847540,  -0.00020500,   0.00001300,
   22.85247040,  -0.00344100,  -0.00000500,
   88.87412262,  14.99946022,   0.00000000,
    0.55791402,  -0.00010540,  -0.00001020,
    0.01171800,  -0.00010490,  -0.00001020,
    0.00459940,   0.00457650,
"+20650703&Acc=2&Umb=1&Lmt=1&Mag=0&dT=125.2", "PSE_2065_07_03.kmz",
//2065 Aug 2
2475499.732, 6.0, -3.0, 3.0,  125.4,  125.4,
   -0.24687999,   0.50017041,  -0.00001090,  -0.00006580,
   -1.27270401,  -0.19401599,  -0.00004950,   0.00002730,
   17.59382057,  -0.01034800,  -0.00000400,
  268.41497803,  15.00205994,   0.00000000,
    0.55113798,  -0.00012490,  -0.00001090,
    0.00497600,  -0.00012430,  -0.00001080,
    0.00460730,   0.00458440,
"+20650802&Acc=2&Umb=1&Lmt=1&Mag=0&dT=125.4", "PSE_2065_08_02.kmz",
//2065 Dec 27
2475646.861, 9.0, -3.0, 3.0,  126.1,  126.1,
    0.34354201,   0.57266837,  -0.00005220,  -0.00009510,
   -1.03038800,   0.08242680,   0.00023440,  -0.00001530,
  -23.28576088,   0.00176800,   0.00000600,
  314.71313477,  14.99643040,   0.00000000,
    0.54037499,   0.00004920,  -0.00001290,
   -0.00573400,   0.00004900,  -0.00001290,
    0.00475390,   0.00473020,
"+20651227&Acc=2&Umb=1&Lmt=1&Mag=0&dT=126.1", "PSE_2065_12_27.kmz",
//2066 Jun 22
2475824.310, 19.0, -3.0, 3.0,  127.2,  127.2,
   -0.13370501,   0.50265813,  -0.00001130,  -0.00005630,
    0.75273299,  -0.05670910,  -0.00017610,   0.00000740,
   23.41819000,  -0.00037600,  -0.00000600,
  104.43367767,  14.99903965,   0.00000000,
    0.56569898,   0.00000000,  -0.00000970,
    0.01946400,   0.00000000,  -0.00000960,
    0.00460150,   0.00457860,
"+20660622&Acc=2&Umb=1&Lmt=1&Mag=0&dT=127.2", "ASE_2066_06_22.kmz",
//2066 Dec 17
2476001.516, 0.0, -3.0, 3.0,  128.3,  128.3,
   -0.20250200,   0.57886010,   0.00000540,  -0.00009700,
   -0.41803101,   0.03687790,   0.00020230,  -0.00000740,
  -23.34728050,  -0.00158200,   0.00000600,
  181.02413940,  14.99645996,   0.00000000,
    0.53954202,  -0.00003520,  -0.00001300,
   -0.00656300,  -0.00003510,  -0.00001290,
    0.00475060,   0.00472700,
"+20661217&Acc=2&Umb=1&Lmt=1&Mag=0&dT=128.3", "TSE_2066_12_17.kmz",
//2067 Jun 11
2476178.363, 21.0, -3.0, 3.0,  129.3,  129.3,
    0.15015300,   0.51736069,  -0.00002270,  -0.00006190,
   -0.04359100,  -0.01696530,  -0.00014750,   0.00000300,
   23.12772942,   0.00272100,  -0.00000600,
  135.03097534,  14.99919033,   0.00000000,
    0.56012303,   0.00007960,  -0.00001010,
    0.01391600,   0.00007920,  -0.00001010,
    0.00460560,   0.00458270,
"+20670611&Acc=2&Umb=1&Lmt=1&Mag=0&dT=129.3", "ASE_2067_06_11.kmz",
//2067 Dec 6
2476356.086, 14.0, -3.0, 3.0,  130.4,  130.4,
   -0.02978000,   0.55434018,   0.00002100,  -0.00008130,
    0.28498799,  -0.00897010,   0.00014670,   0.00000030,
  -22.53071976,  -0.00484100,   0.00000600,
   32.25571823,  14.99705982,   0.00000000,
    0.55038500,  -0.00011320,  -0.00001190,
    0.00422600,  -0.00011270,  -0.00001180,
    0.00474500,   0.00472140,
"+20671206&Acc=2&Umb=1&Lmt=1&Mag=0&dT=130.4", "HSE_2067_12_06.kmz",
//2068 May 31
2476532.664, 4.0, -3.0, 3.0,  131.3,  131.3,
    0.06617700,   0.54819739,  -0.00001340,  -0.00007770,
   -0.79488403,   0.02448380,  -0.00011180,  -0.00000270,
   22.02277946,   0.00564400,  -0.00000500,
  240.53245544,  14.99981976,   0.00000000,
    0.54594201,   0.00011580,  -0.00001130,
   -0.00019500,   0.00011520,  -0.00001130,
    0.00461180,   0.00458880,
"+20680531&Acc=2&Umb=1&Lmt=1&Mag=0&dT=131.3", "TSE_2068_05_31.kmz",
//2068 Nov 24
2476710.398, 22.0, -3.0, 3.0,  132.4,  132.4,
    0.33383399,   0.51846659,   0.00001460,  -0.00006350,
    1.00312603,  -0.04853090,   0.00009190,   0.00000500,
  -20.83827972,  -0.00789100,   0.00000500,
  153.25810242,  14.99816990,   0.00000000,
    0.56551498,  -0.00010860,  -0.00001050,
    0.01928100,  -0.00010810,  -0.00001050,
    0.00473690,   0.00471330,
"+20681124&Acc=2&Umb=1&Lmt=1&Mag=0&dT=132.4", "PSE_2068_11_24.kmz",
//2069 Apr 21
2476857.924, 10.0, -3.0, 3.0,  133.3,  133.3,
   -0.37409201,   0.56460118,   0.00003940,  -0.00009620,
    1.00026298,   0.14793260,  -0.00013660,  -0.00002430,
   12.12613010,   0.01368500,  -0.00000300,
  330.34121704,  15.00341988,   0.00000000,
    0.53311199,   0.00001970,  -0.00001290,
   -0.01296100,   0.00001960,  -0.00001290,
    0.00465250,   0.00462940,
"+20690421&Acc=2&Umb=1&Lmt=1&Mag=0&dT=133.3", "PSE_2069_04_21.kmz",
//2069 May 20
2476887.245, 18.0, -3.0, 3.0,  133.5,  133.5,
    0.23658600,   0.57323867,  -0.00000570,  -0.00009440,
   -1.46765101,   0.06703430,  -0.00005930,  -0.00001030,
   20.21186066,   0.00825300,  -0.00000500,
   90.83296204,  15.00074005,   0.00000000,
    0.53396702,   0.00006090,  -0.00001260,
   -0.01211000,   0.00006060,  -0.00001250,
    0.00462010,   0.00459710,
"+20690520&Acc=2&Umb=1&Lmt=1&Mag=0&dT=133.5", "PSE_2069_05_20.kmz",
//2069 Oct 15
2477034.681, 4.0, -3.0, 3.0,  134.4,  134.4,
   -0.51142299,   0.48632449,   0.00002730,  -0.00005490,
   -1.15554202,  -0.14153440,   0.00009710,   0.00001530,
   -8.71068001,  -0.01501000,   0.00000200,
  243.57150269,  15.00349045,   0.00000000,
    0.57011497,   0.00005170,  -0.00000990,
    0.02385800,   0.00005150,  -0.00000980,
    0.00468910,   0.00466570,
"+20691015&Acc=2&Umb=1&Lmt=1&Mag=0&dT=134.4", "PSE_2069_10_15.kmz",
//2070 Apr 11
2477212.608, 3.0, -3.0, 3.0,  135.4,  135.4,
    0.11634100,   0.55045623,   0.00002160,  -0.00008910,
    0.41447100,   0.16071419,  -0.00006960,  -0.00002520,
    8.41018963,   0.01490300,  -0.00000200,
  224.73706055,  15.00405025,   0.00000000,
    0.53808701,  -0.00009320,  -0.00001250,
   -0.00801100,  -0.00009280,  -0.00001240,
    0.00466670,   0.00464340,
"+20700411&Acc=2&Umb=1&Lmt=1&Mag=0&dT=135.4", "TSE_2070_04_11.kmz",
//2070 Oct 4
2477388.798, 7.0, -3.0, 3.0,  136.5,  136.5,
   -0.22296400,   0.50618988,   0.00000150,  -0.00006510,
   -0.44891101,  -0.15802170,   0.00005260,   0.00001950,
   -4.51254988,  -0.01565400,   0.00000100,
  287.82974243,  15.00442028,   0.00000000,
    0.55776101,   0.00012050,  -0.00001070,
    0.01156600,   0.00011990,  -0.00001070,
    0.00467350,   0.00465030,
"+20701004&Acc=2&Umb=1&Lmt=1&Mag=0&dT=136.5", "ASE_2070_10_04.kmz",
//2071 Mar 31
2477567.126, 15.0, -3.0, 3.0,  137.4,  137.4,
    0.10209700,   0.51732367,   0.00001990,  -0.00007090,
   -0.35986501,   0.16181970,  -0.00000090,  -0.00002140,
    4.35244989,   0.01572100,  -0.00000100,
   43.98604965,  15.00432968,   0.00000000,
    0.55273402,  -0.00012380,  -0.00001120,
    0.00656400,  -0.00012320,  -0.00001120,
    0.00468160,   0.00465830,
"+20710331&Acc=2&Umb=1&Lmt=1&Mag=0&dT=137.4", "ASE_2071_03_31.kmz",
//2071 Sep 23
2477743.223, 17.0, -3.0, 3.0,  138.5,  138.5,
   -0.10334200,   0.53709328,  -0.00000960,  -0.00008270,
    0.30817300,  -0.17189540,  -0.00000750,   0.00002570,
   -0.31420001,  -0.01579400,   0.00000000,
   76.93184662,  15.00494957,   0.00000000,
    0.54175299,   0.00011500,  -0.00001210,
   -0.00436300,   0.00011440,  -0.00001200,
    0.00465860,   0.00463540,
"+20710923&Acc=2&Umb=1&Lmt=1&Mag=0&dT=138.5", "TSE_2071_09_23.kmz",
//2072 Mar 19
2477921.341, 20.0, -3.0, 3.0,  139.6,  139.6,
    0.26349601,   0.48749220,  -0.00000070,  -0.00005680,
   -1.11326206,   0.15665150,   0.00004980,  -0.00001750,
    0.02934000,   0.01608700,   0.00000000,
  118.16259003,  15.00424957,   0.00000000,
    0.56776297,  -0.00007420,  -0.00001010,
    0.02151800,  -0.00007380,  -0.00001000,
    0.00469680,   0.00467340,
"+20720319&Acc=2&Umb=1&Lmt=1&Mag=0&dT=139.6", "PSE_2072_03_19.kmz",
//2072 Sep 12
2478097.875, 9.0, -3.0, 3.0,  140.7,  140.7,
    0.29777199,   0.55619049,  -0.00002750,  -0.00009460,
    0.91848302,  -0.17622641,  -0.00007460,   0.00002920,
    3.77284002,  -0.01550600,  -0.00000100,
  315.99017334,  15.00504971,   0.00000000,
    0.53279698,   0.00002170,  -0.00001290,
   -0.01327500,   0.00002160,  -0.00001280,
    0.00464500,   0.00462180,
"+20720912&Acc=2&Umb=1&Lmt=1&Mag=0&dT=140.7", "TSE_2072_09_12.kmz",
//2073 Feb 7
2478245.581, 2.0, -3.0, 3.0,  141.6,  141.6,
   -0.21807700,   0.49966681,  -0.00002170,  -0.00005820,
    1.14498305,   0.11048680,   0.00004150,  -0.00001210,
  -15.15655994,   0.01283200,   0.00000400,
  206.50175476,  15.00076008,   0.00000000,
    0.57026702,   0.00007290,  -0.00001020,
    0.02400900,   0.00007260,  -0.00001010,
    0.00474190,   0.00471830,
"+20730207&Acc=2&Umb=1&Lmt=1&Mag=0&dT=141.6", "PSE_2073_02_07.kmz",
//2073 Aug 3
2478423.219, 17.0, -3.0, 3.0,  142.7,  142.7,
   -0.30171800,   0.55115569,   0.00000930,  -0.00008320,
   -0.83514100,  -0.10260300,  -0.00007130,   0.00001480,
   17.18993950,  -0.01086100,  -0.00000400,
   73.44228363,  15.00234032,   0.00000000,
    0.54054397,  -0.00010130,  -0.00001180,
   -0.00556600,  -0.00010080,  -0.00001180,
    0.00460780,   0.00458490,
"+20730803&Acc=2&Umb=1&Lmt=1&Mag=0&dT=142.7", "TSE_2073_08_03.kmz",
//2074 Jan 27
2478599.781, 7.0, -3.0, 3.0,  143.6,  143.6,
    0.07283400,   0.53534532,  -0.00003980,  -0.00007360,
    0.44234100,   0.08635120,   0.00009720,  -0.00001100,
  -18.33945084,   0.01063300,   0.00000500,
  281.84396362,  14.99932003,   0.00000000,
    0.55613101,   0.00011440,  -0.00001140,
    0.00994300,   0.00011390,  -0.00001130,
    0.00474870,   0.00472510,
"+20740127&Acc=2&Umb=1&Lmt=1&Mag=0&dT=143.6", "ASE_2074_01_27.kmz",
//2074 Jul 24
2478777.632, 3.0, -3.0, 3.0,  144.7,  144.7,
   -0.10727100,   0.52359110,   0.00000400,  -0.00006620,
   -0.11184300,  -0.06512920,  -0.00012200,   0.00000740,
   19.78580093,  -0.00866500,  -0.00000400,
  223.33976746,  15.00115013,   0.00000000,
    0.55524099,  -0.00010320,  -0.00001050,
    0.00905800,  -0.00010270,  -0.00001040,
    0.00460300,   0.00458010,
"+20740724&Acc=2&Umb=1&Lmt=1&Mag=0&dT=144.7", "ASE_2074_07_24.kmz",
//2075 Jan 16
2478954.275, 19.0, -3.0, 3.0,  145.8,  145.8,
    0.25383100,   0.57102323,  -0.00003830,  -0.00009260,
   -0.25730601,   0.05360840,   0.00016460,  -0.00000780,
  -20.79369926,   0.00799500,   0.00000500,
  102.56072235,  14.99802017,   0.00000000,
    0.54243499,   0.00006740,  -0.00001270,
   -0.00368400,   0.00006700,  -0.00001270,
    0.00475290,   0.00472920,
"+20750116&Acc=2&Umb=1&Lmt=1&Mag=0&dT=145.8", "TSE_2075_01_16.kmz",
//2075 Jul 13
2479131.754, 6.0, -3.0, 3.0,  146.9,  146.9,
   -0.01239900,   0.50623649,  -0.00000300,  -0.00005720,
    0.65995902,  -0.02767040,  -0.00016110,   0.00000230,
   21.78327942,  -0.00604000,  -0.00000500,
  268.52969360,  15.00008011,   0.00000000,
    0.56504798,  -0.00002730,  -0.00000970,
    0.01881700,  -0.00002720,  -0.00000970,
    0.00460020,   0.00457730,
"+20750713&Acc=2&Umb=1&Lmt=1&Mag=0&dT=146.9", "ASE_2075_07_13.kmz",
//2076 Jan 6
2479308.922, 10.0, -3.0, 3.0,  148.0,  148.0,
   -0.05238400,   0.58246690,   0.00000220,  -0.00009900,
   -0.93865001,   0.01238630,   0.00022590,  -0.00000090,
  -22.47513008,   0.00498900,   0.00000600,
  328.59515381,  14.99697971,   0.00000000,
    0.53866702,  -0.00001930,  -0.00001310,
   -0.00743400,  -0.00001920,  -0.00001310,
    0.00475450,   0.00473090,
"+20760106&Acc=2&Umb=1&Lmt=1&Mag=0&dT=148.0", "TSE_2076_01_06.kmz",
//2076 Jun 1
2479456.230, 18.0, -3.0, 3.0,  148.9,  148.9,
    0.55791801,   0.51135778,  -0.00000510,  -0.00006340,
   -1.29718399,   0.11847800,  -0.00008560,  -0.00001610,
   22.23944092,   0.00498200,  -0.00000500,
   90.47128296,  14.99962044,   0.00000000,
    0.55674398,   0.00009240,  -0.00001040,
    0.01055400,   0.00009190,  -0.00001040,
    0.00461110,   0.00458820,
"+20760601&Acc=2&Umb=1&Lmt=1&Mag=0&dT=148.9", "PSE_2076_06_01.kmz",
//2076 Jul 1
2479485.785, 7.0, -3.0, 3.0,  149.1,  149.1,
    0.05155500,   0.51310837,  -0.00000900,  -0.00005990,
    1.40182495,   0.01012000,  -0.00020230,  -0.00000190,
   23.02268028,  -0.00310700,  -0.00000500,
  283.96859741,  14.99934959,   0.00000000,
    0.56204402,   0.00006670,  -0.00000990,
    0.01582800,   0.00006640,  -0.00000990,
    0.00459970,   0.00457680,
"+20760701&Acc=2&Umb=1&Lmt=1&Mag=0&dT=149.1", "PSE_2076_07_01.kmz",
//2076 Nov 26
2479633.988, 12.0, -3.0, 3.0,  149.8,  149.8,
    0.46169800,   0.52331382,   0.00003700,  -0.00007240,
    1.05380797,  -0.14963810,   0.00008790,   0.00002210,
  -21.14557076,  -0.00719800,   0.00000600,
    3.12841010,  14.99796963,   0.00000000,
    0.55443001,  -0.00012570,  -0.00001150,
    0.00825100,  -0.00012510,  -0.00001140,
    0.00473790,   0.00471430,
"+20761126&Acc=2&Umb=1&Lmt=1&Mag=0&dT=149.8", "PSE_2076_11_26.kmz",
//2077 May 22
2479810.615, 3.0, -3.0, 3.0,  150.9,  150.9,
    0.29312500,   0.53319740,   0.00001100,  -0.00007890,
   -0.50847799,   0.16522419,  -0.00010930,  -0.00002610,
   20.49352074,   0.00767400,  -0.00000500,
  225.80885315,  15.00051022,   0.00000000,
    0.54220903,   0.00010460,  -0.00001170,
   -0.00390900,   0.00010410,  -0.00001170,
    0.00461920,   0.00459620,
"+20770522&Acc=2&Umb=1&Lmt=1&Mag=0&dT=150.9", "TSE_2077_05_22.kmz",
//2077 Nov 15
2479988.214, 17.0, -3.0, 3.0,  152.0,  152.0,
    0.09753200,   0.48229790,   0.00004820,  -0.00005610,
    0.46522501,  -0.17609610,   0.00009090,   0.00002200,
  -18.75906944,  -0.00993700,   0.00000500,
   78.83480072,  14.99936008,   0.00000000,
    0.56875497,  -0.00007600,  -0.00001020,
    0.02250400,  -0.00007560,  -0.00001020,
    0.00472780,   0.00470430,
"+20771115&Acc=2&Umb=1&Lmt=1&Mag=0&dT=152.0", "ASE_2077_11_15.kmz",
//2078 May 11
2480165.248, 18.0, -3.0, 3.0,  153.1,  153.1,
   -0.03716100,   0.54408091,   0.00004130,  -0.00009110,
    0.18248101,   0.20625859,  -0.00012850,  -0.00003630,
   18.12167931,   0.01000100,  -0.00000400,
   90.88990784,  15.00154018,   0.00000000,
    0.53270602,   0.00003630,  -0.00001280,
   -0.01336400,   0.00003610,  -0.00001270,
    0.00462920,   0.00460610,
"+20780511&Acc=2&Umb=1&Lmt=1&Mag=0&dT=153.1", "TSE_2078_05_11.kmz",
//2078 Nov 4
2480342.205, 17.0, -3.0, 3.0,  154.2,  154.2,
   -0.05813000,   0.46238831,   0.00003730,  -0.00005080,
   -0.22388200,  -0.20061190,   0.00009700,   0.00002370,
  -15.63582039,  -0.01218400,   0.00000300,
   79.12265015,  15.00094032,   0.00000000,
    0.57281899,   0.00002000,  -0.00000980,
    0.02654900,   0.00001990,  -0.00000980,
    0.00471510,   0.00469160,
"+20781104&Acc=2&Umb=1&Lmt=1&Mag=0&dT=154.2", "ASE_2078_11_04.kmz",
//2079 May 1
2480519.952, 11.0, -3.0, 3.0,  155.3,  155.3,
   -0.27683201,   0.53025001,   0.00006600,  -0.00008710,
    0.86999398,   0.23142490,  -0.00013940,  -0.00004000,
   15.20186043,   0.01198000,  -0.00000300,
  345.71423340,  15.00251007,   0.00000000,
    0.53468502,  -0.00006800,  -0.00001270,
   -0.01139600,  -0.00006770,  -0.00001260,
    0.00464100,   0.00461790,
"+20790501&Acc=2&Umb=1&Lmt=1&Mag=0&dT=155.3", "TSE_2079_05_01.kmz",
//2079 Oct 24
2480696.258, 18.0, -3.0, 3.0,  156.3,  156.3,
   -0.49365401,   0.46998009,   0.00003780,  -0.00005730,
   -0.78762800,  -0.22894099,   0.00010540,   0.00002950,
  -11.98526001,  -0.01382800,   0.00000200,
   93.97573853,  15.00244999,   0.00000000,
    0.56280398,   0.00011140,  -0.00001050,
    0.01658400,   0.00011080,  -0.00001040,
    0.00470070,   0.00467720,
"+20791024&Acc=2&Umb=1&Lmt=1&Mag=0&dT=156.3", "ASE_2079_10_24.kmz",
//2080 Mar 21
2480845.014, 12.0, -3.0, 3.0,  157.2,  157.2,
    0.35692200,   0.46506050,   0.00000130,  -0.00005950,
   -1.01180005,   0.25848860,   0.00004850,  -0.00003470,
    0.71432000,   0.01582300,   0.00000000,
  358.28573608,  15.00422001,   0.00000000,
    0.55802399,  -0.00011250,  -0.00001080,
    0.01182700,  -0.00011190,  -0.00001080,
    0.00469430,   0.00467090,
"+20800321&Acc=2&Umb=1&Lmt=1&Mag=0&dT=157.2", "PSE_2080_03_21.kmz",
//2080 Sep 13
2481021.193, 17.0, -3.0, 3.0,  158.3,  158.3,
    0.69778800,   0.50164098,  -0.00005860,  -0.00007930,
    0.84046102,  -0.27482179,  -0.00005910,   0.00004560,
    3.23846006,  -0.01533200,  -0.00000100,
   76.11579132,  15.00494003,   0.00000000,
    0.53771001,   0.00007950,  -0.00001240,
   -0.00838500,   0.00007910,  -0.00001230,
    0.00464670,   0.00462350,
"+20800913&Acc=2&Umb=1&Lmt=1&Mag=0&dT=158.3", "PSE_2080_09_13.kmz",
//2081 Mar 10
2481199.141, 15.0, -3.0, 3.0,  159.4,  159.4,
    0.00284000,   0.44363540,  -0.00000430,  -0.00004930,
   -0.41576600,   0.24513890,   0.00003770,  -0.00002890,
   -3.67919993,   0.01577800,   0.00000100,
   42.50627899,  15.00378990,   0.00000000,
    0.57107699,  -0.00004410,  -0.00000990,
    0.02481500,  -0.00004390,  -0.00000990,
    0.00470930,   0.00468590,
"+20810310&Acc=2&Umb=1&Lmt=1&Mag=0&dT=159.4", "ASE_2081_03_10.kmz",
//2081 Sep 3
2481375.880, 9.0, -3.0, 3.0,  160.5,  160.5,
    0.09403600,   0.51564318,  -0.00002680,  -0.00008690,
    0.33262300,  -0.27407131,  -0.00006060,   0.00004820,
    7.22193003,  -0.01468700,  -0.00000200,
  315.18859863,  15.00469971,   0.00000000,
    0.53207302,  -0.00000410,  -0.00001290,
   -0.01399500,  -0.00000410,  -0.00001280,
    0.00463410,   0.00461100,
"+20810903&Acc=2&Umb=1&Lmt=1&Mag=0&dT=160.5", "TSE_2081_09_03.kmz",
//2082 Feb 27
2481553.116, 15.0, -3.0, 3.0,  161.5,  161.5,
   -0.05977400,   0.44892421,  -0.00002630,  -0.00005020,
    0.34859499,   0.23728520,   0.00002500,  -0.00002830,
   -8.02772999,   0.01516600,   0.00000200,
   41.88127899,  15.00298977,   0.00000000,
    0.57132900,   0.00004800,  -0.00001000,
    0.02506500,   0.00004780,  -0.00000990,
    0.00472270,   0.00469920,
"+20820227&Acc=2&Umb=1&Lmt=1&Mag=0&dT=161.5", "ASE_2082_02_27.kmz",
//2082 Aug 24
2481730.553, 1.0, -3.0, 3.0,  162.6,  162.6,
   -0.31668699,   0.50789630,  -0.00000210,  -0.00007840,
   -0.28962001,  -0.25266391,  -0.00005170,   0.00004100,
   10.98987961,  -0.01367100,  -0.00000200,
  194.38230896,  15.00407028,   0.00000000,
    0.53854400,  -0.00008900,  -0.00001210,
   -0.00755600,  -0.00008850,  -0.00001210,
    0.00462330,   0.00460030,
"+20820824&Acc=2&Umb=1&Lmt=1&Mag=0&dT=162.6", "TSE_2082_08_24.kmz",
//2083 Feb 16
2481907.255, 18.0, -3.0, 3.0,  163.7,  163.7,
   -0.49697900,   0.48056081,  -0.00002730,  -0.00006240,
    0.88927197,   0.23324279,   0.00002200,  -0.00003200,
  -12.08178997,   0.01398000,   0.00000300,
   86.52725983,  15.00189018,   0.00000000,
    0.55902201,   0.00011870,  -0.00001100,
    0.01282000,   0.00011810,  -0.00001100,
    0.00473370,   0.00471010,
"+20830216&Acc=2&Umb=1&Lmt=1&Mag=0&dT=163.7", "PSE_2083_02_16.kmz",
//2083 Jul 15
2482055.510, 0.0, -3.0, 3.0,  164.6,  164.6,
    0.28164399,   0.50215060,  -0.00003470,  -0.00006060,
    1.52567601,  -0.13508271,  -0.00019750,   0.00001740,
   21.50350952,  -0.00625500,  -0.00000500,
  178.46908569,  15.00022030,   0.00000000,
    0.55880499,  -0.00008700,  -0.00001020,
    0.01260400,  -0.00008660,  -0.00001010,
    0.00460020,   0.00457730,
"+20830715&Acc=2&Umb=1&Lmt=1&Mag=0&dT=164.6", "PSE_2083_07_15.kmz",
//2083 Aug 13
2482085.024, 13.0, -3.0, 3.0,  164.8,  164.8,
   -0.28705600,   0.48776880,  -0.00000600,  -0.00006330,
   -1.19325602,  -0.21834250,  -0.00003230,   0.00003020,
   14.48647022,  -0.01224700,  -0.00000300,
   13.76465034,  15.00312996,   0.00000000,
    0.55251002,  -0.00012280,  -0.00001080,
    0.00634100,  -0.00012220,  -0.00001070,
    0.00461450,   0.00459150,
"+20830813&Acc=2&Umb=1&Lmt=1&Mag=0&dT=164.8", "PSE_2083_08_13.kmz",
//2084 Jan 7
2482232.229, 18.0, -3.0, 3.0,  165.8,  165.8,
    0.51758099,   0.56472009,  -0.00007300,  -0.00009390,
   -0.98074102,   0.12939000,   0.00021970,  -0.00002330,
  -22.29984093,   0.00513000,   0.00000600,
   88.45179749,  14.99705029,   0.00000000,
    0.54006600,   0.00003970,  -0.00001300,
   -0.00604200,   0.00003950,  -0.00001290,
    0.00475450,   0.00473080,
"+20840107&Acc=2&Umb=1&Lmt=1&Mag=0&dT=165.8", "PSE_2084_01_07.kmz",
//2084 Jul 3
2482409.577, 2.0, -3.0, 3.0,  166.9,  166.9,
    0.23439400,   0.49669591,  -0.00003560,  -0.00005550,
    0.79073697,  -0.09568410,  -0.00017150,   0.00001190,
   22.87346077,  -0.00337700,  -0.00000500,
  208.87272644,  14.99940014,   0.00000000,
    0.56561899,  -0.00000420,  -0.00000970,
    0.01938400,  -0.00000420,  -0.00000960,
    0.00459990,   0.00457700,
"+20840703&Acc=2&Umb=1&Lmt=1&Mag=0&dT=166.9", "ASE_2084_07_03.kmz",
//2084 Dec 27
2482586.885, 9.0, -3.0, 3.0,  167.8,  167.8,
   -0.07122500,   0.57292420,  -0.00001550,  -0.00009550,
   -0.42462501,   0.08557050,   0.00020070,  -0.00001570,
  -23.26555061,   0.00188600,   0.00000600,
  314.67559814,  14.99643993,   0.00000000,
    0.54001802,  -0.00004500,  -0.00001300,
   -0.00608900,  -0.00004480,  -0.00001290,
    0.00475380,   0.00473010,
"+20841227&Acc=2&Umb=1&Lmt=1&Mag=0&dT=167.8", "TSE_2084_12_27.kmz",
//2085 Jun 22
2482763.640, 3.0, -3.0, 3.0,  169.0,  169.0,
   -0.17790900,   0.51612413,  -0.00002350,  -0.00006230,
    0.06533400,  -0.05740350,  -0.00015300,   0.00000800,
   23.42000008,  -0.00029900,  -0.00000600,
  224.44166565,  14.99907017,   0.00000000,
    0.55906802,   0.00009760,  -0.00001020,
    0.01286600,   0.00009720,  -0.00001010,
    0.00460160,   0.00457870,
"+20850622&Acc=2&Umb=1&Lmt=1&Mag=0&dT=169.0", "ASE_2085_06_22.kmz",
//2085 Dec 16
2482941.443, 23.0, -3.0, 3.0,  170.1,  170.1,
    0.18553101,   0.55139148,  -0.00000170,  -0.00008010,
    0.29164401,   0.03683980,   0.00015520,  -0.00000660,
  -23.35828018,  -0.00146900,   0.00000600,
  165.99411011,  14.99639034,   0.00000000,
    0.55144399,  -0.00012560,  -0.00001180,
    0.00528000,  -0.00012500,  -0.00001180,
    0.00475080,   0.00472720,
"+20851216&Acc=2&Umb=1&Lmt=1&Mag=0&dT=170.1", "ASE_2085_12_16.kmz",
//2086 Jun 11
2483117.963, 11.0, -3.0, 3.0,  171.2,  171.2,
   -0.08892900,   0.55065691,  -0.00001800,  -0.00007900,
   -0.71907800,  -0.01720130,  -0.00012370,   0.00000340,
   23.12593079,   0.00272500,  -0.00000600,
  345.02404785,  14.99927044,   0.00000000,
    0.54462802,   0.00011930,  -0.00001140,
   -0.00150200,   0.00011870,  -0.00001140,
    0.00460530,   0.00458240,
"+20860611&Acc=2&Umb=1&Lmt=1&Mag=0&dT=171.2", "TSE_2086_06_11.kmz",
//2086 Dec 6
2483295.735, 6.0, -3.0, 3.0,  172.3,  172.3,
    0.19949400,   0.51902211,   0.00000960,  -0.00006300,
    1.01620495,  -0.00866700,   0.00010800,   0.00000000,
  -22.53672981,  -0.00482200,   0.00000600,
  272.25625610,  14.99697018,   0.00000000,
    0.56676400,  -0.00010390,  -0.00001050,
    0.02052300,  -0.00010340,  -0.00001040,
    0.00474530,   0.00472160,
"+20861206&Acc=2&Umb=1&Lmt=1&Mag=0&dT=172.3", "PSE_2086_12_06.kmz",
//2087 May 2
2483443.253, 18.0, -3.0, 3.0,  173.3,  173.3,
   -0.27989799,   0.57089829,   0.00003710,  -0.00009750,
    1.07917702,   0.12333400,  -0.00016620,  -0.00002020,
   15.60330009,   0.01199600,  -0.00000300,
   90.75095367,  15.00247955,   0.00000000,
    0.53232002,   0.00001100,  -0.00001290,
   -0.01374800,   0.00001100,  -0.00001280,
    0.00463960,   0.00461650,
"+20870502&Acc=2&Umb=1&Lmt=1&Mag=0&dT=173.3", "PSE_2087_05_02.kmz",
//2087 Jun 1
2483472.561, 1.0, -3.0, 3.0,  173.5,  173.5,
   -0.19704200,   0.57771939,   0.00000800,  -0.00009580,
   -1.42915595,   0.02666200,  -0.00007720,  -0.00000360,
   22.05985069,   0.00556500,  -0.00000500,
  195.51393127,  14.99987030,   0.00000000,
    0.53299898,   0.00007020,  -0.00001260,
   -0.01307300,   0.00006980,  -0.00001250,
    0.00461140,   0.00458840,
"+20870601&Acc=2&Umb=1&Lmt=1&Mag=0&dT=173.5", "PSE_2087_06_01.kmz",
//2087 Oct 26
2483619.991, 12.0, -3.0, 3.0,  174.2,  174.2,
   -0.21145301,   0.49129069,   0.00002060,  -0.00005560,
   -1.27551401,  -0.12523820,   0.00012580,   0.00001350,
  -12.60517025,  -0.01383700,   0.00000300,
    4.02182007,  15.00228024,   0.00000000,
    0.57069403,   0.00004620,  -0.00000990,
    0.02443400,   0.00004600,  -0.00000990,
    0.00470320,   0.00467980,
"+20871026&Acc=2&Umb=1&Lmt=1&Mag=0&dT=174.2", "PSE_2087_10_26.kmz",
//2088 Apr 21
2483797.939, 11.0, -3.0, 3.0,  175.4,  175.4,
    0.15702701,   0.55414170,   0.00002520,  -0.00008910,
    0.46746600,   0.14269720,  -0.00009800,  -0.00002220,
   12.27414036,   0.01363700,  -0.00000300,
  345.36242676,  15.00335026,   0.00000000,
    0.53789502,  -0.00009910,  -0.00001240,
   -0.00820200,  -0.00009860,  -0.00001240,
    0.00465250,   0.00462940,
"+20880421&Acc=2&Umb=1&Lmt=1&Mag=0&dT=175.4", "TSE_2088_04_21.kmz",
//2088 Oct 14
2483974.117, 15.0, -3.0, 3.0,  176.5,  176.5,
   -0.04763000,   0.51085299,   0.00000100,  -0.00006630,
   -0.54315299,  -0.14820680,   0.00008120,   0.00001840,
   -8.65711021,  -0.01500300,   0.00000200,
   48.56719971,  15.00356960,   0.00000000,
    0.55781502,   0.00011500,  -0.00001080,
    0.01162000,   0.00011450,  -0.00001080,
    0.00468810,   0.00466480,
"+20881014&Acc=2&Umb=1&Lmt=1&Mag=0&dT=176.5", "ASE_2088_10_14.kmz",
//2089 Apr 10
2484152.448, 23.0, -3.0, 3.0,  177.7,  177.7,
    0.22513600,   0.51873922,   0.00002160,  -0.00007050,
   -0.28009099,   0.15104841,  -0.00002930,  -0.00001970,
    8.49475956,   0.01490300,  -0.00000200,
  164.75439453,  15.00395966,   0.00000000,
    0.55274397,  -0.00012930,  -0.00001110,
    0.00657400,  -0.00012870,  -0.00001110,
    0.00466720,   0.00464390,
"+20890410&Acc=2&Umb=1&Lmt=1&Mag=0&dT=177.7", "ASE_2089_04_10.kmz",
//2089 Oct 4
2484328.552, 1.0, -3.0, 3.0,  178.8,  178.8,
   -0.07391500,   0.53981578,  -0.00000260,  -0.00008380,
    0.25006101,  -0.16834410,   0.00002060,   0.00002540,
   -4.57124996,  -0.01562000,   0.00000100,
  197.83990479,  15.00450039,   0.00000000,
    0.54181999,   0.00011010,  -0.00001220,
   -0.00429600,   0.00010960,  -0.00001210,
    0.00467280,   0.00464950,
"+20891004&Acc=2&Umb=1&Lmt=1&Mag=0&dT=178.8", "TSE_2089_10_04.kmz",
//2090 Mar 31
2484506.651, 4.0, -3.0, 3.0,  179.8,  179.8,
    0.50793898,   0.48765811,  -0.00000230,  -0.00005650,
   -0.99639601,   0.15305400,   0.00002160,  -0.00001700,
    4.33023024,   0.01574500,  -0.00000100,
  238.98228455,  15.00426006,   0.00000000,
    0.56738800,  -0.00008030,  -0.00001000,
    0.02114500,  -0.00007990,  -0.00001000,
    0.00468260,   0.00465920,
"+20900331&Acc=2&Umb=1&Lmt=1&Mag=0&dT=179.8", "PSE_2090_03_31.kmz",
//2090 Sep 23
2484683.206, 17.0, -3.0, 3.0,  180.9,  180.9,
    0.31214499,   0.55547071,  -0.00001920,  -0.00009460,
    0.86148399,  -0.17890251,  -0.00004590,   0.00002960,
   -0.47152999,  -0.01577400,   0.00000000,
   76.96498108,  15.00498962,   0.00000000,
    0.53339201,   0.00001480,  -0.00001290,
   -0.01268200,   0.00001470,  -0.00001290,
    0.00465830,   0.00463510,
"+20900923&Acc=2&Umb=1&Lmt=1&Mag=0&dT=180.9", "TSE_2090_09_23.kmz",
//2091 Feb 18
2484830.913, 10.0, -3.0, 3.0,  181.9,  181.9,
   -0.26001200,   0.49571249,  -0.00001770,  -0.00005810,
    1.14974594,   0.13247810,   0.00001550,  -0.00001480,
  -11.47191048,   0.01444800,   0.00000300,
  326.55902100,  15.00212955,   0.00000000,
    0.56910801,   0.00007600,  -0.00001020,
    0.02285600,   0.00007560,  -0.00001020,
    0.00473260,   0.00470900,
"+20910218&Acc=2&Umb=1&Lmt=1&Mag=0&dT=181.9", "PSE_2091_02_18.kmz",
//2091 Aug 15
2485008.524, 1.0, -3.0, 3.0,  183.0,  183.0,
    0.00983900,   0.54352301,  -0.00000440,  -0.00008130,
   -0.97768402,  -0.12907900,  -0.00004220,   0.00001870,
   14.00129032,  -0.01270100,  -0.00000300,
  193.84063721,  15.00341034,   0.00000000,
    0.54172099,  -0.00011940,  -0.00001180,
   -0.00439400,  -0.00011880,  -0.00001170,
    0.00461520,   0.00459220,
"+20910815&Acc=2&Umb=1&Lmt=1&Mag=0&dT=183.0", "TSE_2091_08_15.kmz",
//2092 Feb 7
2485185.132, 15.0, -3.0, 3.0,  184.2,  184.2,
   -0.18429799,   0.53151518,  -0.00003020,  -0.00007390,
    0.40198499,   0.11674810,   0.00007260,  -0.00001540,
  -15.17413044,   0.01280600,   0.00000400,
   41.50920105,  15.00082016,   0.00000000,
    0.55484700,   0.00012360,  -0.00001140,
    0.00866500,   0.00012300,  -0.00001140,
    0.00474180,   0.00471820,
"+20920207&Acc=2&Umb=1&Lmt=1&Mag=0&dT=184.2", "ASE_2092_02_07.kmz",
//2092 Aug 3
2485362.916, 10.0, -3.0, 3.0,  185.3,  185.3,
   -0.03327100,   0.51691169,  -0.00000310,  -0.00006470,
   -0.20173000,  -0.09559940,  -0.00009880,   0.00001130,
   17.15640068,  -0.01089700,  -0.00000400,
  328.43862915,  15.00226974,   0.00000000,
    0.55641401,  -0.00010360,  -0.00001040,
    0.01022500,  -0.00010310,  -0.00001040,
    0.00460820,   0.00458530,
"+20920803&Acc=2&Umb=1&Lmt=1&Mag=0&dT=185.3", "ASE_2092_08_03.kmz",
//2093 Jan 27
2485539.640, 3.0, -3.0, 3.0,  186.3,  186.3,
   -0.16662700,   0.56729311,  -0.00002370,  -0.00009270,
   -0.30436999,   0.09208810,   0.00014300,  -0.00001420,
  -18.27779961,   0.01067100,   0.00000400,
  221.84153748,  14.99942970,   0.00000000,
    0.54163897,   0.00008220,  -0.00001280,
   -0.00447600,   0.00008180,  -0.00001270,
    0.00474830,   0.00472460,
"+20930127&Acc=2&Umb=1&Lmt=1&Mag=0&dT=186.3", "TSE_2093_01_27.kmz",
//2093 Jul 23
2485717.022, 13.0, -3.0, 3.0,  187.4,  187.4,
    0.30386099,   0.50262862,  -0.00002220,  -0.00005660,
    0.53854603,  -0.06199640,  -0.00014120,   0.00000630,
   19.81949997,  -0.00863100,  -0.00000400,
   13.33267021,  15.00109005,   0.00000000,
    0.56545299,  -0.00003120,  -0.00000970,
    0.01921900,  -0.00003110,  -0.00000970,
    0.00460310,   0.00458020,
"+20930723&Acc=2&Umb=1&Lmt=1&Mag=0&dT=187.4", "ASE_2093_07_23.kmz",
//2094 Jan 16
2485894.291, 19.0, -3.0, 3.0,  188.6,  188.6,
    0.10048500,   0.57942212,  -0.00001680,  -0.00009830,
   -0.92795998,   0.05701050,   0.00020810,  -0.00000860,
  -20.71500015,   0.00809000,   0.00000500,
  102.54383850,  14.99808025,   0.00000000,
    0.53871900,  -0.00002880,  -0.00001310,
   -0.00738200,  -0.00002870,  -0.00001300,
    0.00475260,   0.00472890,
"+20940116&Acc=2&Umb=1&Lmt=1&Mag=0&dT=188.6", "TSE_2094_01_16.kmz",
//2094 Jun 13
2486041.515, 0.0, -3.0, 3.0,  189.5,  189.5,
    0.02695900,   0.52083969,   0.00000510,  -0.00006550,
   -1.47401094,   0.07922080,  -0.00008670,  -0.00001130,
   23.22146988,   0.00204100,  -0.00000600,
  179.93438721,  14.99915028,   0.00000000,
    0.55540699,   0.00011350,  -0.00001050,
    0.00922300,   0.00011300,  -0.00001040,
    0.00460500,   0.00458210,
"+20940613&Acc=2&Umb=1&Lmt=1&Mag=0&dT=189.5", "PSE_2094_06_13.kmz",
//2094 Jul 12
2486071.059, 13.0, -3.0, 3.0,  189.7,  189.7,
   -0.13868099,   0.51367211,  -0.00001400,  -0.00006050,
    1.32447195,  -0.02792240,  -0.00018900,   0.00000270,
   21.82238007,  -0.00596300,  -0.00000500,
   13.52124023,  15.00008011,   0.00000000,
    0.56141597,   0.00008370,  -0.00001000,
    0.01520200,   0.00008330,  -0.00000990,
    0.00460000,   0.00457710,
"+20940712&Acc=2&Umb=1&Lmt=1&Mag=0&dT=189.7", "PSE_2094_07_12.kmz",
//2094 Dec 7
2486219.337, 20.0, -3.0, 3.0,  190.7,  190.7,
    0.17804000,   0.53140068,   0.00004140,  -0.00007280,
    1.14214599,  -0.10829360,   0.00010210,   0.00001610,
  -22.71690941,  -0.00407700,   0.00000600,
  122.08750153,  14.99687004,   0.00000000,
    0.55577600,  -0.00011780,  -0.00001140,
    0.00959000,  -0.00011720,  -0.00001130,
    0.00474580,   0.00472220,
"+20941207&Acc=2&Umb=1&Lmt=1&Mag=0&dT=190.7", "PSE_2094_12_07.kmz",
//2095 Jun 2
2486395.922, 10.0, -3.0, 3.0,  191.9,  191.9,
    0.07563900,   0.54556769,   0.00001480,  -0.00008190,
   -0.63912100,   0.12732890,  -0.00011840,  -0.00002070,
   22.24581909,   0.00494100,  -0.00000500,
  330.45397949,  14.99969006,   0.00000000,
    0.54084998,   0.00011100,  -0.00001180,
   -0.00526100,   0.00011050,  -0.00001180,
    0.00461090,   0.00458790,
"+20950602&Acc=2&Umb=1&Lmt=1&Mag=0&dT=191.9", "TSE_2095_06_02.kmz",
//2095 Nov 27
2486573.544, 1.0, -3.0, 3.0,  192.8,  192.8,
    0.11189800,   0.49192521,   0.00004500,  -0.00005690,
    0.47801599,  -0.14220279,   0.00011200,   0.00001790,
  -21.12899017,  -0.00723400,   0.00000500,
  198.14639282,  14.99790955,   0.00000000,
    0.56997502,  -0.00007410,  -0.00001020,
    0.02371800,  -0.00007380,  -0.00001010,
    0.00473810,   0.00471450,
"+20951127&Acc=2&Umb=1&Lmt=1&Mag=0&dT=192.8", "ASE_2095_11_27.kmz",
//2096 May 22
2486750.568, 2.0, -3.0, 3.0,  194.0,  194.0,
    0.17598400,   0.55674738,   0.00002940,  -0.00009370,
    0.17940900,   0.17158200,  -0.00014920,  -0.00003050,
   20.56045914,   0.00757000,  -0.00000500,
  210.79228210,  15.00053024,   0.00000000,
    0.53189498,   0.00002220,  -0.00001280,
   -0.01417200,   0.00002210,  -0.00001270,
    0.00461880,   0.00459580,
"+20960522&Acc=2&Umb=1&Lmt=1&Mag=0&dT=194.0", "TSE_2096_05_22.kmz",
//2096 Nov 15
2486927.525, 1.0, -3.0, 3.0,  195.2,  195.2,
    0.11769500,   0.47320661,   0.00003320,  -0.00005220,
   -0.25826901,  -0.17382970,   0.00012120,   0.00002070,
  -18.68646049,  -0.01000300,   0.00000400,
  198.85609436,  14.99938965,   0.00000000,
    0.57344598,   0.00001870,  -0.00000990,
    0.02717200,   0.00001860,  -0.00000980,
    0.00472720,   0.00470370,
"+20961115&Acc=2&Umb=1&Lmt=1&Mag=0&dT=195.2", "ASE_2096_11_15.kmz",
//2097 May 11
2487105.274, 19.0, -3.0, 3.0,  196.3,  196.3,
   -0.06889800,   0.54096532,   0.00005890,  -0.00008860,
    0.88346201,   0.20237900,  -0.00016330,  -0.00003500,
   18.22874069,   0.00991800,  -0.00000400,
  105.89084625,  15.00148010,   0.00000000,
    0.53449702,  -0.00007950,  -0.00001260,
   -0.01158300,  -0.00007910,  -0.00001250,
    0.00462920,   0.00460620,
"+20970511&Acc=2&Umb=1&Lmt=1&Mag=0&dT=196.3", "TSE_2097_05_11.kmz",
//2097 Nov 4
2487281.584, 2.0, -3.0, 3.0,  197.5,  197.5,
   -0.36622700,   0.48102090,   0.00003930,  -0.00005920,
   -0.81415898,  -0.20839010,   0.00013060,   0.00002720,
  -15.56418037,  -0.01220100,   0.00000300,
  214.12190247,  15.00102997,   0.00000000,
    0.56285697,   0.00011060,  -0.00001060,
    0.01663600,   0.00011010,  -0.00001050,
    0.00471390,   0.00469040,
"+20971104&Acc=2&Umb=1&Lmt=1&Mag=0&dT=197.5", "ASE_2097_11_04.kmz",
//2098 Apr 1
2487430.335, 20.0, -3.0, 3.0,  198.5,  198.5,
    0.50660002,   0.46586400,   0.00000750,  -0.00005910,
   -0.97719502,   0.25357589,   0.00002430,  -0.00003380,
    4.99576998,   0.01540600,  -0.00000100,
  119.11235809,  15.00417042,   0.00000000,
    0.55799401,  -0.00011700,  -0.00001080,
    0.01179700,  -0.00011640,  -0.00001070,
    0.00468010,   0.00465680,
"+20980401&Acc=2&Umb=1&Lmt=1&Mag=0&dT=198.5", "PSE_2098_04_01.kmz",
//2098 Sep 25
2487606.522, 1.0, -3.0, 3.0,  199.4,  199.4,
    0.78067303,   0.50183779,  -0.00004960,  -0.00007980,
    0.84662300,  -0.27698290,  -0.00003660,   0.00004630,
   -1.01596999,  -0.01554200,   0.00000000,
  197.08433533,  15.00483036,   0.00000000,
    0.53785503,   0.00007250,  -0.00001250,
   -0.00824100,   0.00007210,  -0.00001240,
    0.00466020,   0.00463700,
"+20980925&Acc=2&Umb=1&Lmt=1&Mag=0&dT=199.4", "PSE_2098_09_25.kmz",
//2098 Oct 24
2487635.942, 11.0, -3.0, 3.0,  199.6,  199.6,
   -0.46970600,   0.50279868,   0.00004330,  -0.00007430,
   -1.48399699,  -0.24235870,   0.00015180,   0.00003730,
  -12.02058983,  -0.01377600,   0.00000200,
  348.97515869,  15.00251961,   0.00000000,
    0.54645002,   0.00010580,  -0.00001190,
    0.00031100,   0.00010530,  -0.00001190,
    0.00469960,   0.00467620,
"+20981024&Acc=2&Umb=1&Lmt=1&Mag=0&dT=199.6", "PSE_2098_10_24.kmz",
//2099 Mar 21
2487784.455, 23.0, -3.0, 3.0,  200.6,  200.6,
    0.23612601,   0.44210401,  -0.00000090,  -0.00004900,
   -0.32814401,   0.24693550,   0.00001260,  -0.00002910,
    0.65386999,   0.01585500,   0.00000000,
  163.28031921,  15.00415039,   0.00000000,
    0.57052302,  -0.00004850,  -0.00000990,
    0.02426400,  -0.00004830,  -0.00000980,
    0.00469550,   0.00467210,
"+20990321&Acc=2&Umb=1&Lmt=1&Mag=0&dT=200.6", "ASE_2099_03_21.kmz",
//2099 Sep 14
2487961.207, 17.0, -3.0, 3.0,  201.8,  201.8,
    0.20840500,   0.51104248,  -0.00001970,  -0.00008600,
    0.33524600,  -0.28185049,  -0.00003750,   0.00004950,
    3.08305001,  -0.01532800,  -0.00000100,
   76.14335632,  15.00496960,   0.00000000,
    0.53282899,  -0.00001410,  -0.00001290,
   -0.01324300,  -0.00001400,  -0.00001280,
    0.00464660,   0.00462350,
"+20990914&Acc=2&Umb=1&Lmt=1&Mag=0&dT=201.8", "TSE_2099_09_14.kmz"
);


//
// C2 limb corrections for the 2003 May 31 annular eclipse in seconds
//
// The first 3 elements of the array tell us that the remaining data starts at contact angle
// 197.37 degrees in 0.4 degree increments for 315 data points, which means that the last
// element is for angle 322.97 degrees
//
// These limb corrections were calculated by Fred Espenak, NASA/GSFC
//
var C2limb2003May = new Array(
197.37, 0.4, 315,
9.85, 9.35, 8.85, 8.33, 7.80, 7.26, 6.71, 6.14, 5.56, 5.22, 5.06,
4.89, 4.70, 4.51, 4.31, 4.10, 3.88, 3.82, 3.91, 4.00, 4.07, 4.14,
4.20, 4.26, 4.31, 4.35, 4.38, 4.41, 4.43, 4.44, 4.44, 4.44, 4.43,
4.42, 4.39, 4.36, 4.33, 4.28, 4.23, 4.17, 4.11, 4.04, 3.96, 3.87,
3.84, 3.85, 3.86, 3.86, 3.86, 3.85, 3.83, 3.81, 3.78, 3.74, 3.70,
3.65, 3.59, 3.53, 3.47, 3.39, 3.31, 3.22, 3.13, 3.03, 2.93, 2.81,
2.70, 2.57, 2.44, 2.31, 2.16, 2.01, 1.86, 1.70, 1.59, 1.64, 1.69,
1.72, 1.76, 1.78, 1.81, 1.87, 1.92, 1.97, 2.01, 2.05, 2.08, 2.11,
2.13, 2.15, 2.16, 2.23, 2.37, 2.51, 2.64, 2.77, 2.89, 3.01, 3.12,
3.23, 3.33, 3.43, 3.52, 3.61, 3.69, 3.77, 3.84, 3.91, 3.97, 4.03,
4.08, 4.13, 4.17, 4.21, 4.24, 4.27, 4.29, 4.31, 4.32, 4.33, 4.33,
4.33, 4.32, 4.31, 4.29, 4.27, 4.24, 4.20, 4.17, 4.12, 4.08, 4.02,
3.96, 3.90, 3.83, 3.76, 3.68, 3.60, 3.51, 3.42, 3.32, 3.22, 3.11,
3.00, 2.88, 2.76, 2.63, 2.53, 2.50, 2.46, 2.41, 2.36, 2.31, 2.25,
2.19, 2.12, 2.04, 1.96, 1.88, 1.79, 1.70, 1.60, 1.49, 1.39, 1.27,
1.15, 1.03, 0.90, 0.77, 0.63, 0.49, 0.34, 0.19, 0.17, 0.21, 0.24,
0.26, 0.29, 0.30, 0.31, 0.32, 0.32, 0.31, 0.30, 0.29, 0.26, 0.24,
0.21, 0.17, 0.13, 0.09, 0.05, 0.18, 0.31, 0.43, 0.55, 0.66, 0.77,
0.87, 0.97, 1.05, 1.14, 1.22, 1.29, 1.36, 1.42, 1.48, 1.53, 1.57,
1.61, 1.65, 1.68, 1.70, 1.72, 1.73, 1.73, 1.73, 1.73, 1.72, 1.70,
1.69, 1.75, 1.81, 1.87, 1.92, 1.96, 2.00, 2.03, 2.06, 2.08, 2.10,
2.11, 2.12, 2.12, 2.12, 2.13, 2.16, 2.18, 2.19, 2.20, 2.21, 2.25,
2.35, 2.44, 2.52, 2.59, 2.66, 2.71, 2.77, 2.81, 2.85, 2.89, 2.91,
2.93, 2.94, 2.95, 2.94, 3.07, 3.22, 3.37, 3.51, 3.64, 3.77, 3.88,
3.99, 4.09, 4.18, 4.27, 4.34, 4.41, 4.47, 4.52, 4.57, 4.60, 4.63,
4.65, 4.66, 4.66, 4.66, 4.64, 4.62, 4.59, 4.55, 4.50, 4.45, 4.39,
4.31, 4.23, 4.15, 4.05, 3.94, 3.83, 3.71, 3.58, 3.44, 3.29, 3.14,
2.97, 2.80, 2.62, 2.88, 3.47, 4.05, 4.62, 5.16, 5.70, 6.21, 6.71,
7.19, 7.66, 8.10, 8.54, 8.95, 9.35, 9.73
);

//
// C3 limb corrections for the 2003 May 31 annular eclipse in seconds
//
// The first 3 elements of the array tell us that the remaining data starts at contact angle
// 353.37 degrees in 0.4 degree increments for 340 data points, which means that the last
// element is for angle 128.97 degrees
//
// These limb corrections were calculated by Fred Espenak, NASA/GSFC
//
var C3limb2003May = new Array(
353.37, 0.4, 340,
-8.67, -6.49, -6.14, -6.36, -6.62, -6.87, -7.09, -7.29, -7.47, -7.64, -7.78,
-7.90, -8.01, -8.09, -8.15, -8.20, -8.22, -8.23, -8.22, -8.18, -8.13, -8.06,
-7.97, -7.86, -7.74, -7.59, -7.43, -7.25, -7.05, -6.83, -6.60, -6.34, -6.07,
-5.78, -5.48, -5.15, -4.81, -4.79, -4.82, -4.84, -4.85, -4.84, -4.83, -4.80,
-4.76, -4.70, -4.64, -4.56, -4.48, -4.38, -4.26, -4.14, -4.01, -3.86, -3.81,
-3.79, -3.78, -3.92, -4.05, -4.17, -4.29, -4.40, -4.50, -4.59, -4.67, -4.74,
-4.81, -4.87, -4.92, -4.96, -5.00, -5.02, -5.04, -5.05, -5.05, -5.04, -5.03,
-5.00, -4.97, -4.93, -4.89, -4.83, -4.77, -4.70, -4.62, -4.53, -4.44, -4.33,
-4.22, -4.20, -4.26, -4.32, -4.37, -4.42, -4.45, -4.49, -4.51, -4.53, -4.54,
-4.55, -4.54, -4.54, -4.52, -4.50, -4.47, -4.44, -4.39, -4.35, -4.29, -4.23,
-4.16, -4.09, -4.01, -3.92, -3.82, -3.72, -3.62, -3.50, -3.38, -3.37, -3.40,
-3.42, -3.44, -3.46, -3.47, -3.47, -3.46, -3.45, -3.44, -3.42, -3.39, -3.36,
-3.32, -3.27, -3.22, -3.18, -3.12, -3.06, -3.00, -2.93, -2.91, -2.90, -2.87,
-2.85, -2.81, -2.77, -2.73, -2.68, -2.62, -2.57, -2.52, -2.63, -2.75, -2.87,
-2.99, -3.10, -3.21, -3.31, -3.40, -3.49, -3.58, -3.66, -3.73, -3.81, -3.87,
-3.93, -3.99, -4.04, -4.08, -4.12, -4.16, -4.19, -4.21, -4.23, -4.25, -4.26,
-4.26, -4.26, -4.25, -4.24, -4.23, -4.23, -4.23, -4.22, -4.21, -4.20, -4.18,
-4.15, -4.12, -4.09, -4.05, -4.04, -4.09, -4.14, -4.19, -4.23, -4.26, -4.31,
-4.37, -4.44, -4.49, -4.54, -4.59, -4.63, -4.67, -4.76, -4.88, -4.99, -5.11,
-5.21, -5.31, -5.41, -5.50, -5.58, -5.66, -5.74, -5.81, -5.88, -5.94, -5.99,
-6.04, -6.09, -6.13, -6.16, -6.20, -6.22, -6.24, -6.26, -6.27, -6.27, -6.28,
-6.28, -6.27, -6.26, -6.24, -6.22, -6.19, -6.16, -6.12, -6.08, -6.03, -5.98,
-5.92, -5.86, -5.79, -5.72, -5.64, -5.56, -5.47, -5.47, -5.45, -5.44, -5.41,
-5.39, -5.35, -5.31, -5.27, -5.22, -5.17, -5.11, -5.05, -4.98, -4.90, -4.82,
-4.74, -4.67, -4.60, -4.53, -4.46, -4.43, -4.61, -4.78, -4.95, -5.11, -5.27,
-5.42, -5.57, -5.70, -5.84, -5.96, -6.08, -6.20, -6.30, -6.40, -6.50, -6.59,
-6.67, -6.75, -6.82, -6.88, -6.96, -7.13, -7.29, -7.44, -7.58, -7.72, -7.86,
-7.98, -8.10, -8.22, -8.32, -8.42, -8.52, -8.60, -8.68, -8.75, -8.82, -8.88,
-8.93, -8.98, -9.02, -9.06, -9.08, -9.11, -9.12, -9.13, -9.13, -9.12, -9.11,
-9.09, -9.06, -9.03, -8.98, -8.94, -8.90, -8.87, -8.83, -8.79, -8.74, -8.68,
-8.62, -8.54, -8.47, -8.38, -8.29, -8.18, -8.09, -8.59, -9.08, -9.56
);

//
// Calculate a limb correction
function limbcorrection(p, correctiondata)
{
  var i, n;

  i = (p * 180 / Math.PI) - correctiondata[0];
  while (i >= 360.0)
    i -= 360.0;
  while (i < 0.0)
    i += 360.0;
  i = i / correctiondata[1];
  if (i >= (correctiondata[2] - 1))
    return 999.0;
  n = Math.floor(i);

  return (((correctiondata[n+4] - correctiondata[n+3]) * (i - n)) + correctiondata[n+3]);
}

//
// Observer constants -
// (0) North Latitude (radians)
// (1) West Longitude (radians)
// (2) Altitude (metres)
// (3) West time zone (hours)
// (4) rho sin O'
// (5) rho cos O'
// (6) index into the elements array for the eclipse in question
//
// Note that correcting for refraction will involve creating a "virtual" altitude
// for each contact, and hence a different value of rho and O' for each contact!
//
var obsvconst = new Array();

//
// Eclipse circumstances
//  (0) Event type (C1=-2, C2=-1, Mid=0, C3=1, C4=2)
//  (1) t
// -- time-only dependent circumstances (and their per-hour derivatives) follow --
//  (2) x
//  (3) y
//  (4) d
//  (5) sin d
//  (6) cos d
//  (7) mu
//  (8) l1
//  (9) l2
// (10) dx
// (11) dy
// (12) dd
// (13) dmu
// (14) dl1
// (15) dl2
// -- time and location dependent circumstances follow --
// (16) h
// (17) sin h
// (18) cos h
// (19) xi
// (20) eta
// (21) zeta
// (22) dxi
// (23) deta
// (24) u
// (25) v
// (26) a
// (27) b
// (28) l1'
// (29) l2'
// (30) n^2
// -- observational circumstances follow --
// (31) p
// (32) alt
// (33) q
// (34) v
// (35) azi
// (36) m (mid eclipse only) or limb correction applied (where available!)
// (37) magnitude (mid eclipse only)
// (38) moon/sun (mid eclipse only)
// (39) calculated local event type for a transparent earth (0 = none, 1 = partial, 2 = annular, 3 = total)
//
var c1 = new Array();
var c2 = new Array();
var mid = new Array();
var c3 = new Array();
var c4 = new Array();

//
// Populate the circumstances array with the time-only dependent circumstances (x, y, d, m, ...)
function timedependent(circumstances)
{
  var type, index, t, ans;

  t = circumstances[1];
  index = obsvconst[6];
  // Calculate x
  ans = elements[9 + index] * t + elements[8 + index];
  ans = ans * t + elements[7 + index];
  ans = ans * t + elements[6 + index];
  circumstances[2] = ans;
  // Calculate dx
  ans = 3.0 * elements[9 + index] * t + 2.0 * elements[8 + index];
  ans = ans * t + elements[7 + index];
  circumstances[10] = ans;
  // Calculate y
  ans = elements[13 + index] * t + elements[12 + index];
  ans = ans * t + elements[11 + index];
  ans = ans * t + elements[10 + index];
  circumstances[3] = ans
  // Calculate dy
  ans = 3.0 * elements[13 + index] * t + 2.0 * elements[12 + index];
  ans = ans * t + elements[11 + index];
  circumstances[11] = ans;
  // Calculate d
  ans = elements[16 + index] * t + elements[15 + index];
  ans = ans * t + elements[14 + index];
  ans = ans * D2R;
  circumstances[4] = ans;
  // sin d and cos d
  circumstances[5] = Math.sin(ans);
  circumstances[6] = Math.cos(ans);
  // Calculate dd
  ans = 2.0 * elements[16 + index] * t + elements[15 + index];
  ans = ans * D2R;
  circumstances[12] = ans;
  // Calculate m
  ans = elements[19 + index] * t + elements[18 + index];
  ans = ans * t + elements[17 + index];
  if (ans >= 360.0)
    ans -= 360.0;
  ans = ans * D2R;
  circumstances[7] = ans;
  // Calculate dm
  ans = 2.0 * elements[19 + index] * t + elements[18 + index];
  ans = ans * D2R;
  circumstances[13] = ans;
  // Calculate l1 and dl1
  type = circumstances[0]
  if ((type == -2) || (type == 0) || (type == 2))
  {
    ans = elements[22 + index] * t + elements[21 + index];
    ans = ans * t + elements[20 + index];
    circumstances[8] = ans;
    circumstances[14] = 2.0 * elements[22 + index] * t + elements[21 + index];
  }
  // Calculate l2 and dl2
  if ((type == -1) || (type == 0) || (type == 1))
  {
    ans = elements[25 + index] * t + elements[24 + index];
    ans = ans * t + elements[23 + index];
    circumstances[9] = ans;
    circumstances[15] = 2.0 * elements[25 + index] * t + elements[24 + index];
  }

  return circumstances;
}

//
// Populate the circumstances array with the time and location dependent circumstances
function timelocdependent(circumstances)
{
  var ans, index, type;

  timedependent(circumstances);
  index = obsvconst[6];
  // Calculate h, sin h, cos h
  circumstances[16] = circumstances[7] - obsvconst[1] - (elements[index+5] / 13713.44);
  circumstances[17] = Math.sin(circumstances[16]);
  circumstances[18] = Math.cos(circumstances[16]);
  // Calculate xi
  circumstances[19] = obsvconst[5] * circumstances[17];
  // Calculate eta
  circumstances[20] = obsvconst[4] * circumstances[6] - obsvconst[5] * circumstances[18] * circumstances[5];
  // Calculate zeta
  circumstances[21] = obsvconst[4] * circumstances[5] + obsvconst[5] * circumstances[18] * circumstances[6];
  // Calculate dxi
  circumstances[22] = circumstances[13] * obsvconst[5] * circumstances[18];
  // Calculate deta
  circumstances[23] = circumstances[13] * circumstances[19] * circumstances[5] - circumstances[21] * circumstances[12];
  // Calculate u
  circumstances[24] = circumstances[2] - circumstances[19];
  // Calculate v
  circumstances[25] = circumstances[3] - circumstances[20];
  // Calculate a
  circumstances[26] = circumstances[10] - circumstances[22];
  // Calculate b
  circumstances[27] = circumstances[11] - circumstances[23];
  // Calculate l1'
  type = circumstances[0];
  if ((type == -2) || (type == 0) || (type == 2))
    circumstances[28] = circumstances[8] - circumstances[21] * elements[26 + index];
  // Calculate l2'
  if ((type == -1) || (type == 0) || (type == 1))
    circumstances[29] = circumstances[9] - circumstances[21] * elements[27 + index];
  // Calculate n^2
  circumstances[30] = circumstances[26] * circumstances[26] + circumstances[27] * circumstances[27];

  return circumstances;
}

//
// Iterate on C1 or C4
function c1c4iterate(circumstances)
{
  var sign, iter, tmp, n;

  timelocdependent(circumstances);
  if (circumstances[0] < 0)
    sign = -1.0;
  else
    sign = 1.0;
  tmp = 1.0;
  iter = 0;
  while (((tmp > 0.000001) || (tmp < -0.000001)) && (iter < 50))
  {
    n = Math.sqrt(circumstances[30]);
    tmp = circumstances[26] * circumstances[25] - circumstances[24] * circumstances[27];
    tmp = tmp / n / circumstances[28];
    tmp = sign * Math.sqrt(1.0 - tmp * tmp) * circumstances[28] / n;
    tmp = (circumstances[24] * circumstances[26] + circumstances[25] * circumstances[27]) / circumstances[30] - tmp;
    circumstances[1] = circumstances[1] - tmp;
    timelocdependent(circumstances);
    iter++;
  }

  return circumstances;
}

//
// Get C1 and C4 data
//   Entry conditions -
//   1. The mid array must be populated
//   2. The magnitude at mid eclipse must be > 0.0
function getc1c4()
{
  var tmp, n;

  n = Math.sqrt(mid[30]);
  tmp = mid[26] * mid[25] - mid[24] * mid[27];
  tmp = tmp / n / mid[28];
  tmp = Math.sqrt(1.0 - tmp * tmp) * mid[28] / n;
  c1[0] = -2;
  c4[0] = 2;
  c1[1] = mid[1] - tmp;
  c4[1] = mid[1] + tmp;
  c1c4iterate(c1);
  c1c4iterate(c4);
}

//
// Iterate on C2 or C3
function c2c3iterate(circumstances)
{
  var sign, iter, tmp, n;

  timelocdependent(circumstances);
  if (circumstances[0] < 0)
    sign = -1.0;
  else
    sign = 1.0;
  if (mid[29] < 0.0)
    sign = -sign;
  tmp = 1.0;
  iter = 0;
  while (((tmp > 0.000001) || (tmp < -0.000001)) && (iter < 50))
  {
    n = Math.sqrt(circumstances[30]);
    tmp = circumstances[26] * circumstances[25] - circumstances[24] * circumstances[27];
    tmp = tmp / n / circumstances[29];
    tmp = sign * Math.sqrt(1.0 - tmp * tmp) * circumstances[29] / n;
    tmp = (circumstances[24] * circumstances[26] + circumstances[25] * circumstances[27]) / circumstances[30] - tmp;
    circumstances[1] = circumstances[1] - tmp;
    timelocdependent(circumstances);
    iter++;
  }

  return circumstances;
}

//
// Get C2 and C3 data
//   Entry conditions -
//   1. The mid array must be populated
//   2. There mut be either a total or annular eclipse at the location!
function getc2c3()
{
  var tmp, n;

  n = Math.sqrt(mid[30]);
  tmp = mid[26] * mid[25] - mid[24] * mid[27];
  tmp = tmp / n / mid[29];
  tmp = Math.sqrt(1.0 - tmp * tmp) * mid[29] / n;
  c2[0] = -1;
  c3[0] = 1;
  if (mid[29] < 0.0)
  {
    c2[1] = mid[1] + tmp;
    c3[1] = mid[1] - tmp;
  }
  else
  {
    c2[1] = mid[1] - tmp;
    c3[1] = mid[1] + tmp;
  }
  c2c3iterate(c2);
  c2c3iterate(c3);
}

//
// Get the observational circumstances
function observational(circumstances)
{
  var contacttype, coslat, sinlat;

  // We are looking at an "external" contact UNLESS this is a total eclipse AND we are looking at
  // c2 or c3, in which case it is an INTERNAL contact! Note that if we are looking at mid eclipse,
  // then we may not have determined the type of eclipse (mid[39]) just yet!
  if (circumstances[0] == 0)
    contacttype = 1.0;
  else
  {
    if ((mid[39] == 3) && ((circumstances[0] == -1) || (circumstances[0] == 1)))
      contacttype = -1.0;
    else
      contacttype = 1.0;
  }
  // Calculate p
  circumstances[31] = Math.atan2(contacttype * circumstances[24], contacttype * circumstances[25]);
  // Calculate alt
  sinlat = Math.sin(obsvconst[0]);
  coslat = Math.cos(obsvconst[0]);
  circumstances[32] = Math.asin(circumstances[5] * sinlat + circumstances[6] * coslat * circumstances[18]);
  // Calculate q
  circumstances[33] = Math.asin(coslat * circumstances[17] / Math.cos(circumstances[32]));
  if (circumstances[20] < 0.0)
    circumstances[33] = Math.PI - circumstances[33];
  // Calculate v
  circumstances[34] = circumstances[31] - circumstances[33];
  // Calculate azi
  circumstances[35] = Math.atan2(-1.0 * circumstances[17] * circumstances[6], circumstances[5] * coslat - circumstances[18] * sinlat * circumstances[6]);
}

//
// Calculate mid eclipse
function getmid()
{
  var iter, tmp;

  mid[0] = 0;
  mid[1] = 0.0;
  iter = 0;
  tmp = 1.0;
  timelocdependent(mid);
  while (((tmp > 0.000001) || (tmp < -0.000001)) && (iter < 50))
  {
    tmp = (mid[24] * mid[26] + mid[25] * mid[27]) / mid[30];
    mid[1] -= tmp;
    iter++;
    timelocdependent(mid);
  }
}

//
// Populate the c1, c2, mid, c3 and c4 arrays
function getall()
{
  getmid();
  observational(mid);
  // Calculate m, magnitude and moon/sun
  mid[36] = Math.sqrt(mid[24] * mid[24] + mid[25] * mid[25]);
  mid[37] = (mid[28] - mid[36]) / (mid[28] + mid[29]);
  mid[38] = (mid[28] - mid[29]) / (mid[28] + mid[29]);
  if (mid[37] > 0.0)
  {
    getc1c4();
    if ((mid[36] < mid[29]) || (mid[36] < -mid[29]))
    {
      getc2c3();
      if (mid[29] < 0.0)
        mid[39] = 3; // Total eclipse
      else
        mid[39] = 2; // Annular eclipse
      observational(c2);
      observational(c3);
      // 2003 May 31 eclipse limb corrections -
      if (parseInt(document.getElementById("eclipseIndex").value, 10) == 8)
      {
        c2[36] = limbcorrection(c2[31], C2limb2003May);
        c3[36] = limbcorrection(c3[31], C3limb2003May);
        if (c2[36] < 990.0)
          c2[1] += c2[36] / 3600.0;
        if (c3[36] < 990.0)
          c3[1] += c3[36] / 3600.0;
      }
      else
      {
        c2[36] = 999.9;
        c3[36] = 999.9;
      }
    }
    else
      mid[39] = 1; // Partial eclipse
    observational(c1);
    observational(c4);
  }
  else
    mid[39] = 0; // No eclipse
}

//
// Read the data that's in the form, and populate the obsvconst array
function readform( language )
{
  var tmp;

  // Make sure that we have something to parse from the form
  if (document.getElementById("latd").value == "")
    document.getElementById("latd").value = "0";
  if (document.getElementById("latm").value == "")
    document.getElementById("latm").value = "0";
  if (document.getElementById("lond").value == "")
    document.getElementById("lond").value = "0";
  if (document.getElementById("lonm").value == "")
    document.getElementById("lonm").value = "0";
  if (document.getElementById("alt").value == "")
    document.getElementById("alt").value = "0";

  // Write back to the form what we are parsing
  document.getElementById("latd").value = Math.abs(parseFloat(document.getElementById("latd").value));
  document.getElementById("latm").value = Math.abs(parseFloat(document.getElementById("latm").value.replace(/,/, '.')));
  if (document.getElementById("latm").value < 10.0)
    document.getElementById("latm").value = "0" + document.getElementById("latm").value;
  if ( convert2dd(1, language) == false )
    return false;
  document.getElementById("lond").value = Math.abs(parseFloat(document.getElementById("lond").value));
  document.getElementById("lonm").value = Math.abs(parseFloat(document.getElementById("lonm").value.replace(/,/, '.')));
  if (document.getElementById("lonm").value < 10.0)
    document.getElementById("lonm").value = "0" + document.getElementById("lonm").value;
  if ( convert2dd(2, language) == false )
    return false;
  document.getElementById("alt").value = Math.abs(parseFloat(document.getElementById("alt").value));

  // Get the latitude
  obsvconst[0] = parseInt(document.getElementById("latd").value, 10);
  obsvconst[0] += (parseFloat(document.getElementById("latm").value) / 60.0);
  if ( checkDMS(1, obsvconst[0]) == false )
  {
    if ( language == "fr" )
      alert("La latitude exprim\xE9e en degr\xE9s doit \xEAtre comprise entre 0\xBA et 90\xBA.");
    else
      alert("The latitude in degrees must be between 0\xBA and 90\xBA.");
    document.getElementById("latd").focus();
    document.getElementById("latd").select();
    return false;
  }
  obsvconst[0] *= parseFloat(document.getElementById("latx").value);
  obsvconst[0] *= D2R;

  // Get the longitude
  obsvconst[1] = parseInt(document.getElementById("lond").value, 10);
  obsvconst[1] += (parseFloat(document.getElementById("lonm").value) / 60.0);
  if ( checkDMS(2, obsvconst[1]) == false )
  {
    if ( language == "fr" )
      alert("La longitude exprim\xE9e en degr\xE9s doit \xEAtre comprise entre 0\xBA et 180\xBA.");
    else
      alert("The longitude in degrees must be between 0\xBA and 180\xBA.");
    document.getElementById("lond").focus();
    document.getElementById("lond").select();
    return false;
  }
  obsvconst[1] *= parseFloat(document.getElementById("lonx").value);
  obsvconst[1] *= D2R;

  // Get the altitude
  obsvconst[2] = parseFloat(document.getElementById("alt").value);

  // Get the time zone
  obsvconst[3] = parseFloat(document.getElementById("tzh").value);
  obsvconst[3] += (parseFloat(document.getElementById("tzm").value) / 60.0);
  obsvconst[3] *= parseFloat(document.getElementById("tzx").value);
  obsvconst[3] -= parseFloat(document.getElementById("dst").value);

  // Get the observer's geocentric position
  tmp = Math.atan(0.99664719 * Math.tan(obsvconst[0]));
  obsvconst[4] = 0.99664719 * Math.sin(tmp) + (obsvconst[2] / 6378140.0) * Math.sin(obsvconst[0]);
  obsvconst[5] = Math.cos(tmp) + (obsvconst[2] / 6378140.0 * Math.cos(obsvconst[0]));

  // Get the index for the selected eclipse
  obsvconst[6] = 30 * getEclipseIndex();
}

//
// Convert the location coordinates to decimal notation
function convert2dd( which, language )
{
  var ddStr;

  if ( which == 1 ) // Latitude
  {
    if ( document.getElementById("lat_dd") )
    {
      ddStr = parseInt(document.getElementById("latd").value, 10);
      ddStr += parseFloat((document.getElementById("latm").value == "") ? "0.0" : document.getElementById("latm").value.replace(/\,/, '.')) / 60.0;
      if ( ! isNaN(ddStr) )
      {
        ddStr = Math.abs(ddStr);
        if ( ddStr > 90.0 )
        {
          if ( myLanguage == "fr" )
            alert("Saisissez une latitude comprise entre 0 et 90 degr\xE9s, Nord ou Sud.");
          else
            alert("Please enter a latitude between 0 and 90 degrees, North or South.");
          document.getElementById("latd").focus();
          document.getElementById("latd").select();
          return false;
        }
        if ( document.getElementById("latx").selectedIndex == 1 ) // South
          ddStr = -ddStr;
        ddStr = ddStr.toFixed(5);
        if ( language == "fr" )
          ddStr = ddStr.replace(/\./, ',');
        document.getElementById("lat_dd").innerHTML = "&#160;&#8212;&#62;&#160;" + ddStr + "&#176;";
      }
      else
        document.getElementById("lat_dd").innerHTML = "";
    }
  }
  else // Longitude
  {
    if ( document.getElementById("lon_dd") )
    {
      ddStr = parseInt(document.getElementById("lond").value, 10);
      ddStr += parseFloat((document.getElementById("lonm").value == "") ? "0.0" : document.getElementById("lonm").value.replace(/\,/, '.')) / 60.0;
      if ( ! isNaN(ddStr) )
      {
        ddStr = Math.abs(ddStr);
        if ( ddStr > 180.0 )
        {
          if ( myLanguage == "fr" )
            alert("Saisissez une longitude comprise entre 0 et 180 degr\xE9s, Est ou Ouest.");
          else
            alert("Please enter a longitude between 0 and 180 degrees, East or West.");
          document.getElementById("lond").focus();
          document.getElementById("lond").select();
          return false;
        }
        if ( document.getElementById("lonx").selectedIndex == 1 ) // West
          ddStr = -ddStr;
        ddStr = ddStr.toFixed(5);
        if ( language == "fr" )
          ddStr = ddStr.replace(/\./, ',');
        document.getElementById("lon_dd").innerHTML = "&#160;&#8212;&#62;&#160;" + ddStr + "&#176;";
      }
      else
        document.getElementById("lon_dd").innerHTML = "";
    }
  }

  var id = document.getElementById("world_map");
  if ( id )
  {
    var ddLat = parseInt((document.getElementById("latd").value == "") ? "0" : document.getElementById("latd").value.replace(/\,/, '.'), 10);
    ddLat += parseFloat((document.getElementById("latm").value == "") ? "0.0" : document.getElementById("latm").value.replace(/\,/, '.')) / 60.0;
    var ddLng = parseInt((document.getElementById("lond").value == "") ? "0" : document.getElementById("lond").value.replace(/\,/, '.'), 10);
    ddLng += parseFloat((document.getElementById("lonm").value == "") ? "0.0" : document.getElementById("lonm").value.replace(/\,/, '.')) / 60.0;
    if ( ( ! isNaN(ddLat) ) && ( ! isNaN(ddLng) ) )
    {
      ddLat = Math.abs(ddLat);
      if ( document.getElementById("latx").selectedIndex == 1 ) // South
        ddLat = -ddLat;
      ddLng = Math.abs(ddLng);
      if ( document.getElementById("lonx").selectedIndex == 1 ) // West
        ddLng = -ddLng;
      var x = lng2x(ddLng) - 2;
      var y = lat2y(ddLat) - 2;
      var obs = document.getElementById("observer");
      if ( obs )
      {
        obs.style.left = x + id.style.left + "px";
        obs.style.top = y + id.style.top + "px";
        obs.style.display = "block";
      }
    }
  }

  return true;
}

/* Location mapping */
var xWidth = 134; // Width of the total map in pixels
var yWidth = 67; // Height of the total map in pixels
var xOffset = 67; // x offset of the map in pixels
var yOffset = 34; // y offset of the map in pixels

function lng2x( longitude )
{
  return(xOffset + Math.round((longitude * xWidth) / 360));
}

function lat2y( latitude )
{
  return(yOffset - Math.round((latitude * yWidth) / 180));
}

function ShowObserver( )
{
  var id = document.getElementById("world_map");
  if ( id )
  {
    var x = lng2x(-gLng) - 2;
    var y = lat2y(gLat) - 2;
    var obs = document.getElementById("observer");
    if ( obs )
    {
      obs.style.left = x + id.style.left + "px";
      obs.style.top = y + id.style.top + "px";
      obs.style.display = "block";
    }
  }
}

function x2lng( x )
{
  return(360 * (x - xOffset) / xWidth);
}

function y2lat( y )
{
  return(180 * (yOffset - y) / yWidth);
}

//
// Handle a location modification
function modifiedCoordinates( which )
{
  clearresults();
  convert2dd(which, getLocalizedString("Language"));
}

//
// Check the latitude/longitude bounds
function checkDMS( type, checkLatLon )
{
  var toCheck = Math.abs(checkLatLon);

  if ( type == 1) // Latitude
  {
    if ( toCheck <= 90.0 )
      return true;
    else
      return false;
  }
  else // Longitude
  {
    if ( toCheck <= 180.0 )
      return true;
    else
      return false;
  }
}

//
// Read the deltaT value for the selected eclipse
function getdTValue()
{
  var index, deltaT;

  index = 30 * getEclipseIndex();
  deltaT = elements[5 + index];
  document.getElementById("deltaT").innerText = getLocalizedString("deltaTbefore") + deltaT.toFixed(1) + getLocalizedString("deltaTafter");
}

//
// Clear the form results
function clearresults()
{
  document.getElementById("c1_date").innerText = "00/00/00";
  document.getElementById("c1_date").style.visibility = "hidden";
  document.getElementById("c1_time").innerText = "00:00:00.0";
  document.getElementById("c1_time").style.visibility = "hidden";
  document.getElementById("c1_alt").innerText = "+00\xB0";
  document.getElementById("c1_alt").style.visibility = "hidden";
  document.getElementById("c1_azi").innerText = "000\xB0";
  document.getElementById("c1_azi").style.visibility = "hidden";
  document.getElementById("c1_p").innerText = "000\xB0";
  document.getElementById("c1_p").style.visibility = "hidden";
  document.getElementById("c1_v").innerText = "00.0";
  document.getElementById("c1_v").style.visibility = "hidden";
  document.getElementById("c2_date").innerText = "00/00/00";
  document.getElementById("c2_date").style.visibility = "hidden";
  document.getElementById("c2_time").innerText = "00:00:00.0";
  document.getElementById("c2_time").style.visibility = "hidden";
  document.getElementById("c2_alt").innerText = "+00\xB0";
  document.getElementById("c2_alt").style.visibility = "hidden";
  document.getElementById("c2_azi").innerText = "000\xB0";
  document.getElementById("c2_azi").style.visibility = "hidden";
  document.getElementById("c2_p").innerText = "000\xB0";
  document.getElementById("c2_p").style.visibility = "hidden";
  document.getElementById("c2_v").innerText = "00.0";
  document.getElementById("c2_v").style.visibility = "hidden";
  document.getElementById("c2_lc").innerText = "+00.0";
  document.getElementById("c2_lc").style.visibility = "hidden";
  document.getElementById("mid_date").innerText = "00/00/00";
  document.getElementById("mid_date").style.visibility = "hidden";
  document.getElementById("mid_time").innerText = "00:00:00.0";
  document.getElementById("mid_time").style.visibility = "hidden";
  document.getElementById("mid_alt").innerText = "+00\xB0";
  document.getElementById("mid_alt").style.visibility = "hidden";
  document.getElementById("mid_azi").innerText = "000\xB0";
  document.getElementById("mid_azi").style.visibility = "hidden";
  document.getElementById("mid_p").innerText = "000\xB0";
  document.getElementById("mid_p").style.visibility = "hidden";
  document.getElementById("mid_v").innerText = "00.0";
  document.getElementById("mid_v").style.visibility = "hidden";
  document.getElementById("c3_date").innerText = "00/00/00";
  document.getElementById("c3_date").style.visibility = "hidden";
  document.getElementById("c3_time").innerText = "00:00:00.0";
  document.getElementById("c3_time").style.visibility = "hidden";
  document.getElementById("c3_alt").innerText = "+00\xB0";
  document.getElementById("c3_alt").style.visibility = "hidden";
  document.getElementById("c3_azi").innerText = "000\xB0";
  document.getElementById("c3_azi").style.visibility = "hidden";
  document.getElementById("c3_p").innerText = "000\xB0";
  document.getElementById("c3_p").style.visibility = "hidden";
  document.getElementById("c3_v").innerText = "00.0";
  document.getElementById("c3_v").style.visibility = "hidden";
  document.getElementById("c3_lc").innerText = "+00.0";
  document.getElementById("c3_lc").style.visibility = "hidden";
  document.getElementById("c4_date").innerText = "00/00/00";
  document.getElementById("c4_date").style.visibility = "hidden";
  document.getElementById("c4_time").innerText = "00:00:00.0";
  document.getElementById("c4_time").style.visibility = "hidden";
  document.getElementById("c4_alt").innerText = "+00\xB0";
  document.getElementById("c4_alt").style.visibility = "hidden";
  document.getElementById("c4_azi").innerText = "000\xB0";
  document.getElementById("c4_azi").style.visibility = "hidden";
  document.getElementById("c4_p").innerText = "000\xB0";
  document.getElementById("c4_p").style.visibility = "hidden";
  document.getElementById("c4_v").innerText = "00.0";
  document.getElementById("c4_v").style.visibility = "hidden";
  document.getElementById("E_type").innerText = "NONE";
  document.getElementById("E_type").style.visibility = "hidden";
  document.getElementById("E_duration").innerText = "0:00.0";
  document.getElementById("E_duration").style.visibility = "hidden";
  document.getElementById("E_mag").innerText = "100.0%";
  document.getElementById("E_mag").style.visibility = "hidden";
  document.getElementById("E_ratio").innerText = "0.00000";
  document.getElementById("E_ratio").style.visibility = "hidden";
  document.getElementById("E_coverage").innerText = "0.0000";
  document.getElementById("E_coverage").style.visibility = "hidden";
  document.getElementById("E_depth").innerText = "100.0%";
  document.getElementById("E_depth").style.visibility = "hidden";
}

//
// Clear the form inputs
function clearinputs()
{
  document.getElementById("latd").value = "";
  document.getElementById("latm").value = "";
  document.getElementById("latx").selectedIndex = 0; // North
  document.getElementById("lond").value = "";
  document.getElementById("lonm").value = "";
  document.getElementById("lonx").selectedIndex = 0; // East
  document.getElementById("alt").value = "";
  document.getElementById("tzh").selectedIndex = 0; // Hour
  document.getElementById("tzm").selectedIndex = 0; // Minute
  document.getElementById("tzx").selectedIndex = 0; // East
  document.getElementById("dst").selectedIndex = 0; // Winter / Regular Time
}

//
// Get the local date of an event
function getdate( circumstances, language )
{
  var ans, a;

  var index = obsvconst[6];
  // JD for noon (TDT) the day before the day that contains T0
  var jd = Math.floor(elements[index] - (elements[1 + index] / 24.0));
  // Local time (ie the offset in hours since midnight TDT on the day containing T0) to the nearest 0.1 sec
  t = circumstances[1] + elements[1 + index] - obsvconst[3] - (elements[4 + index] - 0.05) / 3600.0;
  if (t < 0.0)
    jd--;
  else if (t >= 24.0)
    jd++;
  if (jd >= 2299160.0)
  {
    a = Math.floor((jd - 1867216.25) / 36524.25);
    a += jd + 1 - Math.floor(a / 4);
  }
  else
    a = jd;
  var b = a + 1525.0;
  var c = Math.floor((b - 122.1) / 365.25);
  var d = Math.floor(365.25 * c);
  var e = Math.floor((b - d) / 30.6001);
  d = b - d - Math.floor(30.6001 * e);
  if (e < 13.5)
    e -= 1;
  else
    e -= 13;
  if ( language == "fr" )
  {
    if (d < 10)
      ans = "0";
    else
      ans = "";
    ans += d + "/";
    if (e < 10)
      ans += "0";
    ans += e + "/";
    if (e > 2.5)
      ans += c - 4716;
    else
      ans += c - 4715;
  }
  else
  {
    if (e > 2.5)
      ans = c - 4716 + "/";
    else
      ans = c - 4715 + "/";
    if (e < 10)
      ans += "0";
    ans += e + "/";
    if (d < 10)
      ans += "0";
    ans += d;
  }

  return ans;
}


//
// Get the local time of an event
function gettime(circumstances, language)
{
  var t, ans, index;

  ans = "";
  index = obsvconst[6];
  // Calculate the local time. Add 0.05 seconds, as we will be rounding up to the nearest 0.1 sec
  t = circumstances[1] + elements[1 + index] - obsvconst[3] - (elements[4 + index] - 0.05) / 3600.0;
  if (t < 0.0)
    t += 24.0
  if (t >= 24.0)
    t -= 24.0;
  if (t < 10.0)
    ans += "0";
  ans += Math.floor(t) + ":";
  t = (t * 60.0) - 60.0 * Math.floor(t);
  if (t < 10.0)
    ans += "0";
  ans += Math.floor(t) + ":"
  t = (t * 60.0) - 60.0 * Math.floor(t);
  if (t < 10.0)
    ans += "0";
  ans += Math.floor(t);
  if ( language == "fr" )
    ans += ",";
  else
    ans += ".";
  ans += Math.floor(10.0 * (t - Math.floor(t)));
  // Add an asterix if the altitude is less than zero
  if (circumstances[32] <= 0.0)
    ans += "*";

  return ans;
}

//
// Get the altitude
function getalt(circumstances, language)
{
  var t, ans;

  t = circumstances[32] * R2D;
  if (t < 0.0)
  {
    ans = "-";
    t = -t;
  }
  else
    ans = "+";
  t = Math.floor(t + 0.5);
  if (t < 10.0)
    ans = ans + "0";
  ans = ans + t + "\xB0";

  return ans;
}

//
// Get the true altitude
function gettruealt(circumstances, language)
{
  var t, ans;

  t = circumstances[32] * R2D;
  if (t > 0.0)
  {
    var true_alt = elevationRefraction(t);
    true_alt = true_alt.toFixed(1);
    if ( language == "fr" )
      true_alt = true_alt.replace(/\./, ',');

    ans = true_alt + "\xB0 " + ((language == "fr") ? "avec la r\xE9fraction" : "with refraction");
  }
  else
    ans = "";

  return ans;
}

//
// Get the azimuth
function getazi(circumstances, language)
{
  var t, ans;

  ans = "";
  t = circumstances[35] * R2D;
  if (t < 0.0)
    t += 360.0;
  else if (t >= 360.0)
    t -= 360.0;
  t = Math.floor(t + 0.5)
  if (t < 10.0)
    ans += "00";
  else if (t < 100.0)
    ans += "0";
  ans += t + "\xB0";

  return ans;
}

//
// Get P
function getp(circumstances)
{
  var ans, t;

  ans = "";
  t = circumstances[31] * R2D;
  if (t < 0.0)
    t += 360.0;
  else if (t >= 360.0)
    t -= 360.0;
  t = Math.floor(t + 0.5)
  if (t < 10.0)
    ans += "00";
  else if (t < 100.0)
    ans += "0";
  ans += t + "\xB0";

  return ans;
}

//
// Get V
function getv(circumstances, language)
{
  var t, ans;

  ans = "";
  t = Math.floor(120.5 - circumstances[34] * 60.0 / Math.PI) / 10.0;
  if (t > 13.0)
    t -= 12.0;
  if (t > 13.0)
    t -= 12.0;
  if (t < 1.0)
    t += 12.0;
  if (t < 10.0)
    ans += "0";
  ans += Math.floor(t);
  if ( language == "fr" )
    ans += ",";
  else
    ans += ".";
  ans += Math.floor(t * 10.0 - 10.0 * Math.floor(t));

  return ans;
}

//
// Get the limb correction
function getlc(circumstances, language)
{
  var t, ans;

  ans = "";
  if (((circumstances[0] == 1) || (circumstances[0] == -1)) && (circumstances[36] < 990.0))
  {
    if (circumstances[36] < 0.0)
    {
      ans = "-";
      t = -circumstances[36];
    }
    else
    {
      ans = "+";
      t = circumstances[36];
    }
    t = Math.floor(t * 10.0 + 0.5) / 10.0;
    ans += Math.floor(t);
    if ( language == "fr" )
      ans += ",";
    else
      ans += ".";
    ans += Math.floor(t * 10.0 - 10.0 * Math.floor(t));
  }

  return ans;
}

function elevationRefraction( elv_geometric )
{
  if ( elv_geometric > 10.2 )
    refraction = 0.01617 * Math.cos(elv_geometric * D2R) / Math.sin(elv_geometric * D2R);
  else
  {
    var a0 = 0.58804392;
    var a1 = -0.17941557;
    var a2 = 0.29906946e-1;
    var a3 = -0.25187400e-2;
    var a4 = 0.82622101e-4;
    var x = Math.abs(elv_geometric + 0.589);
    var x2 = x * x;
    var x3 = x * x2;
    var x4 = x2 * x2;
    refraction = Math.abs(a0 + (a1 * x) + (a2 * x2) + (a3 * x3) + (a4 * x4));
  }
  var elv_observed = elv_geometric + refraction;

  return(elv_observed);
}

//
// Display the information about 1st and 4th contact
function displayc1c4( language )
{
  document.getElementById("c1_date").innerText = getdate(c1, language);
  document.getElementById("c1_date").style.visibility = "visible";
  document.getElementById("c1_time").innerText = gettime(c1, language);
  document.getElementById("c1_time").style.visibility = "visible";
  document.getElementById("c1_alt").innerText = getalt(c1, language);
  document.getElementById("c1_alt").title = gettruealt(c1, language);
  document.getElementById("c1_alt").style.visibility = "visible";
  document.getElementById("c1_azi").innerText = getazi(c1, language);
  document.getElementById("c1_azi").style.visibility = "visible";
  document.getElementById("c1_p").innerText = getp(c1);
  document.getElementById("c1_p").style.visibility = "visible";
  document.getElementById("c1_v").innerText = getv(c1, language);
  document.getElementById("c1_v").style.visibility = "visible";

  document.getElementById("c4_date").innerText = getdate(c4, language);
  document.getElementById("c4_date").style.visibility = "visible";
  document.getElementById("c4_time").innerText = gettime(c4, language);
  document.getElementById("c4_time").style.visibility = "visible";
  document.getElementById("c4_alt").innerText = getalt(c4, language);
  document.getElementById("c4_alt").title = gettruealt(c4, language);
  document.getElementById("c4_alt").style.visibility = "visible";
  document.getElementById("c4_azi").innerText = getazi(c4, language);
  document.getElementById("c4_azi").style.visibility = "visible";
  document.getElementById("c4_p").innerText = getp(c4);
  document.getElementById("c4_p").style.visibility = "visible";
  document.getElementById("c4_v").innerText = getv(c4, language);
  document.getElementById("c4_v").style.visibility = "visible";
}

//
// Display the information about 2nd and 3rd contact
function displayc2c3( language )
{
  document.getElementById("c2_date").innerText = getdate(c2, language);
  document.getElementById("c2_date").style.visibility = "visible";
  document.getElementById("c2_time").innerText = gettime(c2, language);
  document.getElementById("c2_time").style.visibility = "visible";
  document.getElementById("c2_alt").innerText = getalt(c2, language);
  document.getElementById("c2_alt").title = gettruealt(c2, language);
  document.getElementById("c2_alt").style.visibility = "visible";
  document.getElementById("c2_azi").innerText = getazi(c2, language);
  document.getElementById("c2_azi").style.visibility = "visible";
  document.getElementById("c2_p").innerText = getp(c2);
  document.getElementById("c2_p").style.visibility = "visible";
  document.getElementById("c2_v").innerText = getv(c2, language);
  document.getElementById("c2_v").style.visibility = "visible";
  document.getElementById("c2_lc").innerText = getlc(c2, language);
  document.getElementById("c2_lc").style.visibility = "visible";

  document.getElementById("c3_date").innerText = getdate(c3, language);
  document.getElementById("c3_date").style.visibility = "visible";
  document.getElementById("c3_time").innerText = gettime(c3, language);
  document.getElementById("c3_time").style.visibility = "visible";
  document.getElementById("c3_alt").innerText = getalt(c3, language);
  document.getElementById("c3_alt").title = gettruealt(c3, language);
  document.getElementById("c3_alt").style.visibility = "visible";
  document.getElementById("c3_azi").innerText = getazi(c3, language);
  document.getElementById("c3_azi").style.visibility = "visible";
  document.getElementById("c3_p").innerText = getp(c3);
  document.getElementById("c3_p").style.visibility = "visible";
  document.getElementById("c3_v").innerText = getv(c3, language);
  document.getElementById("c3_v").style.visibility = "visible";
  document.getElementById("c3_lc").innerText = getlc(c3, language);
  document.getElementById("c2_lc").style.visibility = "visible";
}

//
// Display the information about mid eclipse
function displaymid( language )
{
  document.getElementById("mid_date").innerText = getdate(mid, language);
  document.getElementById("mid_date").style.visibility = "visible";
  document.getElementById("mid_time").innerText = gettime(mid, language);
  document.getElementById("mid_time").style.visibility = "visible";
  document.getElementById("mid_alt").innerText = getalt(mid, language);
  document.getElementById("mid_alt").title = gettruealt(mid, language);
  document.getElementById("mid_alt").style.visibility = "visible";
  document.getElementById("mid_azi").innerText = getazi(mid, language);
  document.getElementById("mid_azi").style.visibility = "visible";
  document.getElementById("mid_p").innerText = getp(mid);
  document.getElementById("mid_p").style.visibility = "visible";
  document.getElementById("mid_v").innerText = getv(mid, language);
  document.getElementById("mid_v").style.visibility = "visible";
}

//
// Get the duration in mm:ss.s format
//
// Adapted from code written by Stephen McCann - 27/04/2001
function getduration( language )
{
  var tmp, ans;

  tmp = c3[1] - c2[1];
  if (tmp < 0.0)
    tmp += 24.0;
  else if (tmp >= 24.0)
    tmp -= 24.0;
  tmp = (tmp * 60.0) - 60.0 * Math.floor(tmp) + 0.05 / 60.0;
  ans = Math.floor(tmp) + ":";
  tmp = (tmp * 60.0) - 60.0 * Math.floor(tmp);
  if (tmp < 10.0)
    ans += "0";
  ans += Math.floor(tmp);
  if ( language == "fr" )
    ans += ",";
  else
    ans += ".";
  ans += Math.floor((tmp - Math.floor(tmp)) * 10.0);

  return ans;
}

//
// Get the coverage
function getcoverage( language )
{
  var a, b, c;

  if (mid[37] <= 0.0)
  {
    if ( language == "fr" )
      return "0,0%";
    else
      return "0.0%";
  }
  else if (mid[37] >= 1.0)
  {
    if ( language == "fr" )
      return "100,0%";
    else
      return "100.0%";
  }
  if (mid[39] == 2)
    c = mid[38] * mid[38];
  else
  {
    c = Math.acos((mid[28] * mid[28] + mid[29] * mid[29] - 2.0 * mid[36] * mid[36]) / (mid[28] * mid[28] - mid[29] * mid[29]));
    b = Math.acos((mid[28] * mid[29] + mid[36] * mid[36]) / mid[36] / (mid[28] + mid[29]));
    a = Math.PI - b - c;
    c = ((mid[38] * mid[38] * a + b) - mid[38] * Math.sin(c)) / Math.PI;
  }
  c = (1000.0 * c + 0.5) / 10.0;
  a = Math.floor(c);
  if ( language == "fr" )
    a += ",";
  else
    a += ".";
  a += Math.floor(10.0 * c - Math.floor(c) * 10.0);
  a += "%";

  return a;
}

//
// Get the (Ant)Umbral depth
// Entry condition - there is a total or annular eclipse
function getdepth( language )
{
  var depth, ans;

  depth = mid[36] / mid[29];
  if (depth < 0.0)
    depth = 1.0 + depth;
  else
    depth = 1.0 - depth;
  depth = Math.floor(depth * 1000.0 + 0.5) / 10.0;
  ans = Math.floor(depth);
  if ( language == "fr" )
    ans += ",";
  else
    ans += ".";
  ans += Math.floor(10.0 * depth - Math.floor(depth) * 10.0);
  ans += "%";

  return ans;
}

//
// Re-calculate
function recalculate( language )
{
  var tmp;
  var refractionHeight = -0.00524;	// Take refraction into account

  clearresults();
  readform(language);
  getall();
  getdTValue();
  displaymid( language );
  tmp = "" + Math.floor(100000.0 * mid[37] + 0.5) / 100000.0;
  if ( language == "fr" )
    document.getElementById("E_mag").innerText = tmp.replace(/\./, ',');
  else
    document.getElementById("E_mag").innerText = tmp;
  tmp = "" + Math.floor(100000.0 * mid[38] + 0.5) / 100000.0;
  if ( language == "fr" )
    document.getElementById("E_ratio").innerText = tmp.replace(/\./, ',');
  else
    document.getElementById("E_ratio").innerText = tmp;
  document.getElementById("E_mag").style.visibility = "visible";
  document.getElementById("E_ratio").style.visibility = "visible";
  // Is there an event?
  if (mid[39] > 0)
  {
    displayc1c4( language );
    // Is there a total/annular event?
    if (mid[39] > 1)
    {
      displayc2c3( language );
      // Is the sun below the horizon for the entire duration of the event?
      if ((c1[32] <= refractionHeight) && (c4[32] <= refractionHeight))
      {
        if ( language == "fr" )
        {
          document.getElementById("E_type").innerText = "AUCUNE";
          document.getElementById("E_duration").innerText = "ns";
          document.getElementById("E_coverage").innerText = "ns";
          document.getElementById("E_depth").innerText = "ns";
        }
        else
        {
          document.getElementById("E_type").innerText = "NONE";
          document.getElementById("E_duration").innerText = "n/a";
          document.getElementById("E_coverage").innerText = "n/a";
          document.getElementById("E_depth").innerText = "n/a";
        }
        document.getElementById("E_type").style.visibility = "visible";
        document.getElementById("E_duration").style.visibility = "visible";
        document.getElementById("E_coverage").style.visibility = "visible";
        document.getElementById("E_depth").style.visibility = "visible";
      }
      else // ... or is the sun above the horizon for at least some of the event?
      {
        // Is the sun below the horizon for just the total/annular event?
        if ((c2[32] <= refractionHeight) && (c3[32] <= refractionHeight))
        {
          if ( language == "fr" )
          {
            document.getElementById("E_type").innerText = "Partielle";
            document.getElementById("E_duration").innerText = "ns";
          }
          else
          {
            document.getElementById("E_type").innerText = "Partial";
            document.getElementById("E_duration").innerText = "n/a"
          }
          document.getElementById("E_coverage").innerText = "???";
          document.getElementById("E_depth").innerText = "???";
          document.getElementById("E_type").style.visibility = "visible";
          document.getElementById("E_duration").style.visibility = "visible";
          document.getElementById("E_coverage").style.visibility = "visible";
          document.getElementById("E_depth").style.visibility = "visible";
        }
        else // ... or is the sun above the horizon for at least some of the total/annular event?
        {
          // Is it an annular event?
          if (mid[39] == 2)
          {
            if ( language == "fr" )
              document.getElementById("E_type").innerText = "Annulaire";
            else
              document.getElementById("E_type").innerText = "Annular";
            document.getElementById("E_type").style.visibility = "visible";
          }
          else
          {
            if ( language == "fr" )
              document.getElementById("E_type").innerText = "Totale";
            else
              document.getElementById("E_type").innerText = "Total";
            document.getElementById("E_type").style.visibility = "visible";
          }
          document.getElementById("E_depth").innerText = getdepth(language);
          document.getElementById("E_depth").style.visibility = "visible";
          // Is the sun above the horizon for the entire annular/total event?
          if ((c2[32] > refractionHeight) && (c3[32] > refractionHeight))
          {
            document.getElementById("E_duration").innerText = getduration(language);
            document.getElementById("E_coverage").innerText = getcoverage(language);
          }
          else // ... or is the sun below the horizon for at least some of the annular/total event
          {
            document.getElementById("E_duration").innerText = "???";
            // Is the sun above the horizon at C2 or C3? (The coverage remains constant during a total/annular event)
            if ((c2[32] > refractionHeight) || (c3[32] > refractionHeight))
              document.getElementById("E_coverage").innerText = getcoverage(language);
            else
             document.getElementById("E_coverage").innerText = "???";
          }
          document.getElementById("E_duration").style.visibility = "visible";
          document.getElementById("E_coverage").style.visibility = "visible";
        }
      }
    }
    else // ... or is it just a partial event?
    {
      // Is the sun below the horizon for the entire event?
      if ((c1[32] <= refractionHeight) && (c4[32] <= refractionHeight))
      {
        if ( language == "fr" )
        {
          document.getElementById("E_type").innerText = "AUCUNE";
          document.getElementById("E_coverage").innerText = "ns";
        }
        else
        {
          document.getElementById("E_type").innerText = "NONE";
          document.getElementById("E_coverage").innerText = "n/a";
        }
        document.getElementById("E_type").style.visibility = "visible";
        document.getElementById("E_coverage").style.visibility = "visible";
      }
      else // ... or is the sun above the horizon for at least some of the event?
      {
        if ( language == "fr" )
          document.getElementById("E_type").innerText = "Partielle";
        else
          document.getElementById("E_type").innerText = "Partial";
        document.getElementById("E_type").style.visibility = "visible";
        // Is the sun below the horizon at mid eclipse?
        if (mid[32] <= refractionHeight)
          document.getElementById("coverage").innerText = "???";
        else // ... or is the sun above the horizon at mid eclipse?
          document.getElementById("E_coverage").innerText = getcoverage(language);
        document.getElementById("E_coverage").style.visibility = "visible";
      }
      if ( language == "fr" )
      {
        document.getElementById("E_duration").innerText = "ns";
        document.getElementById("E_depth").innerText = "ns";
        document.getElementById("c2_date").innerText = "= Aucune =";
        document.getElementById("c2_date").style.visibility = "visible";
        document.getElementById("c3_date").innerText = "= Aucune =";
        document.getElementById("c3_date").style.visibility = "visible";
      }
      else
      {
        document.getElementById("E_duration").innerText = "n/a";
        document.getElementById("E_depth").innerText = "n/a";
        document.getElementById("c2_date").innerText = "== None ==";
        document.getElementById("c2_date").style.visibility = "visible";
        document.getElementById("c3_date").innerText = "== None ==";
        document.getElementById("c3_date").style.visibility = "visible";
      }
      document.getElementById("E_duration").style.visibility = "visible";
      document.getElementById("E_depth").style.visibility = "visible";
    }
  }
  else // ... or is there no event at all?
  {
    if ( language == "fr" )
    {
      document.getElementById("E_type").innerText = "AUCUNE";
      document.getElementById("E_duration").innerText = "ns";
      document.getElementById("E_coverage").innerText = "ns";
      document.getElementById("E_depth").innerText = "ns";
      document.getElementById("c1_date").innerText = "= Aucune =";
      document.getElementById("c2_date").innerText = "= Aucune =";
      document.getElementById("c3_date").innerText = "= Aucune =";
      document.getElementById("c4_date").innerText = "= Aucune =";
    }
    else
    {
      document.getElementById("E_type").innerText = "NONE";
      document.getElementById("E_duration").innerText = "n/a";
      document.getElementById("E_coverage").innerText = "n/a";
      document.getElementById("E_depth").innerText = "n/a";
      document.getElementById("c1_date").innerText = "== None ==";
      document.getElementById("c2_date").innerText = "== None ==";
      document.getElementById("c3_date").innerText = "== None ==";
      document.getElementById("c4_date").innerText = "== None ==";
    }
    document.getElementById("E_type").style.visibility = "visible";
    document.getElementById("E_duration").style.visibility = "visible";
    document.getElementById("E_coverage").style.visibility = "visible";
    document.getElementById("E_depth").style.visibility = "visible";
    document.getElementById("c1_date").style.visibility = "visible";
    document.getElementById("c2_date").style.visibility = "visible";
    document.getElementById("c3_date").style.visibility = "visible";
    document.getElementById("c4_date").style.visibility = "visible";
  }

  document.getElementById("latd").focus();
  document.getElementById("latd").select();
}

function checkUpdate( language )
{
  var url = 'http://xjubier.free.fr/download/sec_widget_version.php';
  var versionCheckRequest = new XMLHttpRequest();
  versionCheckRequest.open("GET", url, true);
  versionCheckRequest.onreadystatechange = function( )
  {
    if ( versionCheckRequest.readyState == 4 )
    {
      if ( ( versionCheckRequest.status == 200 ) && ( versionCheckRequest.responseText > getVersion(1, 0, 6) ) )	// "1.0.6"
      {
        if ( language == "fr" )
        {
          document.getElementById("version_update").innerHTML = '<a href="javascript:widget.openURL(\'http://xjubier.free.fr/site_pages/SolarEclipsesDownloads.html\');">Nouvelle version disponible</a>';
          document.getElementById("version_update").title = "Merci de t\xE9l\xE9charger la nouvelle version";
        }
        else
        {
          document.getElementById("version_update").innerHTML = '<a href="javascript:widget.openURL(\'http://xjubier.free.fr/en/site_pages/SolarEclipsesDownloads.html\');">New version available</a>';
          document.getElementById("version_update").title = "Please download the new version";
        }
      }
      else
      {
          document.getElementById("version_update").innerHTML = "";
      }	
    }
  }
  versionCheckRequest.send(null);
}

function getVersion( major, minor, revision )
{
  version = (major * 20) + (minor * 10) + revision;

  return version;
}
//-->